// Add this function to the existing JavaScript in get-reports.php

// Function to play emergency announcement for a report
function playEmergencyAnnouncement(report) {
    // Get report data
    const codeLabel = report.code_label || '';
    const codeDescription = report.code_description || '';
    const location = report.location || '';
    const details = report.details || '';
    
    // Create an attention sound using AudioContext
    const playAttentionSound = () => {
        return new Promise((resolve) => {
            try {
                const audioContext = new (window.AudioContext || window.webkitAudioContext)();
                const oscillator = audioContext.createOscillator();
                const gainNode = audioContext.createGain();
                
                oscillator.type = 'sine';
                oscillator.frequency.setValueAtTime(880, audioContext.currentTime); // A5 note
                
                // Fade in/out to avoid clicks
                gainNode.gain.setValueAtTime(0, audioContext.currentTime);
                gainNode.gain.linearRampToValueAtTime(0.5, audioContext.currentTime + 0.1);
                gainNode.gain.linearRampToValueAtTime(0, audioContext.currentTime + 0.8);
                
                oscillator.connect(gainNode);
                gainNode.connect(audioContext.destination);
                
                oscillator.start();
                oscillator.stop(audioContext.currentTime + 0.9);
                
                // Resolve after sound finishes
                setTimeout(resolve, 1000);
            } catch (error) {
                console.error("Error playing attention sound:", error);
                resolve(); // Continue even if sound fails
            }
        });
    };
    
    // Function to get best available voice
    const getBestAvailableVoice = () => {
        const voices = window.speechSynthesis.getVoices();
        
        // Try to find a premium/enhanced voice
        const premiumVoice = voices.find(voice => 
            (voice.name.includes('Premium') || voice.name.includes('Enhanced')) && 
            voice.lang.startsWith('en')
        );
        
        if (premiumVoice) return premiumVoice;
        
        // Try specific high-quality voices by name
        const knownGoodVoices = [
            'Google US English Male',
            'Microsoft David',
            'Microsoft Mark',
            'Daniel',
            'Google UK English Male'
        ];
        
        for (const voiceName of knownGoodVoices) {
            const voice = voices.find(v => v.name.includes(voiceName));
            if (voice) return voice;
        }
        
        // Try any male English voice
        const maleEnglishVoice = voices.find(voice => 
            voice.lang.startsWith('en') && 
            (voice.name.includes('Male') || !voice.name.includes('Female'))
        );
        
        if (maleEnglishVoice) return maleEnglishVoice;
        
        // Fall back to any English voice
        const anyEnglishVoice = voices.find(voice => voice.lang.startsWith('en'));
        
        if (anyEnglishVoice) return anyEnglishVoice;
        
        // Last resort: any available voice
        return voices[0];
    };
    
    // Function to speak each part of the announcement
    const speakWithPacing = async (text) => {
        return new Promise((resolve) => {
            try {
                const utterance = new SpeechSynthesisUtterance(text);
                const voice = getBestAvailableVoice();
                
                // Optimize speech parameters
                utterance.rate = 0.9;     // Slightly slower for clarity
                utterance.pitch = 1.0;    // Natural pitch
                utterance.volume = 1.0;   // Maximum volume
                
                if (voice) {
                    utterance.voice = voice;
                }
                
                // Set up event handlers
                utterance.onend = () => {
                    resolve();
                };
                
                utterance.onerror = (e) => {
                    console.error("Speech synthesis error:", e);
                    resolve();
                };
                
                // Start speaking
                window.speechSynthesis.speak(utterance);
            } catch (error) {
                console.error("Error in speech synthesis:", error);
                resolve();
            }
        });
    };
    
    // Main function to run the announcement sequence
    const runAnnouncement = async () => {
        // Update UI to show playing status
        const playBtn = document.getElementById('play-announcement-btn');
        if (playBtn) {
            playBtn.disabled = true;
            playBtn.innerHTML = '<svg class="animate-spin -ml-1 mr-2 h-4 w-4 text-white inline-block" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"><circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle><path class="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path></svg> Playing...';
        }
        
        try {
            // Format announcement text
            const announcementText = `Attention all staff. ${codeLabel}. ${codeDescription}. Has been reported in ${location}.`;
            const detailsText = details ? `Additional details: ${details}.` : '';
            const repetitionText = `Repeating: ${codeLabel} in ${location}.`;
            
            // Cancel any ongoing speech
            window.speechSynthesis.cancel();
            
            // Play attention sound before first announcement
            await playAttentionSound();
            
            // First full announcement
            await speakWithPacing(announcementText + ' ' + detailsText);
            
            // Short pause
            await new Promise(resolve => setTimeout(resolve, 1000));
            
            // Second announcement (with attention sound)
            await playAttentionSound();
            await speakWithPacing("Repeating announcement.");
            await speakWithPacing(repetitionText);
            
        } catch (error) {
            console.error("Error during announcement:", error);
        } finally {
            // Reset play button state
            if (playBtn) {
                playBtn.disabled = false;
                playBtn.innerHTML = '<svg class="w-4 h-4 mr-1 inline-block" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.752 11.168l-3.197-2.132A1 1 0 0010 9.87v4.263a1 1 0 001.555.832l3.197-2.132a1 1 0 000-1.664z"></path><path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path></svg> Play Announcement';
            }
        }
    };
    
    // Start the announcement
    runAnnouncement();
}

// Modify the showReportDetails function to include the play button
// Find the part of your showReportDetails function that builds modalContent 
// and add the play button after the details section

// Original showReportDetails function (modified to include play button)
const showReportDetails = (report) => {
    modalTitle.textContent = `${report.code_label} Report`;
    
    const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
    
    modalContent.innerHTML = `
        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
            <div>
                <p class="text-gray-500 text-sm">Report ID</p>
                <p class="font-medium text-blue-600">${formattedRefId}</p>
            </div>
            <div>
                <p class="text-gray-500 text-sm">Code</p>
                <p class="font-medium">${report.code_label}</p>
            </div>
            <div>
                <p class="text-gray-500 text-sm">Location</p>
                <p class="font-medium">${report.location}</p>
            </div>
            <div>
                <p class="text-gray-500 text-sm">Reported By</p>
                <p class="font-medium">${report.reported_by}</p>
            </div>
            <div>
                <p class="text-gray-500 text-sm">Time</p>
                <p class="font-medium">${formatDate(report.report_time)}</p>
            </div>
            <div>
                <p class="text-gray-500 text-sm">Status</p>
                <p class="font-medium">${getStatusBadge(report.status)}</p>
            </div>
            <div class="col-span-2">
                <p class="text-gray-500 text-sm">Details</p>
                <p class="font-medium">${report.details || 'No additional details provided'}</p>
            </div>
        </div>
        
        <div class="mt-4 pt-4 border-t border-gray-200">
            <button id="play-announcement-btn" class="bg-blue-500 hover:bg-blue-600 text-white px-3 py-2 rounded flex items-center" onclick="playEmergencyAnnouncement(${JSON.stringify(report)})">
                <svg class="w-4 h-4 mr-1" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.752 11.168l-3.197-2.132A1 1 0 0010 9.87v4.263a1 1 0 001.555.832l3.197-2.132a1 1 0 000-1.664z"></path><path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path></svg>
                Play Announcement
            </button>
        </div>
        
        <div class="mt-4 pt-4 border-t border-gray-200">
            <h4 class="font-bold mb-2">Status Notes</h4>
            <textarea id="status-notes" class="w-full px-3 py-2 border border-gray-300 rounded-md" 
                      rows="2" placeholder="Add notes about this status change (optional)"></textarea>
        </div>
    `;
    
    // Set current status in the dropdown
    statusUpdate.value = report.status;
    
    // Set report ID for the update button
    updateStatusBtn.setAttribute('data-report-id', report.id);
    
    // Show modal
    reportModal.classList.remove('hidden');
};

// Add this to the document ready function to ensure speech synthesis is initialized
document.addEventListener('DOMContentLoaded', function() {
    // ... your existing code ...
    
    // Initialize speech synthesis
    if ('speechSynthesis' in window) {
        // Load voices (needed for Chrome)
        window.speechSynthesis.getVoices();
        
        if (window.speechSynthesis.onvoiceschanged !== undefined) {
            window.speechSynthesis.onvoiceschanged = function() {
                console.log("Voices loaded: " + window.speechSynthesis.getVoices().length);
            };
        }
    } else {
        console.warn("This browser does not support the Speech Synthesis API");
    }
    
    // ... rest of your existing code ...
});