<?php
// /api/reports.php
require_once __DIR__.'/../db-connection.php';

session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    http_response_code(401);
    echo json_encode(['success' => false, 'error' => 'Unauthorized']);
    exit;
}

$userId = $_SESSION["user_id"] ?? 0;

// Handle status update
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_GET['action']) && $_GET['action'] === 'update_status') {
    header('Content-Type: application/json');
    
    try {
        // Validate input
        if (!isset($_POST['report_id']) || !isset($_POST['new_status'])) {
            throw new Exception('Missing required parameters');
        }
        
        $report_id = (int)$_POST['report_id'];
        $new_status = $_POST['new_status'];
        
        // Validate status
        $allowed_statuses = ['active', 'resolved', 'false_alarm'];
        if (!in_array($new_status, $allowed_statuses)) {
            throw new Exception('Invalid status value');
        }
        
        // Check if report belongs to this user
        $check_sql = "SELECT id FROM code_reports WHERE id = ? AND user_id = ?";
        $check_stmt = $pdo->prepare($check_sql);
        $check_stmt->execute([$report_id, $userId]);
        
        if ($check_stmt->rowCount() === 0) {
            throw new Exception('Report not found or not authorized');
        }
        
        // Update status
        $update_sql = "UPDATE code_reports SET status = ? WHERE id = ?";
        $update_stmt = $pdo->prepare($update_sql);
        $update_stmt->execute([$new_status, $report_id]);
        
        echo json_encode(['success' => true, 'message' => 'Status updated successfully']);
        
    } catch (Exception $e) {
        http_response_code(400);
        echo json_encode(['success' => false, 'error' => $e->getMessage()]);
    }
    exit;
}

// Handle GET requests for reports
if ($_SERVER['REQUEST_METHOD'] === 'GET' && isset($_GET['action']) && $_GET['action'] === 'get_reports') {
    header('Content-Type: application/json');
    
    try {
        $limit = isset($_GET['limit']) ? (int)$_GET['limit'] : 20;
        $offset = isset($_GET['offset']) ? (int)$_GET['offset'] : 0;
        $status = isset($_GET['status']) ? $_GET['status'] : null;
        
        // Validate parameters
        if ($limit > 100) $limit = 100;
        if ($limit < 1) $limit = 1;
        if ($offset < 0) $offset = 0;
        
        $idQuery = "SELECT DISTINCT id FROM code_reports WHERE user_id = ?";
        $idParams = [$userId];
        
        if ($status) {
            $idQuery .= " AND status = ?";
            $idParams[] = $status;
        }
        
        $idQuery .= " ORDER BY id DESC LIMIT ? OFFSET ?";
        $idParams[] = $limit;
        $idParams[] = $offset;
        
        $idStmt = $pdo->prepare($idQuery);
        $idStmt->execute($idParams);
        $ids = $idStmt->fetchAll(PDO::FETCH_COLUMN);
        
        if (empty($ids)) {
            echo json_encode([
                'success' => true,
                'reports' => [],
                'pagination' => [
                    'total' => 0,
                    'limit' => $limit,
                    'offset' => $offset,
                    'hasMore' => false
                ]
            ]);
            exit;
        }
        
        $placeholders = implode(',', array_fill(0, count($ids), '?'));
        
        $detailQuery = "
            SELECT 
                r.id,
                CONCAT('ECR-', LPAD(r.id, 6, '0')) AS formatted_reference_id,
                r.code_id,
                (SELECT label FROM emergency_codes WHERE code_value = r.code_id LIMIT 1) AS code_label,
                (SELECT description FROM emergency_codes WHERE code_value = r.code_id LIMIT 1) AS code_description,
                r.location_id AS location,
                r.reported_by,
                r.details,
                r.audio_file,
                DATE_FORMAT(r.report_timestamp, '%Y-%m-%d %H:%i:%s') AS report_time,
                r.status
            FROM code_reports r
            WHERE r.id IN ($placeholders)
            ORDER BY r.id DESC
        ";
        
        $detailStmt = $pdo->prepare($detailQuery);
        $detailStmt->execute($ids);
        $reports = $detailStmt->fetchAll(PDO::FETCH_ASSOC);
        
        $countQuery = "SELECT COUNT(DISTINCT id) FROM code_reports WHERE user_id = ?";
        $countParams = [$userId];
        
        if ($status) {
            $countQuery .= " AND status = ?";
            $countParams[] = $status;
        }
        
        $countStmt = $pdo->prepare($countQuery);
        $countStmt->execute($countParams);
        $totalCount = $countStmt->fetchColumn();
        
        echo json_encode([
            'success' => true,
            'reports' => $reports,
            'pagination' => [
                'total' => (int)$totalCount,
                'limit' => $limit,
                'offset' => $offset,
                'hasMore' => ($offset + $limit < $totalCount)
            ]
        ]);
        
    } catch (Exception $e) {
        error_log('Database Error: ' . $e->getMessage());
        http_response_code(500);
        echo json_encode(['success' => false, 'error' => 'Database error: ' . $e->getMessage()]);
    }
    exit;
}