<?php
// Start session to check authorization
session_start();

// Ensure the user is logged in
if(!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    header("HTTP/1.1 401 Unauthorized");
    echo json_encode(["success" => false, "message" => "Unauthorized"]);
    exit;
}

// Only process POST requests
if ($_SERVER["REQUEST_METHOD"] !== "POST") {
    header("HTTP/1.1 405 Method Not Allowed");
    echo json_encode(["success" => false, "message" => "Method not allowed"]);
    exit;
}

// Get the raw POST data
$json = file_get_contents('php://input');
$data = json_decode($json, true);

// Validate the data
if (!isset($data['subscription']) || !isset($data['userId'])) {
    header("HTTP/1.1 400 Bad Request");
    echo json_encode(["success" => false, "message" => "Missing required parameters"]);
    exit;
}

// Only allow a user to save subscriptions for themselves
// This prevents security issues where a user could register for notifications on another user's behalf
if ($data['userId'] != $_SESSION["user_id"]) {
    header("HTTP/1.1 403 Forbidden");
    echo json_encode(["success" => false, "message" => "Cannot save subscription for another user"]);
    exit;
}

// Include database connection
require_once "../db-connection.php";

try {
    // Check if subscription already exists for this user
    $checkSql = "SELECT id FROM push_subscriptions 
                WHERE user_id = ? AND endpoint = ?";
    $checkStmt = $pdo->prepare($checkSql);
    $checkStmt->execute([
        $data['userId'],
        $data['subscription']['endpoint']
    ]);
    
    if ($checkStmt->rowCount() > 0) {
        // Subscription exists, update it
        $row = $checkStmt->fetch();
        $updateSql = "UPDATE push_subscriptions 
                    SET auth = ?, p256dh = ?, updated_at = NOW() 
                    WHERE id = ?";
        $updateStmt = $pdo->prepare($updateSql);
        $updateStmt->execute([
            $data['subscription']['keys']['auth'],
            $data['subscription']['keys']['p256dh'],
            $row['id']
        ]);
    } else {
        // New subscription, insert it
        $insertSql = "INSERT INTO push_subscriptions 
                    (user_id, endpoint, auth, p256dh, created_at, updated_at) 
                    VALUES (?, ?, ?, ?, NOW(), NOW())";
        $insertStmt = $pdo->prepare($insertSql);
        $insertStmt->execute([
            $data['userId'],
            $data['subscription']['endpoint'],
            $data['subscription']['keys']['auth'],
            $data['subscription']['keys']['p256dh']
        ]);
    }
    
    // Return success response
    header('Content-Type: application/json');
    echo json_encode(["success" => true]);
    
} catch (PDOException $e) {
    // Log the error (to a file, not to response)
    error_log("Database error in save-subscription.php: " . $e->getMessage());
    
    // Return error response
    header("HTTP/1.1 500 Internal Server Error");
    echo json_encode(["success" => false, "message" => "Server error occurred"]);
}

// Close connection
unset($pdo);
?>