<?php
// Enable error reporting for debugging - remove in production
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start output buffering to catch any early output
ob_start();

// Start session
session_start();

// Diagnostic output
echo "<!-- Session info: " . json_encode($_SESSION) . " -->\n";

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
} else if ($_SESSION["role"] !== "admin") {
    // Redirect non-admin users
    echo "<script>window.location.href = 'index.php';</script>";
    exit;
}

// For API requests
if (isset($_GET['api']) && $_GET['api'] === 'true') {
    try {
        // Include database connection
        require_once 'db-connection.php';
        
        // Set response headers
        header('Content-Type: application/json');
        
        // Prepare query parameters
        $limit = isset($_GET['limit']) ? (int)$_GET['limit'] : 20;
        $offset = isset($_GET['offset']) ? (int)$_GET['offset'] : 0;
        $status = isset($_GET['status']) ? $_GET['status'] : null;
        
        // Validate parameters
        if ($limit > 100) $limit = 100; // Maximum 100 records per request
        if ($limit < 1) $limit = 1;     // Minimum 1 record
        if ($offset < 0) $offset = 0;   // No negative offset
        
        // Build simple query to test database
        $query = "SELECT COUNT(*) as count FROM code_reports";
        $stmt = $pdo->query($query);
        $count = $stmt->fetchColumn();
        
        // Return simple response to test API
        echo json_encode([
            'success' => true,
            'message' => 'Database connection successful',
            'count' => $count
        ]);
        
    } catch (Exception $e) {
        // Log the error (in a production environment)
        error_log('Database Error: ' . $e->getMessage());
        
        // Return error response
        http_response_code(500); // Internal Server Error
        echo json_encode([
            'error' => 'Failed to connect to database',
            'message' => $e->getMessage(),
            'success' => false
        ]);
    }
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Emergency Code Reports - Admin Panel</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Hospital Emergency Code Reports</h1>
            <div class="flex items-center space-x-4">
                <a href="user-manager.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Manage Users</a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"] ?? 'Admin'); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <div class="bg-white rounded-lg shadow p-6">
                <div class="flex justify-between items-center mb-6">
                    <h2 class="text-xl font-bold text-gray-800">Emergency Reports</h2>
                    <div class="flex space-x-2">
                        <a href="index.php" class="bg-red-500 hover:bg-red-600 text-white px-4 py-2 rounded">
                            New Report
                        </a>
                        <button id="refresh-btn" class="bg-blue-500 hover:bg-blue-600 text-white px-3 py-1 rounded">
                            Refresh
                        </button>
                    </div>
                </div>
                
                <div class="bg-yellow-100 border-l-4 border-yellow-500 text-yellow-700 p-4 mb-4">
                    <p>Debug Mode: This is a simplified version to help diagnose page loading issues.</p>
                    <p>Session Status: <?php echo isset($_SESSION["loggedin"]) ? "Logged in" : "Not logged in"; ?></p>
                    <p>User Role: <?php echo $_SESSION["role"] ?? "Not set"; ?></p>
                </div>
                
                <div id="test-api" class="mt-4 p-4 border border-gray-300 rounded">
                    <h3 class="font-bold mb-2">API Connection Test</h3>
                    <button id="test-api-btn" class="bg-green-500 hover:bg-green-600 text-white px-3 py-1 rounded">
                        Test API Connection
                    </button>
                    <div id="api-result" class="mt-2 p-2 bg-gray-100 rounded"></div>
                </div>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
    
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Test API connection
            document.getElementById('test-api-btn').addEventListener('click', async function() {
                const resultDiv = document.getElementById('api-result');
                resultDiv.innerHTML = 'Testing API connection...';
                
                try {
                    const response = await fetch('get-reports.php?api=true');
                    const result = await response.json();
                    
                    if (result.success) {
                        resultDiv.innerHTML = `
                            <div class="text-green-700">
                                Connection successful! Database has ${result.count} reports.
                            </div>
                        `;
                    } else {
                        resultDiv.innerHTML = `
                            <div class="text-red-700">
                                Error: ${result.error}<br>
                                Message: ${result.message}
                            </div>
                        `;
                    }
                } catch (error) {
                    resultDiv.innerHTML = `
                        <div class="text-red-700">
                            Failed to connect to API: ${error.message}
                        </div>
                    `;
                    console.error('API connection error:', error);
                }
            });
        });
    </script>
</body>
</html>
<?php
// Flush output buffer
ob_end_flush();
?>
