<?php
// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'error' => 'Unauthorized']);
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Get POST data
$input = json_decode(file_get_contents('php://input'), true);

// Check if report_id is provided
if (empty($input['report_id'])) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'error' => 'Report ID is required']);
    exit;
}

// Get report details from database
try {
    $reportId = (int)$input['report_id'];
    
    $query = "
        SELECT 
            r.id,
            e.label AS code_label,
            e.description AS code_description,
            r.location_id AS location,
            r.selected_building AS building,
            r.details,
            r.text_to_audio,
            DATE_FORMAT(r.report_timestamp, '%Y-%m-%d %H:%i:%s') AS report_time
        FROM 
            code_reports r
        JOIN 
            emergency_codes e ON r.code_id = e.code_value
        WHERE
            r.id = ?
    ";
    
    $stmt = $pdo->prepare($query);
    $stmt->execute([$reportId]);
    $report = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$report) {
        header('Content-Type: application/json');
        echo json_encode(['success' => false, 'error' => 'Report not found']);
        exit;
    }
    
    // Create AudioCodes directory if it doesn't exist
    $audioDir = 'AudioCodes';
    if (!is_dir($audioDir)) {
        mkdir($audioDir, 0755, true);
    }
    
    // Generate unique filename
    $filename = $audioDir . '/code_' . $reportId . '_' . date('Ymd_His') . '.mp3';
    
    // Use the text_to_audio field if available, otherwise generate it
    $announcementText = $report['text_to_audio'] ?? '';
    
    // If text_to_audio is empty, generate it
    if (empty($announcementText)) {
        $announcementText = "Attention all staff. " . $report['code_label'] . ". " . 
                        $report['code_description'] . ". " .
                        "Has been reported in " . $report['location'];
        
        // Add building if available
        if (!empty($report['building'])) {
            $announcementText .= " in the " . $report['building'];
        }
        
        // Add details if any
        if (!empty($report['details'])) {
            $announcementText .= ". Additional details: " . $report['details'] . ".";
        }
        
        // Repeat the announcement
        $announcementText .= " Repeating: " . $report['code_label'] . " in " . $report['location'];
        
        // Add building to repetition if available
        if (!empty($report['building'])) {
            $announcementText .= ", " . $report['building'];
        }
    }
    
    // Option 1: Using Google Cloud Text-to-Speech API (if available)
    // This would be the preferred method but requires API credentials
    $useGoogleTTS = false;
    
    if ($useGoogleTTS) {
        // This part would require the Google Cloud PHP client library
        // and proper API credentials set up
        // Code not included as it requires external dependencies
    } else {
        // Option 2: Using a command-line text-to-speech tool if available on server
        // Check for espeak, festival, or other TTS tools
        
        $ttsCommand = '';
        
        // Check if espeak is available
        exec("which espeak", $output, $returnVal);
        if ($returnVal === 0) {
            // Use espeak to generate MP3
            $escapedText = escapeshellarg($announcementText);
            $ttsCommand = "espeak $escapedText --stdout | ffmpeg -i - -ar 44100 -ac 2 -ab 192k -f mp3 $filename";
        } else {
            // Check if festival is available
            exec("which festival", $output, $returnVal);
            if ($returnVal === 0) {
                // Use festival to generate MP3
                $escapedText = escapeshellarg($announcementText);
                $tempWav = tempnam(sys_get_temp_dir(), 'tts_');
                $ttsCommand = "echo $escapedText | festival --tts --output=$tempWav && ffmpeg -i $tempWav -ar 44100 -ac 2 -ab 192k -f mp3 $filename && rm $tempWav";
            }
        }
        
        // If TTS command is available, execute it
        if (!empty($ttsCommand)) {
            exec($ttsCommand, $output, $returnVal);
            if ($returnVal !== 0) {
                // Command failed, fall back to option 3
                $ttsCommand = '';
            }
        }
        
        // Option 3: If server-side TTS options are not available,
        // create a text file with the announcement to be used client-side
        if (empty($ttsCommand)) {
            // Just save the text for client-side TTS
            $textFilename = $audioDir . '/code_' . $reportId . '_' . date('Ymd_His') . '.txt';
            file_put_contents($textFilename, $announcementText);
            
            // Return the text file path instead
            header('Content-Type: application/json');
            echo json_encode([
                'success' => true, 
                'audioType' => 'text',
                'textFile' => $textFilename,
                'text' => $announcementText,
                'reportId' => $reportId
            ]);
            exit;
        }
    }
    
    // Update the report with the audio file path and text_to_audio if it wasn't previously set
    $updateQuery = "UPDATE code_reports SET audio_file = ?, text_to_audio = CASE WHEN text_to_audio IS NULL OR text_to_audio = '' THEN ? ELSE text_to_audio END WHERE id = ?";
    $updateStmt = $pdo->prepare($updateQuery);
    $updateStmt->execute([$filename, $announcementText, $reportId]);
    
    // Return success response
    header('Content-Type: application/json');
    echo json_encode([
        'success' => true,
        'audioType' => 'file',
        'audioFile' => $filename,
        'reportId' => $reportId
    ]);
    
} catch (Exception $e) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'error' => 'Error generating audio: ' . $e->getMessage()
    ]);
}