/**
 * Duty Status JavaScript
 * 
 * This file contains client-side functionality for the duty status update page.
 * It handles form validation, UI updates, and interaction enhancements.
 */

document.addEventListener('DOMContentLoaded', function() {
    // Get form elements
    const dutyStatusForm = document.getElementById('duty-status-form');
    const dutyStatusSelect = document.getElementById('duty_status');
    const shiftSelect = document.getElementById('shift');
    const updateButton = document.getElementById('update-status-btn');
    const statusCards = document.querySelectorAll('.status-card');
    
    // Handle form submission
    if (dutyStatusForm) {
        dutyStatusForm.addEventListener('submit', function(e) {
            // Validate required fields
            if (!validateForm()) {
                e.preventDefault();
                return false;
            }
            
            // Show loading state on button
            if (updateButton) {
                updateButton.disabled = true;
                updateButton.innerHTML = '<svg class="animate-spin -ml-1 mr-2 h-4 w-4 text-white inline-block" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"><circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle><path class="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path></svg> Updating...';
            }
        });
    }
    
    // Form validation function
    function validateForm() {
        let isValid = true;
        let errorMessage = '';
        
        // Validate duty status
        if (!dutyStatusSelect || dutyStatusSelect.value === '') {
            errorMessage = 'Please select a duty status.';
            isValid = false;
        }
        
        // For certain statuses, require shift selection
        if (isValid && dutyStatusSelect && dutyStatusSelect.value === '1') { // Assuming 1 is OnDuty
            if (!shiftSelect || shiftSelect.value === '') {
                errorMessage = 'Please select a shift for On Duty status.';
                isValid = false;
            }
        }
        
        // Display error message if validation failed
        if (!isValid) {
            showMessage(errorMessage, 'error');
        }
        
        return isValid;
    }
    
    // Add dynamic behavior based on status selection
    if (dutyStatusSelect) {
        dutyStatusSelect.addEventListener('change', function() {
            // Make shift required for certain statuses (e.g., On Duty)
            if (this.value === '1') { // Assuming 1 is OnDuty status
                if (shiftSelect) {
                    shiftSelect.required = true;
                    shiftSelect.parentElement.classList.add('required-field');
                    shiftSelect.parentElement.querySelector('label').innerHTML = 'Select Shift: <span class="text-red-500">*</span>';
                }
            } else {
                if (shiftSelect) {
                    shiftSelect.required = false;
                    shiftSelect.parentElement.classList.remove('required-field');
                    shiftSelect.parentElement.querySelector('label').innerHTML = 'Select Shift:';
                }
            }
            
            // Preview the new status visually
            previewStatusChange(this.value);
        });
    }
    
    // Preview status change function
    function previewStatusChange(statusId) {
        // Find the status option text for display
        let statusText = '';
        if (dutyStatusSelect) {
            const selectedOption = dutyStatusSelect.options[dutyStatusSelect.selectedIndex];
            if (selectedOption) {
                statusText = selectedOption.text;
            }
        }
        
        // Update UI to preview selection
        statusCards.forEach(card => {
            if (statusId) {
                card.classList.add('preview-change');
                const previewEl = card.querySelector('.preview-status');
                if (previewEl) {
                    previewEl.textContent = `Preview: ${statusText}`;
                    previewEl.style.display = 'block';
                }
            } else {
                card.classList.remove('preview-change');
                const previewEl = card.querySelector('.preview-status');
                if (previewEl) {
                    previewEl.style.display = 'none';
                }
            }
        });
    }
    
    // Function to show status messages
    function showMessage(message, type = 'success') {
        // Create message element if it doesn't exist
        let messageEl = document.getElementById('status-message');
        if (!messageEl) {
            messageEl = document.createElement('div');
            messageEl.id = 'status-message';
            messageEl.role = 'alert';
            const container = document.querySelector('.container');
            if (container) {
                container.insertBefore(messageEl, container.firstChild);
            }
        }
        
        // Set message content and styling
        messageEl.textContent = message;
        messageEl.className = type === 'error' 
            ? 'bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4' 
            : 'bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4';
        
        // Auto-hide message after 5 seconds
        setTimeout(() => {
            messageEl.style.display = 'none';
        }, 5000);
    }
    
    // Format dates in the status history table
    formatDatesInTable();
    
    // Function to format dates in a more readable way
    function formatDatesInTable() {
        const timestampCells = document.querySelectorAll('.status-history-table td:nth-child(3)');
        timestampCells.forEach(cell => {
            const timestamp = cell.textContent;
            if (timestamp) {
                try {
                    const date = new Date(timestamp);
                    const formatted = date.toLocaleString();
                    cell.textContent = formatted;
                    cell.title = 'Original timestamp: ' + timestamp;
                } catch (e) {
                    // Keep original format if parsing fails
                    console.error('Error formatting date:', e);
                }
            }
        });
    }
    
    // Handle tab behavior for mobile support
    setupTabBehavior();
    
    // Function to set up tab behavior
    function setupTabBehavior() {
        const tabButtons = document.querySelectorAll('.tab-button');
        const tabContents = document.querySelectorAll('.tab-content');
        
        tabButtons.forEach(button => {
            button.addEventListener('click', function() {
                const tabId = this.getAttribute('data-tab');
                
                // Deactivate all tabs
                tabButtons.forEach(btn => btn.classList.remove('active-tab'));
                tabContents.forEach(content => content.classList.add('hidden'));
                
                // Activate selected tab
                this.classList.add('active-tab');
                document.getElementById(tabId).classList.remove('hidden');
            });
        });
    }
});