/**
 * Emergency Codes Management JavaScript
 * Handles the interactive functionality for adding, editing, and previewing emergency codes
 */

// Initialize preview when page loads
document.addEventListener('DOMContentLoaded', function() {
    // Update initial preview
    updatePreview();

    // Setup event listeners
    setupEventListeners();
});

/**
 * Setup all event listeners
 */
function setupEventListeners() {
    // Add form preview
    document.getElementById('bg_color').addEventListener('input', updatePreview);
    document.getElementById('text_color').addEventListener('input', updatePreview);
    document.getElementById('label').addEventListener('input', updatePreview);
    document.getElementById('description').addEventListener('input', updatePreview);
    document.getElementById('arabic_text').addEventListener('input', updatePreview);
    document.getElementById('bg_color_picker').addEventListener('input', function() {
        document.getElementById('bg_color').value = this.value;
        updatePreview();
    });
    document.getElementById('text_color_picker').addEventListener('input', function() {
        document.getElementById('text_color').value = this.value;
        updatePreview();
    });
    
    // Edit form preview
    document.getElementById('edit_bg_color').addEventListener('input', updateEditPreview);
    document.getElementById('edit_text_color').addEventListener('input', updateEditPreview);
    document.getElementById('edit_label').addEventListener('input', updateEditPreview);
    document.getElementById('edit_description').addEventListener('input', updateEditPreview);
    document.getElementById('edit_arabic_text').addEventListener('input', updateEditPreview);
    document.getElementById('edit_bg_color_picker').addEventListener('input', function() {
        document.getElementById('edit_bg_color').value = this.value;
        updateEditPreview();
    });
    document.getElementById('edit_text_color_picker').addEventListener('input', function() {
        document.getElementById('edit_text_color').value = this.value;
        updateEditPreview();
    });
    
    // Close modal when clicking outside or pressing escape
    const modal = document.getElementById('editModal');
    if (modal) {
        modal.addEventListener('click', function(event) {
            if (event.target === modal) {
                closeEditModal();
            }
        });
    }
    
    document.addEventListener('keydown', function(event) {
        if (event.key === 'Escape') {
            closeEditModal();
        }
    });
    
    // Setup delete confirmation
    setupDeleteConfirmation();
}

/**
 * Update the preview based on form inputs for the add form
 */
function updatePreview() {
    const bgColor = document.getElementById('bg_color').value;
    const textColor = document.getElementById('text_color').value;
    const label = document.getElementById('label').value || 'CODE LABEL';
    const description = document.getElementById('description').value || 'Description';
    const arabicText = document.getElementById('arabic_text').value || '';
    
    const preview = document.getElementById('code_preview');
    preview.style.backgroundColor = bgColor;
    preview.style.color = textColor;
    
    document.getElementById('label_preview').textContent = label;
    document.getElementById('description_preview').textContent = description;
    document.getElementById('arabic_preview').textContent = arabicText;
}

/**
 * Update the preview based on form inputs for the edit form
 */
function updateEditPreview() {
    const bgColor = document.getElementById('edit_bg_color').value;
    const textColor = document.getElementById('edit_text_color').value;
    const label = document.getElementById('edit_label').value || 'CODE LABEL';
    const description = document.getElementById('edit_description').value || 'Description';
    const arabicText = document.getElementById('edit_arabic_text').value || '';
    
    const preview = document.getElementById('edit_code_preview');
    preview.style.backgroundColor = bgColor;
    preview.style.color = textColor;
    
    document.getElementById('edit_label_preview').textContent = label;
    document.getElementById('edit_description_preview').textContent = description;
    document.getElementById('edit_arabic_preview').textContent = arabicText;
}

/**
 * Open the edit modal and populate with code data
 * @param {Object} code - The emergency code data
 */
function openEditModal(code) {
    // Set values in the edit form
    document.getElementById('edit_code_id').value = code.id;
    document.getElementById('edit_code_value').value = code.code_value;
    document.getElementById('edit_label').value = code.label;
    document.getElementById('edit_description').value = code.description;
    document.getElementById('edit_arabic_text').value = code.arabic_text;
    document.getElementById('edit_bg_color').value = code.bg_color;
    document.getElementById('edit_text_color').value = code.text_color;
    document.getElementById('edit_priority').value = code.priority;
    
    // Update color pickers
    document.getElementById('edit_bg_color_picker').value = code.bg_color;
    document.getElementById('edit_text_color_picker').value = code.text_color;
    
    // Update preview
    updateEditPreview();
    
    // Show the modal
    document.getElementById('editModal').classList.remove('hidden');
}

/**
 * Close the edit modal
 */
function closeEditModal() {
    document.getElementById('editModal').classList.add('hidden');
}

/**
 * Setup confirmation for delete operations
 */
function setupDeleteConfirmation() {
    // Find all delete buttons
    const deleteButtons = document.querySelectorAll('button[name="delete_code"]');
    
    // Add confirmation to each
    deleteButtons.forEach(button => {
        button.addEventListener('click', function(event) {
            if (!confirm('Are you sure you want to delete this emergency code? This action cannot be undone.')) {
                event.preventDefault();
            }
        });
    });
}

/**
 * Validate the form before submission
 * @param {HTMLFormElement} form - The form to validate
 * @returns {boolean} - Whether the form is valid
 */
function validateForm(form) {
    let isValid = true;
    
    // Required fields
    const requiredFields = ['code_value', 'label', 'description'];
    
    requiredFields.forEach(fieldName => {
        const field = form.elements[fieldName];
        if (!field.value.trim()) {
            highlightError(field);
            isValid = false;
        } else {
            removeErrorHighlight(field);
        }
    });
    
    // Validate color formats
    const colorFields = ['bg_color', 'text_color'];
    const colorRegex = /^(#[0-9A-Fa-f]{3}|#[0-9A-Fa-f]{6}|[a-zA-Z]+)$/;
    
    colorFields.forEach(fieldName => {
        const field = form.elements[fieldName];
        if (!colorRegex.test(field.value.trim())) {
            highlightError(field);
            isValid = false;
        } else {
            removeErrorHighlight(field);
        }
    });
    
    return isValid;
}

/**
 * Highlight form field with error
 * @param {HTMLElement} field - The field with error
 */
function highlightError(field) {
    field.classList.add('border-red-500');
    
    // Add error message if it doesn't exist yet
    const errorId = `${field.id}-error`;
    if (!document.getElementById(errorId)) {
        const errorMsg = document.createElement('p');
        errorMsg.id = errorId;
        errorMsg.className = 'text-red-500 text-xs mt-1';
        errorMsg.textContent = 'This field is required';
        field.parentNode.appendChild(errorMsg);
    }
}

/**
 * Remove error highlighting from field
 * @param {HTMLElement} field - The field to remove error from
 */
function removeErrorHighlight(field) {
    field.classList.remove('border-red-500');
    
    // Remove error message if it exists
    const errorId = `${field.id}-error`;
    const errorMsg = document.getElementById(errorId);
    if (errorMsg) {
        errorMsg.remove();
    }
}