// Main Emergency Code Reporter Component - ES5 Compatible Version

// Define component - Get user info from the global variables properly
function EmergencyCodeReporter() {
  // Access user info from the global variables defined in index.php
  // Improved access to user information with better fallbacks
  var userInfo = window.userInfo || {};
  var userId = userInfo.userId || '';
  
  // Enhanced fullname resolution with multiple fallbacks
  var fullname = '';
  
  // Try multiple sources to get the user's full name
  if (userInfo.fullname) {
    // First try direct access from window.userInfo
    fullname = userInfo.fullname;
  } else if (typeof PHP_USER_FULLNAME !== 'undefined' && PHP_USER_FULLNAME) {
    // Try global variable that might be set directly by PHP
    fullname = PHP_USER_FULLNAME;
  } else {
    // Last resort fallback
    fullname = 'Current User';
  }

  var userRole = userInfo.role || '';
  var requestId = window.currentRequestId || '';

  var formDataState = React.useState({
    codeType: '',
    location: '',
    selectedBuilding: '',
    reportedBy: fullname, // Pre-fill with user's full name
    details: ''
  });
  var formData = formDataState[0];
  var setFormData = formDataState[1];
  
  var isSubmittingState = React.useState(false);
  var isSubmitting = isSubmittingState[0];
  var setIsSubmitting = isSubmittingState[1];
  
  var submitSuccessState = React.useState(false);
  var submitSuccess = submitSuccessState[0];
  var setSubmitSuccess = submitSuccessState[1];
  
  var errorState = React.useState('');
  var error = errorState[0];
  var setError = errorState[1];
  
  var audioContextState = React.useState(null);
  var audioContext = audioContextState[0];
  var setAudioContext = audioContextState[1];

  // Add debug logging for user information
  React.useEffect(function() {
    // Log detailed information about user data sources
    console.log('Component mounted with:', {
      'window.userInfo': window.userInfo,
      'userInfo object': userInfo,
      'resolved fullname': fullname,
      'resolved userId': userId,
      'resolved userRole': userRole,
      'form data': formData
    });
    
    // If user name is not correctly loaded, check the DOM for username elements
    if (!fullname || fullname === 'Current User' || fullname === 'Unknown User') {
      console.warn('Could not get user name from standard sources, trying DOM...');
      
      // Try to find elements that might contain the username
      var usernameElements = document.querySelectorAll('.username, #username, [data-username], .user-name, #user-name');
      if (usernameElements.length > 0) {
        console.log('Found potential username elements:', usernameElements);
        
        // Try to extract username from the first match
        var extractedName = usernameElements[0].textContent || usernameElements[0].getAttribute('data-username');
        if (extractedName && extractedName.trim()) {
          console.log('Found username in DOM:', extractedName);
          
          // Update the form data with the extracted name
          setFormData(function(prev) {
            var newData = {};
            for(var key in prev) {
              newData[key] = prev[key];
            }
            newData.reportedBy = extractedName.trim();
            return newData;
          });
          
          // Update local fullname variable for consistency
          fullname = extractedName.trim();
        }
      }
    }
  }, []);

  var emergencyCodes = [
    { 
      value: 'code-red', 
      label: 'CODE RED', 
      description: 'Fire',
      arabicText: 'حريق',
      bgColor: '#FF3333', 
      textColor: 'white' 
    },
    { 
      value: 'code-yellow', 
      label: 'CODE YELLOW', 
      description: 'External Disaster',
      arabicText: 'الكوارث الخارجية',
      bgColor: '#FFDC46', 
      textColor: 'black' 
    },
    { 
      value: 'code-black', 
      label: 'CODE BLACK', 
      description: 'BOMB THREAT',
      arabicText: 'التهديد بزرع قنبلة',
      bgColor: '#000000', 
      textColor: 'white' 
    },
    { 
      value: 'code-orange', 
      label: 'CODE ORANGE', 
      description: 'Chemical, Radioactive, Biological Spill',
      arabicText: 'تسرب بيولوجي،كيميائي،إشعاعي',
      bgColor: '#FF9966', 
      textColor: 'white' 
    }
  ];

  var locations = [
    'Emergency Room',
    'ICU',
    'Surgery Center',
    'Pediatrics',
    'Radiology',
    'Laboratory',
    'Cafeteria',
    'Administration',
    'Main Entrance',
    'Parking Garage'
  ];

  var buildings = [
    'Main Hospital Building',
    'Emergency Department',
    'Outpatient Clinic',
    'Surgical Center',
    'Administrative Building',
    'Research Wing'
  ];

  // Handle form field changes
  function handleChange(e) {
    var name = e.target.name;
    var value = e.target.value;
    
    setFormData(function(prev) {
      var newData = {};
      for(var key in prev) {
        newData[key] = prev[key];
      }
      newData[name] = value;
      return newData;
    });
  }

  // Initialize audio context on user interaction
  function initializeAudioContext() {
    if (!audioContext) {
      try {
        var AudioContextClass = window.AudioContext || window.webkitAudioContext;
        var newContext = new AudioContextClass();
        setAudioContext(newContext);
        console.log("Audio context initialized:", newContext);
        return newContext;
      } catch (e) {
        console.error("Failed to initialize AudioContext:", e);
        return null;
      }
    }
    return audioContext;
  }

  // Ensure audio context is running (needed for mobile)
  async function ensureAudioContextRunning(context) {
    if (context && context.state !== 'running') {
      try {
        await context.resume();
        console.log('AudioContext resumed successfully');
      } catch (e) {
        console.error('Failed to resume AudioContext:', e);
      }
    }
  }

  // Generate text for audio announcement
  function generateAnnouncementText() {
    var selectedCode = null;
    for (var i = 0; i < emergencyCodes.length; i++) {
      if (emergencyCodes[i].value === formData.codeType) {
        selectedCode = emergencyCodes[i];
        break;
      }
    }
    
    var codeLabel = selectedCode ? selectedCode.label : 'Emergency Code';
    
    var textToAudio = codeLabel + " ";
    
    if (formData.selectedBuilding) {
      textToAudio += formData.selectedBuilding + " ";
    }
    
    textToAudio += formData.location + " ";
    
    if (formData.details) {
      textToAudio += formData.details;
    }
    
    return textToAudio;
  }

  // Play the announcement
  async function playAnnouncementAudio() {
    try {
      var ctx = initializeAudioContext();
      if (!ctx) {
        console.warn("No audio context available");
        return;
      }
      
      await ensureAudioContextRunning(ctx);
      
      // Get the announcement text
      var text = generateAnnouncementText();
      console.log("Announcement text:", text);
      
      // Use browser's speech synthesis if available
      if ('speechSynthesis' in window) {
        // Cancel any ongoing speech
        window.speechSynthesis.cancel();
        
        // Create a speech synthesis utterance
        var speech = new SpeechSynthesisUtterance(text);
        speech.rate = 0.9; // slightly slower for clarity
        speech.volume = 1.0;
        
        // Try to get a good voice
        var voices = window.speechSynthesis.getVoices();
        var englishVoice = null;
        
        for (var i = 0; i < voices.length; i++) {
          if (voices[i].lang.startsWith('en') && voices[i].name.includes('Male')) {
            englishVoice = voices[i];
            break;
          }
        }
        
        if (!englishVoice) {
          for (var i = 0; i < voices.length; i++) {
            if (voices[i].lang.startsWith('en')) {
              englishVoice = voices[i];
              break;
            }
          }
        }
        
        if (!englishVoice && voices.length > 0) {
          englishVoice = voices[0];
        }
        
        if (englishVoice) {
          speech.voice = englishVoice;
        }
        
        // Speak the text
        window.speechSynthesis.speak(speech);
      } else {
        console.warn("Speech synthesis not available in this browser");
      }
      
      // Also play an attention tone
      try {
        var oscillator = ctx.createOscillator();
        var gainNode = ctx.createGain();
        
        oscillator.type = 'sine';
        oscillator.frequency.setValueAtTime(880, ctx.currentTime); // A5 note
        
        gainNode.gain.setValueAtTime(0, ctx.currentTime);
        gainNode.gain.linearRampToValueAtTime(0.3, ctx.currentTime + 0.1);
        gainNode.gain.linearRampToValueAtTime(0, ctx.currentTime + 0.8);
        
        oscillator.connect(gainNode);
        gainNode.connect(ctx.destination);
        
        oscillator.start();
        oscillator.stop(ctx.currentTime + 0.9);
      } catch (e) {
        console.error("Error playing attention sound:", e);
      }
    } catch (e) {
      console.error("Error in playAnnouncementAudio:", e);
    }
  }

  // Submit data to the server
  async function submitToDatabase() {
    try {
      console.log("Submitting form data:", formData);
      
      // Generate text for audio announcement
      var textToAudio = generateAnnouncementText();
      
      // Get client's local date and time (Riyadh time)
      var now = new Date();
      var localDateString = now.toLocaleString('en-US', { 
        timeZone: 'Asia/Riyadh',
        year: 'numeric',
        month: '2-digit',
        day: '2-digit',
        hour: '2-digit',
        minute: '2-digit',
        second: '2-digit',
        hour12: false
      });
      
      // Prepare data for submission
      var data = {
        codeType: formData.codeType,
        location: formData.location,
        selectedBuilding: formData.selectedBuilding,
        reportedBy: formData.reportedBy,
        details: formData.details,
        textToAudio: textToAudio,
        localTimestamp: localDateString,
        clientTimezone: 'Asia/Riyadh',
        requestId: requestId
      };
      
      console.log("Sending data to server:", data);
      
      // Send the data to our PHP backend
      var response = await fetch('save-report.php', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify(data)
      });
      
      console.log("Server response status:", response.status);
      
      // Get the raw response text first for debugging
      var responseText = await response.text();
      console.log("Raw server response:", responseText);
      
      // Parse the JSON response (might fail if invalid JSON)
      var result;
      try {
        result = JSON.parse(responseText);
      } catch (e) {
        console.error("Error parsing JSON response:", e);
        throw new Error("Invalid response from server: " + responseText.substring(0, 100));
      }
      
      // Check if the request was successful
      if (!response.ok) {
        throw new Error(result.message || 'Failed to save report to database');
      }
      
      console.log('Report saved with ID:', result.reportId);
      return result;
    } catch (error) {
      console.error('Error submitting report:', error);
      throw error;
    }
  }

  // Handle redirects based on user role
  function handleRedirect(reportId) {
    console.log("Handling redirect for role:", userRole, "Report ID:", reportId);
    
    // Store report details in sessionStorage for thank you page
    var reportDetails = {
      id: reportId,
      codeType: formData.codeType,
      location: formData.location,
      building: formData.selectedBuilding,
      details: formData.details,
      timestamp: new Date().toISOString()
    };
    sessionStorage.setItem('lastReport', JSON.stringify(reportDetails));
    
    // Admin users go to the reports list page
    if (userRole === 'admin') {
      // Brief delay to allow announcement to play
      setTimeout(function() {
        window.location.href = 'get-reports.php';
      }, 3000);
    } else {
      // Other users go to the thank you page
      setTimeout(function() {
        window.location.href = 'thank-you.php';
      }, 3000);
    }
  }

  // Handle form submission
  async function handleSubmit(e) {
    e.preventDefault();
    setIsSubmitting(true);
    setError('');
    
    // Enhanced validation for all required fields
    if (!formData.codeType) {
      setError('Please select an emergency code type');
      setIsSubmitting(false);
      return;
    }
    
    if (!formData.location) {
      setError('Please select a location');
      setIsSubmitting(false);
      return;
    }
    
    if (!formData.selectedBuilding) {
      setError('Please select a building');
      setIsSubmitting(false);
      return;
    }
    
    if (!formData.reportedBy) {
      setError('Reporter name is missing');
      setIsSubmitting(false);
      return;
    }
    
    if (!formData.details || formData.details.trim() === '') {
      setError('Please provide additional details about the emergency');
      setIsSubmitting(false);
      return;
    }
    
    try {
      // Initialize audio for mobile
      if (!audioContext) {
        initializeAudioContext();
      }
      
      // Submit data to database
      var result = await submitToDatabase();
      
      if (result.success) {
        // Show success state
        setSubmitSuccess(true);
        
        // Play the announcement
        try {
          await playAnnouncementAudio();
        } catch (audioErr) {
          console.error("Error playing announcement:", audioErr);
        }
        
        // Handle redirect based on user role
        handleRedirect(result.reportId);
      } else {
        setError(result.message || 'Unknown error occurred');
      }
    } catch (err) {
      console.error("Submission error:", err);
      setError(err.message || 'Failed to submit the emergency code. Please try again.');
    } finally {
      setIsSubmitting(false);
    }
  }

  // Render using React.createElement - NO JSX
  return React.createElement(
    'div', 
    { className: 'flex flex-col min-h-screen bg-gray-100' },
    React.createElement(
      'main', 
      { className: 'flex-grow p-4' },
      submitSuccess ? 
        // Success message
        React.createElement(
          'div', 
          { className: 'bg-green-100 border border-green-400 text-green-700 px-4 py-3 rounded relative mb-4' },
          React.createElement('strong', { className: 'font-bold' }, 'Success!'),
          React.createElement('span', { className: 'block sm:inline' }, ' Emergency code has been reported and announced.'),
          React.createElement(
            'div', 
            { className: 'mt-2' },
            React.createElement('p', null, 'Redirecting you ', userRole === 'admin' ? 'to reports page' : 'to confirmation page', '...'),
            React.createElement(
              'div', 
              { className: 'mt-2 w-full h-2 bg-gray-200 rounded-full overflow-hidden' },
              React.createElement('div', { className: 'bg-green-500 h-full animate-pulse', style: {width: '100%'} })
            )
          )
        ) : 
        // Form
        React.createElement(
          'div', 
          { className: 'bg-white rounded-lg shadow-md p-6' },
          // Code selection section
          React.createElement(
            'div', 
            { className: 'mb-6' },
            React.createElement(
              'div', 
              { className: 'mb-4' },
              React.createElement(
                'h2', 
                { className: 'text-xl font-bold flex items-center' },
                React.createElement('span', { className: 'bg-blue-500 text-white rounded-full w-6 h-6 inline-flex items-center justify-center mr-2' }, '1'),
                React.createElement('span', null, 'Code')
              )
            ),
            // Emergency codes grid - Always show all codes, but highlight the selected one
            React.createElement(
              'div', 
              { className: 'grid grid-cols-1 md:grid-cols-2 gap-4' },
              emergencyCodes.map(function(code, index) {
                var letter = String.fromCharCode(65 + index);
                var isSelected = formData.codeType === code.value;
                
                return React.createElement(
                  'div',
                  {
                    key: code.value,
                    className: 'border rounded-md overflow-hidden cursor-pointer ' + (isSelected ? 'ring-2 ring-blue-500' : ''),
                    onClick: function() {
                      setFormData(function(prev) {
                        var newData = {};
                        for(var key in prev) {
                          newData[key] = prev[key];
                        }
                        // If already selected, clicking again doesn't deselect
                        newData.codeType = code.value;
                        return newData;
                      });
                    }
                  },
                  React.createElement(
                    'div',
                    {
                      className: 'p-4 text-center flex flex-col items-center justify-center ' + (isSelected ? 'opacity-100' : formData.codeType ? 'opacity-50' : 'opacity-100'),
                      style: { 
                        backgroundColor: code.bgColor, 
                        color: code.textColor,
                        height: '260px'
                      }
                    },
                    React.createElement('div', { className: 'text-xl font-semibold mb-2 arabic-text', style: { fontSize: '20px' } }, code.arabicText),
                    React.createElement('div', { className: 'text-6xl font-bold my-3' }, code.label.split(' ')[1]),
                    React.createElement('div', { className: 'text-xl' }, code.description)
                  ),
                  React.createElement(
                    'div', 
                    { className: 'bg-gray-100 px-4 py-2' },
                    React.createElement(
                      'div', 
                      { className: 'flex items-center justify-between' },
                      React.createElement(
                        'div',
                        { className: 'flex items-center' },
                        React.createElement('span', { className: 'inline-flex items-center justify-center border border-gray-400 rounded-full w-6 h-6 mr-2' }, letter),
                        React.createElement('span', { className: 'font-bold' }, code.label)
                      ),
                      isSelected && React.createElement(
                        'div',
                        { className: 'bg-blue-500 text-white px-2 py-1 rounded-full text-xs' },
                        'Selected'
                      )
                    )
                  )
                );
              })
            )
          ),
          
          // Form inputs
          React.createElement(
            'form', 
            { onSubmit: handleSubmit },
            React.createElement('input', {
              type: 'hidden',
              name: 'codeType',
              value: formData.codeType,
              required: true
            }),
            
            // Location field
            React.createElement(
              'div', 
              { className: 'mb-4' },
              React.createElement('label', { className: 'block text-gray-700 font-bold mb-2', htmlFor: 'location' }, 'Location *'),
              React.createElement(
                'select',
                {
                  id: 'location',
                  name: 'location',
                  value: formData.location,
                  onChange: handleChange,
                  required: true,
                  className: 'w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500'
                },
                React.createElement('option', { value: '' }, 'Select Location'),
                locations.map(function(location) {
                  return React.createElement('option', { key: location, value: location }, location);
                })
              )
            ),
            
            // Building field (required)
            React.createElement(
              'div', 
              { className: 'mb-4' },
              React.createElement('label', { className: 'block text-gray-700 font-bold mb-2', htmlFor: 'selectedBuilding' }, 'Building *'),
              React.createElement(
                'select',
                {
                  id: 'selectedBuilding',
                  name: 'selectedBuilding',
                  value: formData.selectedBuilding,
                  onChange: handleChange,
                  required: true,
                  className: 'w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500'
                },
                React.createElement('option', { value: '' }, 'Select Building'),
                buildings.map(function(building) {
                  return React.createElement('option', { key: building, value: building }, building);
                })
              )
            ),
            
            // Reported By field - visible but uneditable, autofilled with logged-in user's name
            React.createElement(
              'div', 
              { className: 'mb-4' },
              React.createElement('label', { className: 'block text-gray-700 font-bold mb-2', htmlFor: 'reportedBy' }, 'Reported By *'),
              // Hidden field with the actual value to be submitted
              React.createElement('input', {
                id: 'reportedBy',
                name: 'reportedBy',
                type: 'hidden',
                value: formData.reportedBy,
                required: true,
              }),
              // Read-only display field
              React.createElement('input', {
                type: 'text',
                value: fullname || 'Unknown User',
                readOnly: true,
                disabled: true,
                className: 'w-full px-3 py-2 border border-gray-300 bg-gray-100 rounded-md cursor-not-allowed',
                title: 'This field is automatically filled with your name',
                'aria-label': 'Reporter name (automatically filled)'
              })
            ),
            
            // Details field (required)
            React.createElement(
              'div', 
              { className: 'mb-6' },
              React.createElement('label', { className: 'block text-gray-700 font-bold mb-2', htmlFor: 'details' }, 'Additional Details *'),
              React.createElement('textarea', {
                id: 'details',
                name: 'details',
                value: formData.details,
                onChange: handleChange,
                required: true,
                className: 'w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500',
                rows: '3',
                placeholder: 'Enter any additional details about the emergency (required)'
              })
            ),
            
            // Error message
            error && React.createElement(
              'div', 
              { className: 'bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative mb-4' },
              React.createElement('span', { className: 'block sm:inline' }, error)
            ),
            
            // Submit button
            React.createElement(
              'div', 
              { className: 'flex items-center justify-center' },
              React.createElement(
                'button',
                {
                  type: 'submit',
                  disabled: isSubmitting,
                  className: 'bg-red-600 hover:bg-red-700 text-white font-bold py-3 px-6 rounded-full focus:outline-none focus:shadow-outline w-full max-w-xs ' + (isSubmitting ? 'opacity-50 cursor-not-allowed' : '')
                }, 
                isSubmitting ? 'Submitting...' : 'REPORT EMERGENCY CODE'
              )
            )
          )
        )
    )
  );
}

// Wait for the DOM to be fully loaded
document.addEventListener('DOMContentLoaded', function() {
  console.log('DOM loaded - initializing emergency reporter');
  
  // Make sure the root element exists
  var rootElement = document.getElementById('root');
  if (rootElement) {
    console.log('Root element found, rendering EmergencyCodeReporter component');
    
    // Check if userInfo is available
    if (window.userInfo) {
      console.log('userInfo found:', window.userInfo);
    } else {
      console.warn('userInfo not found in window object');
    }
    
    // Render the component with a try-catch to handle errors
    try {
      ReactDOM.render(
        React.createElement(EmergencyCodeReporter, null),
        rootElement
      );
      console.log('EmergencyCodeReporter rendered successfully');
    } catch (error) {
      console.error('Error rendering React component:', error);
      rootElement.innerHTML = 
        '<div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative">' +
          '<strong class="font-bold">Error!</strong>' +
          '<span class="block sm:inline"> Failed to load the form. Please try refreshing the page.</span>' +
          '<p class="mt-2">Error details: ' + error.message + '</p>' +
        '</div>';
    }
  } else {
    console.error('Root element not found in the DOM');
  }
});