<?php
// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true || $_SESSION["role"] !== "admin") {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Define variables
$error_message = "";
$success_message = "";

// Process user duty status and shift update
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    try {
        // Begin transaction
        $pdo->beginTransaction();
        
        // Prepare update statement
        $update_sql = "UPDATE users SET duty_status_id = ?, duty_shift = ? WHERE id = ?";
        $update_stmt = $pdo->prepare($update_sql);
        
        // Prepare log statement
        $log_sql = "INSERT INTO status_logs (user_id, status_change, notes, change_timestamp) 
                    VALUES (?, ?, ?, NOW())";
        $log_stmt = $pdo->prepare($log_sql);
        
        // Prepare status name retrieval
        $status_query = "SELECT status_name FROM duty_status WHERE id = ?";
        $status_stmt = $pdo->prepare($status_query);
        
        // Process each user update
        $updates = $_POST['updates'] ?? [];
        $successful_updates = 0;
        
        foreach ($updates as $update) {
            $user_id = (int)$update['user_id'];
            $duty_status_id = (int)$update['duty_status_id'];
            $duty_shift = $update['duty_shift'] ?? null;
            
            // Execute user update
            $update_stmt->execute([$duty_status_id, $duty_shift, $user_id]);
            
            // Retrieve status name
            $status_stmt->execute([$duty_status_id]);
            $status_name = $status_stmt->fetchColumn();
            
            // Log the status change
            $log_stmt->execute([
                $user_id, 
                "Changed to $status_name ($duty_shift)", 
                "Status updated by admin: {$_SESSION['fullname']}"
            ]);
            
            $successful_updates++;
        }
        
        // Commit transaction
        $pdo->commit();
        
        $success_message = "$successful_updates user(s) updated successfully.";
    } catch (PDOException $e) {
        // Rollback transaction
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        
        $error_message = "Error updating users: " . $e->getMessage();
    }
}

// Get duty statuses for the dropdown
try {
    $duty_statuses_query = "SELECT id, status_name, description FROM duty_status ORDER BY id";
    $duty_statuses_stmt = $pdo->query($duty_statuses_query);
    $duty_statuses = $duty_statuses_stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = "Error fetching duty statuses: " . $e->getMessage();
    $duty_statuses = [];
}

// Get all users with their current duty status
try {
    $users_query = "
        SELECT 
            u.id, 
            u.username, 
            u.fullname, 
            u.email, 
            u.role, 
            u.last_login, 
            u.created_at, 
            u.active,
            ds.id AS current_duty_status_id,
            ds.status_name AS current_duty_status,
            u.duty_shift
        FROM 
            users u
        LEFT JOIN 
            duty_status ds ON u.duty_status_id = ds.id
        ORDER BY 
            u.created_at DESC
    ";
    $users_stmt = $pdo->query($users_query);
    $users = $users_stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = "Could not fetch users: " . $e->getMessage();
    $users = [];
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>User Management - Emergency Code System</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">User Management</h1>
            <div class="flex items-center space-x-4">
                <a href="get-reports.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Back to Reports</a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"]); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <?php if(!empty($error_message)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
                    <p><?php echo $error_message; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if(!empty($success_message)): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4" role="alert">
                    <p><?php echo $success_message; ?></p>
                </div>
            <?php endif; ?>
            
            <form method="post" id="userUpdateForm">
                <div class="bg-white rounded-lg shadow-md overflow-hidden">
                    <h2 class="text-xl font-bold p-6 bg-gray-50 border-b">User List</h2>
                    
                    <div class="overflow-x-auto">
                        <table class="min-w-full divide-y divide-gray-200">
                            <thead class="bg-gray-50">
                                <tr>
                                    <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Username</th>
                                    <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Name</th>
                                    <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Duty Status</th>
                                    <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Duty Shift</th>
                                </tr>
                            </thead>
                            <tbody class="bg-white divide-y divide-gray-200">
                                <?php foreach ($users as $user): ?>
                                <tr>
                                    <input type="hidden" name="updates[<?php echo $user['id']; ?>][user_id]" value="<?php echo $user['id']; ?>">
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <?php echo htmlspecialchars($user['username']); ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <?php echo htmlspecialchars($user['fullname']); ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <select name="updates[<?php echo $user['id']; ?>][duty_status_id]" class="w-full px-2 py-1 border rounded">
                                            <?php foreach ($duty_statuses as $status): ?>
                                                <option value="<?php echo $status['id']; ?>" 
                                                    <?php echo ($user['current_duty_status_id'] == $status['id']) ? 'selected' : ''; ?>>
                                                    <?php echo htmlspecialchars($status['status_name']); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <select name="updates[<?php echo $user['id']; ?>][duty_shift]" class="w-full px-2 py-1 border rounded">
                                            <option value="">Select Shift</option>
                                            <option value="D6Hours" <?php echo ($user['duty_shift'] == 'D6Hours') ? 'selected' : ''; ?>>Day - 6 Hours</option>
                                            <option value="D12Hours" <?php echo ($user['duty_shift'] == 'D12Hours') ? 'selected' : ''; ?>>Day - 12 Hours</option>
                                            <option value="D24Hours" <?php echo ($user['duty_shift'] == 'D24Hours') ? 'selected' : ''; ?>>Day - 24 Hours</option>
                                            <option value="N6Hours" <?php echo ($user['duty_shift'] == 'N6Hours') ? 'selected' : ''; ?>>Night - 6 Hours</option>
                                            <option value="N12Hours" <?php echo ($user['duty_shift'] == 'N12Hours') ? 'selected' : ''; ?>>Night - 12 Hours</option>
                                            <option value="N24Hours" <?php echo ($user['duty_shift'] == 'N24Hours') ? 'selected' : ''; ?>>Night - 24 Hours</option>
                                        </select>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <div class="p-4 bg-gray-50 border-t">
                        <button type="submit" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                            Update All Users
                        </button>
                    </div>
                </div>
            </form>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
    </footer>
</body>
</html>