<?php
// Start session
session_start();

// Redirect if already logged in
if (isset($_SESSION['user_id'])) {
    // Redirect based on role
    if ($_SESSION['role'] === 'admin') {
        echo "<script>window.location.href = 'get-reports.php';</script>";
        exit;
    } else {
        echo "<script>window.location.href = 'index.php';</script>";
        exit;
    }
}

// Define variables and set to empty values
$username = $password = "";
$username_err = $password_err = $login_err = "";

// Process form data when the form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    
    // Include database connection
    require_once "db-connection.php";
    
    // Validate username
    if (empty(trim($_POST["username"]))) {
        $username_err = "Please enter username.";
    } else {
        $username = trim($_POST["username"]);
    }
    
    // Validate password
    if (empty(trim($_POST["password"]))) {
        $password_err = "Please enter your password.";
    } else {
        $password = trim($_POST["password"]);
    }
    
    // Validate credentials
    if (empty($username_err) && empty($password_err)) {
        // Log the login attempt (before validation for security records)
        $ip_address = $_SERVER['REMOTE_ADDR'];
        if (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
            $ip_address = $_SERVER['HTTP_X_FORWARDED_FOR'];
        }
        
        // Prepare a statement to log login attempt
        $log_sql = "INSERT INTO login_attempts (username, ip_address, success) VALUES (?, ?, ?)";
        $log_stmt = $pdo->prepare($log_sql);
        
        // Prepare a select statement to check user credentials
        $sql = "SELECT id, username, password, role, fullname FROM users WHERE username = ? AND active = TRUE";
        
        if ($stmt = $pdo->prepare($sql)) {
            // Bind variables to the prepared statement as parameters
            $stmt->bindParam(1, $param_username, PDO::PARAM_STR);
            
            // Set parameters
            $param_username = $username;
            
            // Attempt to execute the prepared statement
            if ($stmt->execute()) {
                // Check if username exists
                if ($stmt->rowCount() == 1) {
                    if ($row = $stmt->fetch()) {
                        $id = $row["id"];
                        $username = $row["username"];
                        $hashed_password = $row["password"];
                        $role = $row["role"];
                        $fullname = $row["fullname"];
                        
                        // Verify the password
                        if (password_verify($password, $hashed_password)) {
                            // Password is correct
                            
                            // Store data in session variables (we're already in a session)
                            $_SESSION["loggedin"] = true;
                            $_SESSION["user_id"] = $id;
                            $_SESSION["username"] = $username;
                            $_SESSION["role"] = $role;
                            $_SESSION["fullname"] = $fullname;
                            
                            // Update last login time
                            $update_sql = "UPDATE users SET last_login = NOW() WHERE id = ?";
                            $update_stmt = $pdo->prepare($update_sql);
                            $update_stmt->execute([$id]);
                            
                            // Log successful login
                            $log_stmt->execute([$username, $ip_address, 1]);
                            
                            // Set redirect URL based on role
                            $redirect = ($role === "admin") ? "get-reports.php" : "index.php";
                            
                            // Close any open database connections before redirect
                            unset($stmt);
                            unset($update_stmt);
                            unset($log_stmt);
                            unset($pdo);
                            
                            // Use JavaScript to redirect instead of header()
                            echo "<script>window.location.href = '$redirect';</script>";
                            exit;
                        } else {
                            // Password is not valid
                            $login_err = "Invalid username or password.";
                            
                            // Log failed login
                            $log_stmt->execute([$username, $ip_address, 0]);
                        }
                    }
                } else {
                    // Username doesn't exist
                    $login_err = "Invalid username or password.";
                    
                    // Log failed login
                    $log_stmt->execute([$username, $ip_address, 0]);
                }
            } else {
                $login_err = "Oops! Something went wrong. Please try again later.";
                
                // Log failed login due to error
                $log_stmt->execute([$username, $ip_address, 0]);
            }
            
            // Close statement
            unset($stmt);
        }
    }
    
    // Close connection
    unset($pdo);
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login - Emergency Code Reporter</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <h1 class="text-2xl font-bold text-center">Hospital Emergency Code Reporter</h1>
    </header>
    
    <main class="flex-grow flex items-center justify-center p-4">
        <div class="bg-white p-8 rounded-lg shadow-md w-full max-w-md">
            <h2 class="text-2xl font-bold mb-6 text-center text-gray-800">Login</h2>
            
            <?php if(!empty($login_err)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-6" role="alert">
                    <p><?php echo $login_err; ?></p>
                </div>
            <?php endif; ?>
            
            <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="post">
                <div class="mb-4">
                    <label for="username" class="block text-gray-700 font-bold mb-2">Username</label>
                    <input type="text" name="username" id="username" 
                           class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500 <?php echo (!empty($username_err)) ? 'border-red-500' : ''; ?>" 
                           value="<?php echo $username; ?>">
                    <span class="text-red-500 text-sm"><?php echo $username_err; ?></span>
                </div>
                
                <div class="mb-6">
                    <label for="password" class="block text-gray-700 font-bold mb-2">Password</label>
                    <input type="password" name="password" id="password" 
                           class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500 <?php echo (!empty($password_err)) ? 'border-red-500' : ''; ?>">
                    <span class="text-red-500 text-sm"><?php echo $password_err; ?></span>
                </div>
                
                <div class="flex items-center justify-center">
                    <button type="submit" 
                            class="bg-red-600 hover:bg-red-700 text-white font-bold py-2 px-4 rounded-full focus:outline-none focus:shadow-outline w-full">
                        Login
                    </button>
                </div>
            </form>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
</body>
</html>
