<?php
// Enable error reporting for troubleshooting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
} else if ($_SESSION["role"] !== "admin") {
    // Redirect non-admin users
    echo "<script>window.location.href = 'index.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Initialize messages
$successMessage = '';
$errorMessage = '';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Add new emergency code
    if (isset($_POST['add_code'])) {
        $codeValue = trim($_POST['code_value']);
        $label = trim($_POST['label']);
        $description = trim($_POST['description']);
        $arabicText = trim($_POST['arabic_text']);
        $bgColor = trim($_POST['bg_color']);
        $textColor = trim($_POST['text_color']);
        $priority = (int)$_POST['priority'];
        
        if (empty($codeValue) || empty($label) || empty($description)) {
            $errorMessage = "Code value, label, and description are required fields.";
        } else {
            try {
                // Check if code_value already exists
                $stmt = $pdo->prepare("SELECT id FROM emergency_codes WHERE code_value = ?");
                $stmt->execute([$codeValue]);
                
                if ($stmt->rowCount() > 0) {
                    $errorMessage = "An emergency code with this code value already exists.";
                } else {
                    $sql = "INSERT INTO emergency_codes (code_value, label, description, arabic_text, bg_color, text_color, priority) 
                            VALUES (?, ?, ?, ?, ?, ?, ?)";
                    $stmt = $pdo->prepare($sql);
                    $stmt->execute([$codeValue, $label, $description, $arabicText, $bgColor, $textColor, $priority]);
                    $successMessage = "Emergency code added successfully.";
                }
            } catch (PDOException $e) {
                $errorMessage = "Error adding emergency code: " . $e->getMessage();
            }
        }
    }
    
    // Update existing emergency code
    if (isset($_POST['update_code'])) {
        $codeId = (int)$_POST['code_id'];
        $codeValue = trim($_POST['code_value']);
        $label = trim($_POST['label']);
        $description = trim($_POST['description']);
        $arabicText = trim($_POST['arabic_text']);
        $bgColor = trim($_POST['bg_color']);
        $textColor = trim($_POST['text_color']);
        $priority = (int)$_POST['priority'];
        
        if (empty($codeValue) || empty($label) || empty($description)) {
            $errorMessage = "Code value, label, and description are required fields.";
        } else {
            try {
                // Check if code_value already exists for a different code
                $stmt = $pdo->prepare("SELECT id FROM emergency_codes WHERE code_value = ? AND id != ?");
                $stmt->execute([$codeValue, $codeId]);
                
                if ($stmt->rowCount() > 0) {
                    $errorMessage = "Another emergency code with this code value already exists.";
                } else {
                    $sql = "UPDATE emergency_codes 
                            SET code_value = ?, label = ?, description = ?, arabic_text = ?, 
                                bg_color = ?, text_color = ?, priority = ? 
                            WHERE id = ?";
                    $stmt = $pdo->prepare($sql);
                    $stmt->execute([$codeValue, $label, $description, $arabicText, $bgColor, $textColor, $priority, $codeId]);
                    $successMessage = "Emergency code updated successfully.";
                }
            } catch (PDOException $e) {
                $errorMessage = "Error updating emergency code: " . $e->getMessage();
            }
        }
    }
    
    // Delete emergency code
    if (isset($_POST['delete_code'])) {
        $codeId = (int)$_POST['code_id'];
        
        try {
            // First check if this code is referenced in any reports
            $stmt = $pdo->prepare("SELECT COUNT(*) FROM code_reports WHERE code_id = (SELECT code_value FROM emergency_codes WHERE id = ?)");
            $stmt->execute([$codeId]);
            $reportCount = $stmt->fetchColumn();
            
            if ($reportCount > 0) {
                $errorMessage = "This emergency code cannot be deleted because it is used in $reportCount report(s).";
            } else {
                $stmt = $pdo->prepare("DELETE FROM emergency_codes WHERE id = ?");
                $stmt->execute([$codeId]);
                $successMessage = "Emergency code deleted successfully.";
            }
        } catch (PDOException $e) {
            $errorMessage = "Error deleting emergency code: " . $e->getMessage();
        }
    }
}

// Fetch all emergency codes
try {
    $stmt = $pdo->query("SELECT id, code_value, label, description, arabic_text, bg_color, text_color, priority FROM emergency_codes ORDER BY priority, label");
    $emergencyCodes = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $errorMessage = "Error fetching emergency codes: " . $e->getMessage();
    $emergencyCodes = [];
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Emergency Codes - Admin Panel</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="icon" href="favicon.ico" type="image/x-icon">
    <link href="css/emergency-codes.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Manage Emergency Codes</h1>
            <div class="flex items-center space-x-4">
                <a href="index.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Home</a>
                <a href="get-reports.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">All Reports</a>
                <a href="manage-locations.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Manage Locations</a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"] ?? 'Admin'); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <?php if (!empty($successMessage)): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4" role="alert">
                    <p><?php echo $successMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($errorMessage)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
                    <p><?php echo $errorMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="bg-white rounded-lg shadow p-6 mb-6">
                <h2 class="text-xl font-bold mb-4">Add New Emergency Code</h2>
                <form method="post" action="">
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div>
                            <label for="code_value" class="block text-sm font-medium text-gray-700 mb-1">Code Value *</label>
                            <input type="text" name="code_value" id="code_value" required 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500"
                                   placeholder="e.g., code-red">
                            <p class="text-xs text-gray-500 mt-1">Used as an identifier (e.g., code-red, code-blue)</p>
                        </div>
                        <div>
                            <label for="label" class="block text-sm font-medium text-gray-700 mb-1">Label *</label>
                            <input type="text" name="label" id="label" required 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500"
                                   placeholder="e.g., CODE RED">
                            <p class="text-xs text-gray-500 mt-1">Displayed name (e.g., CODE RED, CODE BLUE)</p>
                        </div>
                        <div>
                            <label for="description" class="block text-sm font-medium text-gray-700 mb-1">Description *</label>
                            <input type="text" name="description" id="description" required 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500"
                                   placeholder="e.g., Fire">
                            <p class="text-xs text-gray-500 mt-1">What the code means (e.g., Fire, Medical Emergency)</p>
                        </div>
                        <div>
                            <label for="arabic_text" class="block text-sm font-medium text-gray-700 mb-1">Arabic Text</label>
                            <input type="text" name="arabic_text" id="arabic_text" dir="rtl"
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500"
                                   placeholder="e.g., حريق">
                            <p class="text-xs text-gray-500 mt-1">Arabic translation for the code</p>
                        </div>
                        <div>
                            <label for="bg_color" class="block text-sm font-medium text-gray-700 mb-1">Background Color</label>
                            <div class="flex items-center">
                                <input type="color" name="bg_color_picker" id="bg_color_picker" value="#FF3333" 
                                       onchange="document.getElementById('bg_color').value = this.value;"
                                       class="mr-2 h-10 w-10 border border-gray-300 rounded">
                                <input type="text" name="bg_color" id="bg_color" value="#FF3333" 
                                       class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500"
                                       placeholder="e.g., #FF3333">
                            </div>
                            <p class="text-xs text-gray-500 mt-1">Background color for the code (hex value)</p>
                        </div>
                        <div>
                            <label for="text_color" class="block text-sm font-medium text-gray-700 mb-1">Text Color</label>
                            <div class="flex items-center">
                                <input type="color" name="text_color_picker" id="text_color_picker" value="#FFFFFF" 
                                       onchange="document.getElementById('text_color').value = this.value;"
                                       class="mr-2 h-10 w-10 border border-gray-300 rounded">
                                <input type="text" name="text_color" id="text_color" value="#FFFFFF" 
                                       class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500"
                                       placeholder="e.g., white or #FFFFFF">
                            </div>
                            <p class="text-xs text-gray-500 mt-1">Text color for the code (hex value or CSS color name)</p>
                        </div>
                        <div>
                            <label for="priority" class="block text-sm font-medium text-gray-700 mb-1">Priority</label>
                            <select name="priority" id="priority" 
                                    class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                                <option value="1">1 - Highest</option>
                                <option value="2">2 - High</option>
                                <option value="3" selected>3 - Medium</option>
                                <option value="4">4 - Low</option>
                                <option value="5">5 - Lowest</option>
                            </select>
                            <p class="text-xs text-gray-500 mt-1">Order of importance (lower number = higher priority)</p>
                        </div>
                        <div>
                            <label class="block text-sm font-medium text-gray-700 mb-1">Preview</label>
                            <div id="code_preview" class="p-4 rounded text-center mt-2" style="background-color: #FF3333; color: white;">
                                <div id="arabic_preview" style="font-size: 18px; margin-bottom: 4px;"></div>
                                <div id="label_preview" style="font-size: 24px; font-weight: bold;"></div>
                                <div id="description_preview" style="font-size: 16px;"></div>
                            </div>
                        </div>
                    </div>
                    <div class="mt-4">
                        <button type="submit" name="add_code" class="bg-green-500 hover:bg-green-600 text-white font-bold py-2 px-4 rounded">
                            Add Emergency Code
                        </button>
                    </div>
                </form>
            </div>
            
            <div class="bg-white rounded-lg shadow overflow-hidden">
                <h2 class="text-xl font-bold p-6 bg-gray-50 border-b">Emergency Codes List</h2>
                
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-200">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Code Display</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Code Value</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Label</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Description</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Arabic Text</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Priority</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                            </tr>
                        </thead>
                        <tbody class="bg-white divide-y divide-gray-200">
                            <?php if (count($emergencyCodes) > 0): ?>
                                <?php foreach ($emergencyCodes as $code): ?>
                                    <tr>
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <div class="code-badge" style="background-color: <?php echo htmlspecialchars($code['bg_color']); ?>; color: <?php echo htmlspecialchars($code['text_color']); ?>">
                                                <?php echo htmlspecialchars($code['label']); ?>
                                            </div>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <?php echo htmlspecialchars($code['code_value']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <?php echo htmlspecialchars($code['label']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <?php echo htmlspecialchars($code['description']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap" dir="rtl">
                                            <?php echo htmlspecialchars($code['arabic_text']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <?php echo htmlspecialchars($code['priority']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                                            <button onclick="openEditModal(<?php echo htmlspecialchars(json_encode($code)); ?>)" 
                                                    class="text-indigo-600 hover:text-indigo-900 mr-3">Edit</button>
                                            <form method="post" action="" class="inline">
                                                <input type="hidden" name="code_id" value="<?php echo $code['id']; ?>">
                                                <button type="submit" name="delete_code" class="text-red-600 hover:text-red-900" 
                                                        onclick="return confirm('Are you sure you want to delete this emergency code? This action cannot be undone.')">
                                                    Delete
                                                </button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="7" class="px-6 py-4 text-center text-gray-500">No emergency codes found.</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
            
            <!-- Instructions Section -->
            <div class="bg-white rounded-lg shadow p-6 mt-6">
                <h2 class="text-xl font-bold mb-4">Instructions</h2>
                <div class="prose max-w-none">
                    <p>This page allows you to manage the emergency codes used throughout the system.</p>
                    
                    <h3 class="font-bold mt-4">Adding Codes</h3>
                    <ul class="list-disc ml-6 space-y-1">
                        <li>Use the form at the top to add new emergency codes to the system.</li>
                        <li>The <strong>Code Value</strong> is used as an identifier in the database and should be unique.</li>
                        <li>The <strong>Label</strong> is how the code appears to users (typically uppercase).</li>
                        <li>The <strong>Description</strong> explains what the code means (e.g., Fire, Medical Emergency).</li>
                    </ul>
                    
                    <h3 class="font-bold mt-4">Editing & Deleting</h3>
                    <ul class="list-disc ml-6 space-y-1">
                        <li>Click the <strong>Edit</strong> button to modify an existing code.</li>
                        <li>Click the <strong>Delete</strong> button to remove a code (only possible if the code is not in use in any reports).</li>
                    </ul>
                    
                    <p class="mt-4 text-sm text-gray-600">Note: Changes to emergency codes will affect how they appear in the emergency reporting form and in reports.</p>
                </div>
            </div>
        </div>
    </main>
    
    <!-- Edit Modal -->
    <div id="editModal" class="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center hidden z-50">
        <div class="bg-white rounded-lg max-w-4xl w-full p-6 max-h-screen overflow-y-auto" onclick="event.stopPropagation();">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-bold">Edit Emergency Code</h3>
                <button onclick="closeEditModal()" class="text-gray-500 hover:text-gray-700">
                    <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12"></path>
                    </svg>
                </button>
            </div>
            
            <form method="post" action="" id="editForm">
                <input type="hidden" name="code_id" id="edit_code_id">
                
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div>
                        <label for="edit_code_value" class="block text-sm font-medium text-gray-700 mb-1">Code Value *</label>
                        <input type="text" name="code_value" id="edit_code_value" required 
                               class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                    </div>
                    <div>
                        <label for="edit_label" class="block text-sm font-medium text-gray-700 mb-1">Label *</label>
                        <input type="text" name="label" id="edit_label" required 
                               class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                    </div>
                    <div>
                        <label for="edit_description" class="block text-sm font-medium text-gray-700 mb-1">Description *</label>
                        <input type="text" name="description" id="edit_description" required 
                               class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                    </div>
                    <div>
                        <label for="edit_arabic_text" class="block text-sm font-medium text-gray-700 mb-1">Arabic Text</label>
                        <input type="text" name="arabic_text" id="edit_arabic_text" dir="rtl"
                               class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                    </div>
                    <div>
                        <label for="edit_bg_color" class="block text-sm font-medium text-gray-700 mb-1">Background Color</label>
                        <div class="flex items-center">
                            <input type="color" name="edit_bg_color_picker" id="edit_bg_color_picker" 
                                   onchange="document.getElementById('edit_bg_color').value = this.value;"
                                   class="mr-2 h-10 w-10 border border-gray-300 rounded">
                            <input type="text" name="bg_color" id="edit_bg_color" 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                        </div>
                    </div>
                    <div>
                        <label for="edit_text_color" class="block text-sm font-medium text-gray-700 mb-1">Text Color</label>
                        <div class="flex items-center">
                            <input type="color" name="edit_text_color_picker" id="edit_text_color_picker" 
                                   onchange="document.getElementById('edit_text_color').value = this.value;"
                                   class="mr-2 h-10 w-10 border border-gray-300 rounded">
                            <input type="text" name="text_color" id="edit_text_color" 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                        </div>
                    </div>
                    <div>
                        <label for="edit_priority" class="block text-sm font-medium text-gray-700 mb-1">Priority</label>
                        <select name="priority" id="edit_priority" 
                                class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                            <option value="1">1 - Highest</option>
                            <option value="2">2 - High</option>
                            <option value="3">3 - Medium</option>
                            <option value="4">4 - Low</option>
                            <option value="5">5 - Lowest</option>
                        </select>
                    </div>
                    <div>
                        <label class="block text-sm font-medium text-gray-700 mb-1">Preview</label>
                        <div id="edit_code_preview" class="p-4 rounded text-center mt-2">
                            <div id="edit_arabic_preview" style="font-size: 18px; margin-bottom: 4px;"></div>
                            <div id="edit_label_preview" style="font-size: 24px; font-weight: bold;"></div>
                            <div id="edit_description_preview" style="font-size: 16px;"></div>
                        </div>
                    </div>
                </div>
                
                <div class="mt-6 flex justify-end">
                    <button type="button" onclick="closeEditModal()" class="bg-gray-300 hover:bg-gray-400 text-gray-800 font-bold py-2 px-4 rounded mr-2">
                        Cancel
                    </button>
                    <button type="submit" name="update_code" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                        Update Emergency Code
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
    
    <!-- Include the JavaScript file -->
    <script src="js/emergency-codes.js"></script>
</body>
</html>