<?php
// Enable error reporting for troubleshooting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
} else if ($_SESSION["role"] !== "admin") {
    // Redirect non-admin users
    echo "<script>window.location.href = 'index.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Initialize messages
$successMessage = '';
$errorMessage = '';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Add new location
    if (isset($_POST['add_location'])) {
        $locationName = trim($_POST['location_name']);
        if (!empty($locationName)) {
            try {
                $stmt = $pdo->prepare("INSERT INTO locations (name) VALUES (?)");
                $stmt->execute([$locationName]);
                $successMessage = "Location '{$locationName}' added successfully.";
            } catch (PDOException $e) {
                $errorMessage = "Error adding location: " . $e->getMessage();
            }
        } else {
            $errorMessage = "Location name cannot be empty.";
        }
    }
    
    // Add new building
    if (isset($_POST['add_building'])) {
        $buildingName = trim($_POST['building_name']);
        $shortCode = trim($_POST['building_code']);
        if (!empty($buildingName)) {
            try {
                $stmt = $pdo->prepare("INSERT INTO buildings (name, short_code, active) VALUES (?, ?, 1)");
                $stmt->execute([$buildingName, $shortCode]);
                $successMessage = "Building '{$buildingName}' added successfully.";
            } catch (PDOException $e) {
                $errorMessage = "Error adding building: " . $e->getMessage();
            }
        } else {
            $errorMessage = "Building name cannot be empty.";
        }
    }
    
    // Delete location
    if (isset($_POST['delete_location'])) {
        $locationId = (int)$_POST['location_id'];
        try {
            $stmt = $pdo->prepare("DELETE FROM locations WHERE id = ?");
            $stmt->execute([$locationId]);
            $successMessage = "Location deleted successfully.";
        } catch (PDOException $e) {
            $errorMessage = "Error deleting location: " . $e->getMessage();
        }
    }
    
    // Delete building
    if (isset($_POST['delete_building'])) {
        $buildingId = (int)$_POST['building_id'];
        try {
            $stmt = $pdo->prepare("DELETE FROM buildings WHERE id = ?");
            $stmt->execute([$buildingId]);
            $successMessage = "Building deleted successfully.";
        } catch (PDOException $e) {
            $errorMessage = "Error deleting building: " . $e->getMessage();
        }
    }
    
    // Toggle building status
    if (isset($_POST['toggle_building'])) {
        $buildingId = (int)$_POST['building_id'];
        $newStatus = (int)$_POST['new_status'];
        try {
            $stmt = $pdo->prepare("UPDATE buildings SET active = ? WHERE id = ?");
            $stmt->execute([$newStatus, $buildingId]);
            $statusText = $newStatus ? "activated" : "deactivated";
            $successMessage = "Building {$statusText} successfully.";
        } catch (PDOException $e) {
            $errorMessage = "Error updating building status: " . $e->getMessage();
        }
    }
}

// Fetch all locations
try {
    $stmt = $pdo->query("SELECT id, name FROM locations ORDER BY name");
    $locations = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $errorMessage = "Error fetching locations: " . $e->getMessage();
    $locations = [];
}

// Fetch all buildings
try {
    $stmt = $pdo->query("SELECT id, name, short_code, active FROM buildings ORDER BY name");
    $buildings = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $errorMessage = "Error fetching buildings: " . $e->getMessage();
    $buildings = [];
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Locations & Buildings - Emergency Code System</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <!-- Add favicon link -->
    <link rel="icon" href="favicon.ico" type="image/x-icon">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Manage Locations & Buildings</h1>
            <div class="flex items-center space-x-4">
                <a href="index.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Home</a>
                <a href="get-reports.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">All Reports</a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"] ?? 'Admin'); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <?php if (!empty($successMessage)): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4" role="alert">
                    <p><?php echo $successMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($errorMessage)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
                    <p><?php echo $errorMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                <!-- Manage Locations -->
                <div class="bg-white rounded-lg shadow p-6">
                    <h2 class="text-xl font-bold mb-4">Manage Locations</h2>
                    
                    <!-- Add Location Form -->
                    <form method="post" action="" class="mb-6">
                        <div class="mb-4">
                            <label for="location_name" class="block text-gray-700 font-bold mb-2">Add New Location:</label>
                            <div class="flex">
                                <input type="text" id="location_name" name="location_name" placeholder="Enter location name" 
                                       class="flex-grow px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                                <button type="submit" name="add_location" class="ml-2 bg-green-500 hover:bg-green-600 text-white px-4 py-2 rounded">
                                    Add
                                </button>
                            </div>
                        </div>
                    </form>
                    
                    <!-- Locations List -->
                    <h3 class="font-bold mb-2">Current Locations:</h3>
                    <?php if (count($locations) > 0): ?>
                        <div class="overflow-y-auto max-h-96">
                            <table class="min-w-full divide-y divide-gray-200">
                                <thead class="bg-gray-50">
                                    <tr>
                                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Location Name</th>
                                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                                    </tr>
                                </thead>
                                <tbody class="bg-white divide-y divide-gray-200">
                                    <?php foreach ($locations as $location): ?>
                                        <tr>
                                            <td class="px-6 py-4 whitespace-nowrap">
                                                <?php echo htmlspecialchars($location['name']); ?>
                                            </td>
                                            <td class="px-6 py-4 whitespace-nowrap">
                                                <form method="post" action="" class="inline">
                                                    <input type="hidden" name="location_id" value="<?php echo $location['id']; ?>">
                                                    <button type="submit" name="delete_location" class="text-red-600 hover:text-red-900"
                                                            onclick="return confirm('Are you sure you want to delete this location?')">
                                                        Delete
                                                    </button>
                                                </form>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php else: ?>
                        <p class="text-gray-500">No locations found.</p>
                    <?php endif; ?>
                </div>
                
                <!-- Manage Buildings -->
                <div class="bg-white rounded-lg shadow p-6">
                    <h2 class="text-xl font-bold mb-4">Manage Buildings</h2>
                    
                    <!-- Add Building Form -->
                    <form method="post" action="" class="mb-6">
                        <div class="mb-4">
                            <label for="building_name" class="block text-gray-700 font-bold mb-2">Add New Building:</label>
                            <div class="grid grid-cols-3 gap-2">
                                <input type="text" id="building_name" name="building_name" placeholder="Building name" 
                                       class="col-span-2 px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                                <input type="text" id="building_code" name="building_code" placeholder="Short code" 
                                       class="px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                                <button type="submit" name="add_building" class="col-span-3 bg-green-500 hover:bg-green-600 text-white px-4 py-2 rounded">
                                    Add Building
                                </button>
                            </div>
                        </div>
                    </form>
                    
                    <!-- Buildings List -->
                    <h3 class="font-bold mb-2">Current Buildings:</h3>
                    <?php if (count($buildings) > 0): ?>
                        <div class="overflow-y-auto max-h-96">
                            <table class="min-w-full divide-y divide-gray-200">
                                <thead class="bg-gray-50">
                                    <tr>
                                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Building Name</th>
                                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Code</th>
                                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
                                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                                    </tr>
                                </thead>
                                <tbody class="bg-white divide-y divide-gray-200">
                                    <?php foreach ($buildings as $building): ?>
                                        <tr>
                                            <td class="px-6 py-4 whitespace-nowrap">
                                                <?php echo htmlspecialchars($building['name']); ?>
                                            </td>
                                            <td class="px-6 py-4 whitespace-nowrap">
                                                <?php echo htmlspecialchars($building['short_code']); ?>
                                            </td>
                                            <td class="px-6 py-4 whitespace-nowrap">
                                                <?php if ($building['active']): ?>
                                                    <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-100 text-green-800">
                                                        Active
                                                    </span>
                                                <?php else: ?>
                                                    <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-red-100 text-red-800">
                                                        Inactive
                                                    </span>
                                                <?php endif; ?>
                                            </td>
                                            <td class="px-6 py-4 whitespace-nowrap">
                                                <form method="post" action="" class="inline mr-2">
                                                    <input type="hidden" name="building_id" value="<?php echo $building['id']; ?>">
                                                    <input type="hidden" name="new_status" value="<?php echo $building['active'] ? 0 : 1; ?>">
                                                    <button type="submit" name="toggle_building" class="text-blue-600 hover:text-blue-900">
                                                        <?php echo $building['active'] ? 'Deactivate' : 'Activate'; ?>
                                                    </button>
                                                </form>
                                                <form method="post" action="" class="inline">
                                                    <input type="hidden" name="building_id" value="<?php echo $building['id']; ?>">
                                                    <button type="submit" name="delete_building" class="text-red-600 hover:text-red-900"
                                                            onclick="return confirm('Are you sure you want to delete this building?')">
                                                        Delete
                                                    </button>
                                                </form>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php else: ?>
                        <p class="text-gray-500">No buildings found.</p>
                    <?php endif; ?>
                </div>
            </div>
            
            <!-- Instructions -->
            <div class="bg-white rounded-lg shadow p-6 mt-6">
                <h2 class="text-xl font-bold mb-4">Instructions</h2>
                <div class="prose max-w-none">
                    <p>This page allows you to manage the locations and buildings that appear in dropdown menus throughout the Emergency Code Reporter system.</p>
                    
                    <h3 class="font-bold mt-4">Locations</h3>
                    <ul class="list-disc ml-6 space-y-1">
                        <li>Add new locations that will appear in the "Location" dropdown on the emergency reporting form.</li>
                        <li>Delete locations that are no longer needed (note: this may affect existing reports).</li>
                    </ul>
                    
                    <h3 class="font-bold mt-4">Buildings</h3>
                    <ul class="list-disc ml-6 space-y-1">
                        <li>Add new buildings that will appear in the "Building" dropdown on the emergency reporting form.</li>
                        <li>Each building can have a short code for easy identification.</li>
                        <li>Buildings can be activated or deactivated without deleting them.</li>
                        <li>Inactive buildings won't appear in the dropdown menu but still exist in the system.</li>
                    </ul>
                    
                    <p class="mt-4 text-sm text-gray-600">Note: Deleting locations or buildings that are referenced by existing reports may cause issues with report display. Consider deactivating buildings instead of deleting them.</p>
                </div>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
</body>
</html>