<?php
// Enable error reporting for troubleshooting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
}

// Get user information
$userId = $_SESSION["user_id"] ?? 0;
$fullname = $_SESSION["fullname"] ?? "User";

// For API requests
if (isset($_GET['api']) && $_GET['api'] === 'true') {
    require_once 'db-connection.php';
    header('Content-Type: application/json');
    
    try {
        $limit = isset($_GET['limit']) ? (int)$_GET['limit'] : 20;
        $offset = isset($_GET['offset']) ? (int)$_GET['offset'] : 0;
        $status = isset($_GET['status']) ? $_GET['status'] : null;
        
        // Validate parameters
        if ($limit > 100) $limit = 100;
        if ($limit < 1) $limit = 1;
        if ($offset < 0) $offset = 0;
        
        // Use a two-step query approach to eliminate duplicates
        
        // Step 1: Get DISTINCT report IDs first with proper pagination
        // IMPORTANT: Filter by user_id to show only the current user's reports
        $idQuery = "
            SELECT DISTINCT id 
            FROM code_reports 
            WHERE user_id = ? 
        ";
        
        // Add status filter if needed
        $idParams = [$userId]; // Always filter by user ID
        if ($status) {
            $idQuery .= " AND status = ? ";
            $idParams[] = $status;
        }
        
        // Add sorting and pagination
        $idQuery .= "
            ORDER BY id DESC
            LIMIT ? OFFSET ?
        ";
        
        $idParams[] = $limit;
        $idParams[] = $offset;
        
        // Execute the first query to get distinct IDs
        $idStmt = $pdo->prepare($idQuery);
        $idStmt->execute($idParams);
        $ids = $idStmt->fetchAll(PDO::FETCH_COLUMN);
        
        // If no reports found, return empty array
        if (empty($ids)) {
            echo json_encode([
                'success' => true,
                'reports' => [],
                'pagination' => [
                    'total' => 0,
                    'limit' => $limit,
                    'offset' => $offset,
                    'hasMore' => false
                ]
            ]);
            exit;
        }
        
        // Step 2: Get full details for these specific IDs only
        // Create placeholders for the IN clause
        $placeholders = implode(',', array_fill(0, count($ids), '?'));
        
        // Build the second query that gets details for these IDs only
        $detailQuery = "
            SELECT 
                r.id,
                CONCAT('ECR-', LPAD(r.id, 6, '0')) AS formatted_reference_id,
                r.code_id,
                (SELECT label FROM emergency_codes WHERE code_value = r.code_id LIMIT 1) AS code_label,
                (SELECT description FROM emergency_codes WHERE code_value = r.code_id LIMIT 1) AS code_description,
                r.location_id AS location,
                r.reported_by,
                r.details,
                r.audio_file,
                DATE_FORMAT(r.report_timestamp, '%Y-%m-%d %H:%i:%s') AS report_time,
                r.status
            FROM 
                code_reports r
            WHERE 
                r.id IN ($placeholders)
            ORDER BY 
                r.id DESC
        ";
        
        // Execute the second query to get full report details
        $detailStmt = $pdo->prepare($detailQuery);
        $detailStmt->execute($ids); // Pass the IDs as parameters for the IN clause
        $reports = $detailStmt->fetchAll(PDO::FETCH_ASSOC);
        
        // Count total distinct reports for pagination (only for this user)
        $countQuery = "SELECT COUNT(DISTINCT id) FROM code_reports WHERE user_id = ?";
        $countParams = [$userId];
        
        if ($status) {
            $countQuery .= " AND status = ?";
            $countParams[] = $status;
        }
        
        $countStmt = $pdo->prepare($countQuery);
        $countStmt->execute($countParams);
        $totalCount = $countStmt->fetchColumn();
        
        // Return JSON response
        echo json_encode([
            'success' => true,
            'reports' => $reports,
            'pagination' => [
                'total' => (int)$totalCount,
                'limit' => $limit,
                'offset' => $offset,
                'hasMore' => ($offset + $limit < $totalCount)
            ]
        ]);
        
    } catch (Exception $e) {
        // Log the error
        error_log('Database Error: ' . $e->getMessage());
        
        // Return error response
        http_response_code(500);
        echo json_encode([
            'success' => false,
            'error' => 'Database error: ' . $e->getMessage()
        ]);
    }
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>My Reports - Emergency Code System</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    
    <!-- Add script error handling -->
    <script>
    window.addEventListener('error', function(e) {
      console.error('Script error:', e.message);
    }, true);
    </script>
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">My Emergency Code Reports</h1>
            <div class="flex items-center space-x-4">
                <a href="index.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Report New Emergency</a>
                <?php if ($_SESSION["role"] === "admin"): ?>
                <a href="get-reports.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">All Reports</a>
                <?php endif; ?>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($fullname); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <div class="bg-white rounded-lg shadow p-6">
                <div class="flex justify-between items-center mb-6">
                    <h2 class="text-xl font-bold text-gray-800">My Reported Emergencies</h2>
                    <div class="flex space-x-2">
                        <select id="status-filter" class="border border-gray-300 rounded px-3 py-1 focus:outline-none focus:ring-2 focus:ring-red-500">
                            <option value="">All Statuses</option>
                            <option value="active">Active</option>
                            <option value="resolved">Resolved</option>
                            <option value="false_alarm">False Alarm</option>
                        </select>
                        <button id="refresh-btn" class="bg-blue-500 hover:bg-blue-600 text-white px-3 py-1 rounded">
                            Refresh
                        </button>
                    </div>
                </div>
                
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-200">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Report ID</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Code</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Location</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Time</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                            </tr>
                        </thead>
                        <tbody id="reports-table-body" class="bg-white divide-y divide-gray-200">
                            <tr>
                                <td colspan="6" class="px-6 py-4 text-center text-gray-500">Loading your reports...</td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                
                <div class="mt-4 flex justify-between items-center">
                    <div class="text-sm text-gray-500" id="reports-count">
                        Loading...
                    </div>
                    <div class="flex space-x-2">
                        <button id="prev-page" class="px-3 py-1 border border-gray-300 rounded disabled:opacity-50">
                            Previous
                        </button>
                        <button id="next-page" class="px-3 py-1 border border-gray-300 rounded disabled:opacity-50">
                            Next
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
    
    <!-- Report details modal -->
    <div id="report-modal" class="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center hidden">
        <div class="bg-white rounded-lg max-w-2xl w-full p-6 max-h-screen overflow-auto">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-bold" id="modal-title">Report Details</h3>
                <button id="close-modal" class="text-gray-500 hover:text-gray-700">
                    <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12"></path>
                    </svg>
                </button>
            </div>
            <div id="modal-content">
                <!-- Report details will be loaded here -->
            </div>
        </div>
    </div>
    
    <!-- Include inline JavaScript -->
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // DOM elements
        const reportsTableBody = document.getElementById('reports-table-body');
        const reportsCount = document.getElementById('reports-count');
        const prevPageBtn = document.getElementById('prev-page');
        const nextPageBtn = document.getElementById('next-page');
        const statusFilter = document.getElementById('status-filter');
        const refreshBtn = document.getElementById('refresh-btn');
        const reportModal = document.getElementById('report-modal');
        const closeModalBtn = document.getElementById('close-modal');
        const modalContent = document.getElementById('modal-content');
        const modalTitle = document.getElementById('modal-title');
        
        // Variables for pagination
        let currentOffset = 0;
        const limit = 10;
        let totalReports = 0;
        let currentStatus = '';
        
        // Format date function (simplified)
        const formatDate = (dateString) => {
            try {
                return new Date(dateString).toLocaleString();
            } catch (e) {
                return dateString;
            }
        };
        
        // Function to get status badge HTML
        const getStatusBadge = (status) => {
            let color = '';
            switch(status) {
                case 'active':
                    color = 'bg-yellow-100 text-yellow-800';
                    break;
                case 'resolved':
                    color = 'bg-green-100 text-green-800';
                    break;
                case 'false_alarm':
                    color = 'bg-gray-100 text-gray-800';
                    break;
                default:
                    color = 'bg-blue-100 text-blue-800';
            }
            
            return `<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full ${color}">
                ${status.replace('_', ' ').toUpperCase()}
            </span>`;
        };
        
        // Load reports from API
        const loadReports = async () => {
            try {
                // Show loading state
                reportsTableBody.innerHTML = '<tr><td colspan="6" class="px-6 py-4 text-center text-gray-500">Loading your reports...</td></tr>';
                
                // Fetch data from API
                const url = `my-reports.php?api=true&limit=${limit}&offset=${currentOffset}${currentStatus ? '&status=' + currentStatus : ''}`;
                const response = await fetch(url);
                const data = await response.json();
                
                if (!data.success) {
                    throw new Error(data.message || 'Failed to load reports');
                }
                
                totalReports = data.pagination.total;
                
                // Update reports count
                reportsCount.textContent = `Showing ${Math.min(data.reports.length, limit)} of ${totalReports} reports`;
                
                // Update pagination buttons
                prevPageBtn.disabled = currentOffset === 0;
                nextPageBtn.disabled = !data.pagination.hasMore;
                
                // Render reports
                if (data.reports.length === 0) {
                    reportsTableBody.innerHTML = '<tr><td colspan="6" class="px-6 py-4 text-center text-gray-500">No reports found</td></tr>';
                    return;
                }
                
                // Build the HTML for the table rows
                let html = '';
                for (const report of data.reports) {
                    const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
                    html += `
                    <tr>
                        <td class="px-6 py-4 whitespace-nowrap font-bold text-blue-600">${formattedRefId}</td>
                        <td class="px-6 py-4 whitespace-nowrap">${report.code_label}</td>
                        <td class="px-6 py-4 whitespace-nowrap">${report.location}</td>
                        <td class="px-6 py-4 whitespace-nowrap">${formatDate(report.report_time)}</td>
                        <td class="px-6 py-4 whitespace-nowrap">${getStatusBadge(report.status)}</td>
                        <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                            <button class="text-indigo-600 hover:text-indigo-900 view-details" 
                                    data-report-id="${report.id}" 
                                    data-report='${JSON.stringify(report)}'>
                                View Details
                            </button>
                        </td>
                    </tr>`;
                }
                reportsTableBody.innerHTML = html;
                
                // Add event listeners to view details buttons
                document.querySelectorAll('.view-details').forEach(button => {
                    button.addEventListener('click', function() {
                        try {
                            const reportData = JSON.parse(this.getAttribute('data-report'));
                            showReportDetails(reportData);
                        } catch (e) {
                            console.error("Error parsing report data:", e);
                            alert("Error displaying report details");
                        }
                    });
                });
                
            } catch (error) {
                console.error('Error loading reports:', error);
                reportsTableBody.innerHTML = `
                    <tr>
                        <td colspan="6" class="px-6 py-4 text-center text-red-500">
                            Error loading reports: ${error.message}
                        </td>
                    </tr>
                `;
            }
        };
        
        // Show report details in modal
        const showReportDetails = (report) => {
            modalTitle.textContent = `${report.code_label} Report`;
            
            const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
            
            modalContent.innerHTML = `
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div>
                        <p class="text-gray-500 text-sm">Report ID</p>
                        <p class="font-medium text-blue-600">${formattedRefId}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Code</p>
                        <p class="font-medium">${report.code_label}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Location</p>
                        <p class="font-medium">${report.location}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Reported By</p>
                        <p class="font-medium">${report.reported_by}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Time</p>
                        <p class="font-medium">${formatDate(report.report_time)}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Status</p>
                        <p class="font-medium">${getStatusBadge(report.status)}</p>
                    </div>
                    <div class="col-span-2">
                        <p class="text-gray-500 text-sm">Details</p>
                        <p class="font-medium">${report.details || 'No additional details provided'}</p>
                    </div>
                </div>
            `;
            
            // Show modal
            reportModal.classList.remove('hidden');
        };
        
        // Event Listeners
        statusFilter.addEventListener('change', function() {
            currentStatus = this.value;
            currentOffset = 0;
            loadReports();
        });
        
        refreshBtn.addEventListener('click', loadReports);
        
        prevPageBtn.addEventListener('click', function() {
            if (currentOffset >= limit) {
                currentOffset -= limit;
                loadReports();
            }
        });
        
        nextPageBtn.addEventListener('click', function() {
            currentOffset += limit;
            loadReports();
        });
        
        closeModalBtn.addEventListener('click', function() {
            reportModal.classList.add('hidden');
        });
        
        // Close modal when clicking outside
        reportModal.addEventListener('click', function(event) {
            if (event.target === reportModal) {
                reportModal.classList.add('hidden');
            }
        });
        
        // Initial load
        loadReports();
    });
    </script>
</body>
</html>