<?php
// Enable error reporting for troubleshooting (remove in production)
error_reporting(E_ALL);
ini_set('display_errors', 0); // Disable display errors, but still log them

// Start session
session_start();

// Check if user is logged in and has appropriate permissions
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'error' => 'Unauthorized', 'code' => 401]);
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Set response headers
header('Content-Type: application/json');

try {
    // Prepare query parameters with proper type casting and validation
    $limit = isset($_GET['limit']) ? intval($_GET['limit']) : 20;
    $offset = isset($_GET['offset']) ? intval($_GET['offset']) : 0;
    $status = isset($_GET['status']) && !empty($_GET['status']) ? $_GET['status'] : null;
    
    // Sanitize status parameter
    if ($status !== null) {
        $validStatuses = ['active', 'resolved', 'false_alarm'];
        if (!in_array($status, $validStatuses)) {
            throw new Exception("Invalid status parameter");
        }
    }
    
    // Validate pagination parameters
    if ($limit > 100) $limit = 100; // Maximum 100 records per request
    if ($limit < 1) $limit = 1;     // Minimum 1 record
    if ($offset < 0) $offset = 0;   // No negative offset
    
    // Log parameters for debugging
    error_log("API Request - limit: $limit, offset: $offset, status: " . ($status ?? "all"));
    
    // Build query with proper error handling
    $query = "
        SELECT 
            r.id,
            r.code_id,
            e.label AS code_label,
            e.description AS code_description,
            r.location_id,
            r.reported_by,
            r.details,
            DATE_FORMAT(r.report_timestamp, '%Y-%m-%d %H:%i:%s') AS report_time,
            r.status
        FROM 
            code_reports r
        JOIN 
            emergency_codes e ON r.code_id = e.code_value
    ";
    
    // Add filters
    $params = [];
    if ($status) {
        $query .= " WHERE r.status = ?";
        $params[] = $status;
    }
    
    // Add sorting
    $query .= " ORDER BY r.id DESC";
    
    // Get total count first (for pagination)
    $countQuery = "SELECT COUNT(*) FROM code_reports";
    if ($status) {
        $countQuery .= " WHERE status = ?";
        $countStmt = $pdo->prepare($countQuery);
        $countStmt->execute([$status]);
    } else {
        $countStmt = $pdo->query($countQuery);
    }
    $totalCount = $countStmt->fetchColumn();
    
    // Add pagination to main query
    $query .= " LIMIT ? OFFSET ?";
    $params[] = $limit;
    $params[] = $offset;
    
    // Log final query for debugging
    error_log("Executing query: " . str_replace("?", "%s", $query));
    
    // Execute the query
    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    
    // Fetch all records
    $reports = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // Format the data for the client
    $formattedReports = [];
    foreach ($reports as $report) {
        // Format reference ID
        $formattedReferenceId = 'ECR-' . str_pad($report['id'], 6, '0', STR_PAD_LEFT);
        
        // Add formatted data
        $formattedReports[] = [
            'id' => $report['id'],
            'formatted_reference_id' => $formattedReferenceId,
            'code_id' => $report['code_id'],
            'code_label' => $report['code_label'],
            'code_description' => $report['code_description'],
            'location' => $report['location_id'],
            'reported_by' => $report['reported_by'],
            'details' => $report['details'],
            'report_time' => $report['report_time'],
            'status' => $report['status']
        ];
    }
    
    // Return the data
    echo json_encode([
        'success' => true,
        'reports' => $formattedReports,
        'pagination' => [
            'total' => (int)$totalCount,
            'limit' => $limit,
            'offset' => $offset,
            'hasMore' => ($offset + $limit < $totalCount)
        ]
    ]);
    
} catch (PDOException $e) {
    // Log the database error
    error_log('Database Error: ' . $e->getMessage());
    
    // Return a sanitized error response (don't expose detailed DB errors to client)
    http_response_code(500);
    echo json_encode([
        'success' => false,
        'error' => 'Database error occurred',
        'code' => 500
    ]);
} catch (Exception $e) {
    // Log general errors
    error_log('API Error: ' . $e->getMessage());
    
    // Return error response
    http_response_code(400);
    echo json_encode([
        'success' => false,
        'error' => $e->getMessage(),
        'code' => 400
    ]);
}