<?php
// This is a utility script to send notifications
// Could be called by your code that processes emergency codes

// Include the web push library
// You need to install this via Composer:
// composer require minishlink/web-push

require_once __DIR__ . '/vendor/autoload.php';
require_once "db-connection.php";

use Minishlink\WebPush\WebPush;
use Minishlink\WebPush\Subscription;

/**
 * Send notification to specific users based on code type
 * 
 * @param string $codeType The emergency code type (e.g., "CODE RED", "CODE BLUE")
 * @param string $location Where the emergency is happening
 * @param string $details Additional details about the emergency
 * @param array $userIds Array of user IDs to notify (or empty for all relevant staff)
 * @param bool $critical Whether this is a critical notification requiring attention
 * @return array Results of notification attempts
 */
function sendEmergencyNotification($codeType, $location, $details = '', $userIds = [], $critical = false) {
    global $pdo;
    
    // Your VAPID keys (same ones you generated earlier)
    $vapidKeys = [
        'publicKey' => 'YOUR_PUBLIC_VAPID_KEY',
        'privateKey' => 'YOUR_PRIVATE_VAPID_KEY',
        'subject' => 'mailto:emergency@yourhospital.com' // Change this to your email
    ];
    
    // Initialize WebPush
    $webPush = new WebPush($vapidKeys);
    
    // Create notification payload
    $payload = json_encode([
        'title' => "Emergency: $codeType",
        'body' => "Location: $location" . ($details ? "\n$details" : ""),
        'url' => "/view-emergency.php?code=" . urlencode($codeType) . "&location=" . urlencode($location),
        'codeType' => $codeType,
        'location' => $location,
        'critical' => $critical
    ]);
    
    try {
        // If specific user IDs provided, notify only those users
        if (!empty($userIds)) {
            $placeholders = str_repeat('?,', count($userIds) - 1) . '?';
            $sql = "SELECT * FROM push_subscriptions WHERE user_id IN ($placeholders)";
            $stmt = $pdo->prepare($sql);
            $stmt->execute($userIds);
        } else {
            // Otherwise, determine which users should receive this code type
            $sql = "SELECT ps.* FROM push_subscriptions ps 
                    JOIN user_notification_preferences unp ON ps.user_id = unp.user_id
                    WHERE unp.code_type = ? OR unp.code_type = 'ALL'";
            $stmt = $pdo->prepare($sql);
            $stmt->execute([$codeType]);
        }
        
        $subscriptions = $stmt->fetchAll(PDO::FETCH_ASSOC);
        $notificationResults = [];
        
        foreach ($subscriptions as $subscription) {
            // Convert database subscription to the format WebPush expects
            $webpushSubscription = Subscription::create([
                'endpoint' => $subscription['endpoint'],
                'keys' => [
                    'p256dh' => $subscription['p256dh'],
                    'auth' => $subscription['auth']
                ]
            ]);
            
            // Queue the notification
            $webPush->queueNotification($webpushSubscription, $payload);
        }
        
        // Send all queued notifications
        $results = $webPush->flush();
        
        // Process the results (optional)
        foreach ($results as $index => $result) {
            $endpoint = $subscriptions[$index]['endpoint'];
            $success = $result->isSuccess();
            
            if (!$success) {
                $error = $result->getReason();
                $statusCode = $result->getStatusCode();
                
                // If subscription is no longer valid (expired or unsubscribed)
                if ($statusCode === 410) {
                    // Remove the subscription from your database
                    $deleteSql = "DELETE FROM push_subscriptions WHERE endpoint = ?";
                    $deleteStmt = $pdo->prepare($deleteSql);
                    $deleteStmt->execute([$endpoint]);
                }
                
                $notificationResults[] = [
                    'endpoint' => $endpoint,
                    'user_id' => $subscriptions[$index]['user_id'],
                    'success' => false,
                    'error' => $error,
                    'statusCode' => $statusCode
                ];
            } else {
                $notificationResults[] = [
                    'endpoint' => $endpoint,
                    'user_id' => $subscriptions[$index]['user_id'],
                    'success' => true
                ];
            }
        }
        
        return [
            'success' => true,
            'results' => $notificationResults
        ];
        
    } catch (Exception $e) {
        error_log("Error sending notifications: " . $e->getMessage());
        return [
            'success' => false,
            'error' => $e->getMessage()
        ];
    }
}

// Example usage:
// $result = sendEmergencyNotification('CODE RED', 'Building B, 3rd Floor', 'Fire reported in electrical closet', [], true);
// print_r($result);
?>