<?php
// Enable error reporting for troubleshooting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    http_response_code(401);
    echo json_encode(['success' => false, 'error' => 'Unauthorized access']);
    exit;
} else if ($_SESSION["role"] !== "admin") {
    http_response_code(403);
    echo json_encode(['success' => false, 'error' => 'Forbidden: Admin access required']);
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Set content type for JSON response
header('Content-Type: application/json');

// Check if this is a POST request
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['success' => false, 'error' => 'Method not allowed']);
    exit;
}

try {
    // Get JSON data from the request
    $json = file_get_contents('php://input');
    $data = json_decode($json, true);
    
    // Validate input data
    if (!isset($data['report_id']) || !isset($data['status'])) {
        throw new Exception('Missing required parameters');
    }
    
    $reportId = (int)$data['report_id'];
    $status = $data['status'];
    $notes = isset($data['notes']) ? $data['notes'] : '';
    
    // Validate status
    $validStatuses = ['active', 'resolved', 'false_alarm'];
    if (!in_array($status, $validStatuses)) {
        throw new Exception('Invalid status value');
    }
    
    // Begin transaction
    $pdo->beginTransaction();
    
    // Update report status - do NOT use reference_id column, use id
    $updateQuery = "UPDATE code_reports SET status = ? WHERE id = ?";
    $updateStmt = $pdo->prepare($updateQuery);
    $updateStmt->execute([$status, $reportId]);
    
    // Check if the update affected any rows
    if ($updateStmt->rowCount() === 0) {
        throw new Exception('Report not found or no changes made');
    }
    
    // Insert status change log if notes are provided
    if (!empty($notes)) {
        $logQuery = "INSERT INTO status_logs (report_id, status, notes, updated_by, update_timestamp) 
                    VALUES (?, ?, ?, ?, NOW())";
        $logStmt = $pdo->prepare($logQuery);
        $logStmt->execute([
            $reportId,
            $status,
            $notes,
            $_SESSION["username"] ?? 'admin'
        ]);
    }
    
    // Commit transaction
    $pdo->commit();
    
    // Return success response
    echo json_encode([
        'success' => true,
        'message' => 'Status updated successfully',
        'report_id' => $reportId,
        'status' => $status
    ]);
    
} catch (Exception $e) {
    // Rollback transaction if it was started
    if (isset($pdo) && $pdo->inTransaction()) {
        $pdo->rollBack();
    }
    
    // Log the error (in a production environment)
    error_log('Status Update Error: ' . $e->getMessage());
    
    // Return error response
    http_response_code(500);
    echo json_encode([
        'success' => false,
        'error' => 'Failed to update status',
        'message' => $e->getMessage()
    ]);
}