<?php
// Start session
session_start();

// Check if user is logged in and has admin privileges
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true || $_SESSION["role"] !== "admin") {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'error' => 'Unauthorized access', 'code' => 401]);
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Set response headers
header('Content-Type: application/json');

// Only allow POST method
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['success' => false, 'error' => 'Method not allowed', 'code' => 405]);
    exit;
}

// Get JSON input
$input = json_decode(file_get_contents('php://input'), true);

// Check if report_id is provided
if (empty($input['report_id'])) {
    http_response_code(400); // Bad Request
    echo json_encode(['success' => false, 'error' => 'Report ID is required', 'code' => 400]);
    exit;
}

// Sanitize report ID
$reportId = (int)$input['report_id'];
if ($reportId <= 0) {
    http_response_code(400); // Bad Request
    echo json_encode(['success' => false, 'error' => 'Invalid Report ID', 'code' => 400]);
    exit;
}

try {
    // Begin transaction
    $pdo->beginTransaction();
    
    // First check if the report exists and get its reference ID
    $checkSql = "SELECT id, status FROM code_reports WHERE id = ?";
    $checkStmt = $pdo->prepare($checkSql);
    $checkStmt->execute([$reportId]);
    $report = $checkStmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$report) {
        throw new Exception("Report not found");
    }
    
    // Log the deletion to report_updates table instead of admin_logs
    // Since we know report_updates exists from your error message
    $logSql = "INSERT INTO report_updates (report_id, update_text, updated_by, user_id) VALUES (?, ?, ?, ?)";
    $logStmt = $pdo->prepare($logSql);
    $formattedRefId = 'ECR-' . str_pad($reportId, 6, '0', STR_PAD_LEFT);
    
    $logText = "Report deleted by administrator";
    
    $logStmt->execute([
        $reportId,
        $logText,
        $_SESSION["fullname"] ?? 'Administrator',
        $_SESSION["user_id"] ?? 0
    ]);
    
    // First delete related records to maintain referential integrity
    // Delete report updates if they exist (we just inserted a final log, but it will be deleted with cascade)
    $deleteUpdatesSql = "DELETE FROM report_updates WHERE report_id = ?";
    $deleteUpdatesStmt = $pdo->prepare($deleteUpdatesSql);
    $deleteUpdatesStmt->execute([$reportId]);
    
    // Check if status_logs table exists before trying to delete from it
    $checkTableSql = "SELECT COUNT(*) FROM information_schema.tables WHERE table_schema = DATABASE() AND table_name = 'status_logs'";
    $tableExists = $pdo->query($checkTableSql)->fetchColumn() > 0;
    
    if ($tableExists) {
        // Delete status logs if they exist
        $deleteStatusLogsSql = "DELETE FROM status_logs WHERE report_id = ?";
        $deleteStatusLogsStmt = $pdo->prepare($deleteStatusLogsSql);
        $deleteStatusLogsStmt->execute([$reportId]);
    }
    
    // Finally delete the report itself
    $deleteReportSql = "DELETE FROM code_reports WHERE id = ?";
    $deleteReportStmt = $pdo->prepare($deleteReportSql);
    $deleteReportStmt->execute([$reportId]);
    
    // Check if the delete affected any rows
    if ($deleteReportStmt->rowCount() === 0) {
        throw new Exception("Failed to delete report");
    }
    
    // Commit transaction
    $pdo->commit();
    
    // Return success response
    echo json_encode([
        'success' => true,
        'message' => 'Report deleted successfully',
        'report_id' => $reportId
    ]);
    
} catch (Exception $e) {
    // Rollback transaction on error
    if ($pdo->inTransaction()) {
        $pdo->rollBack();
    }
    
    // Log the error
    error_log('Delete Report Error: ' . $e->getMessage());
    
    // Return error response
    http_response_code(500);
    echo json_encode([
        'success' => false,
        'error' => 'Failed to delete report: ' . $e->getMessage(),
        'code' => 500
    ]);
}