<?php
// This is a standalone diagnostic script to identify database connection issues
// Put this in the same directory as your other PHP files

// Start with a clean output
error_reporting(E_ALL);
ini_set('display_errors', 1);

echo "<h1>Emergency Codes Database Diagnostic</h1>";

// Include your database connection
require_once 'db-connection.php';

echo "<h2>Connection Test</h2>";
try {
    // Test basic connection
    $test = $pdo->query("SELECT 1")->fetchColumn();
    echo "<p style='color:green'>✓ Database connection successful</p>";
} catch (PDOException $e) {
    echo "<p style='color:red'>✗ Database connection failed: " . htmlspecialchars($e->getMessage()) . "</p>";
    die("Please fix database connection before continuing.");
}

// Test if the emergency_codes table exists
echo "<h2>Table Structure Test</h2>";
try {
    $tables = $pdo->query("SHOW TABLES")->fetchAll(PDO::FETCH_COLUMN);
    
    echo "<p>Available tables in database:</p><ul>";
    foreach ($tables as $table) {
        echo "<li>" . htmlspecialchars($table) . "</li>";
    }
    echo "</ul>";
    
    $tableExists = in_array('emergency_codes', $tables);
    
    if ($tableExists) {
        echo "<p style='color:green'>✓ The 'emergency_codes' table exists</p>";
    } else {
        echo "<p style='color:red'>✗ The 'emergency_codes' table does not exist! Check table name case-sensitivity.</p>";
        
        // Try to find similar tables
        $similar = [];
        foreach ($tables as $table) {
            if (strtolower($table) == 'emergency_codes' || 
                stripos($table, 'emergency') !== false || 
                stripos($table, 'code') !== false) {
                $similar[] = $table;
            }
        }
        
        if (!empty($similar)) {
            echo "<p>Similar tables found that might contain your emergency codes:</p><ul>";
            foreach ($similar as $table) {
                echo "<li>" . htmlspecialchars($table) . "</li>";
            }
            echo "</ul>";
        }
    }
} catch (PDOException $e) {
    echo "<p style='color:red'>✗ Error checking tables: " . htmlspecialchars($e->getMessage()) . "</p>";
}

// If the table exists, check its structure
if (isset($tableExists) && $tableExists) {
    try {
        echo "<h2>Table Columns Test</h2>";
        $columns = $pdo->query("DESCRIBE emergency_codes")->fetchAll(PDO::FETCH_COLUMN);
        
        echo "<p>Columns in 'emergency_codes' table:</p><ul>";
        foreach ($columns as $column) {
            echo "<li>" . htmlspecialchars($column) . "</li>";
        }
        echo "</ul>";
        
        // Check for required columns
        $requiredColumns = ['code_value', 'label', 'description'];
        $missingColumns = [];
        
        foreach ($requiredColumns as $col) {
            if (!in_array($col, $columns)) {
                $missingColumns[] = $col;
            }
        }
        
        if (empty($missingColumns)) {
            echo "<p style='color:green'>✓ All required columns exist</p>";
        } else {
            echo "<p style='color:red'>✗ Missing required columns: " . implode(', ', $missingColumns) . "</p>";
        }
        
    } catch (PDOException $e) {
        echo "<p style='color:red'>✗ Error checking table structure: " . htmlspecialchars($e->getMessage()) . "</p>";
    }
}

// Try to count records
echo "<h2>Data Test</h2>";
try {
    if (isset($tableExists) && $tableExists) {
        $count = $pdo->query("SELECT COUNT(*) FROM emergency_codes")->fetchColumn();
        
        if ($count > 0) {
            echo "<p style='color:green'>✓ The 'emergency_codes' table contains {$count} records</p>";
            
            // Sample the data
            $sample = $pdo->query("SELECT * FROM emergency_codes LIMIT 3")->fetchAll(PDO::FETCH_ASSOC);
            
            echo "<p>Sample data:</p>";
            echo "<table border='1' cellpadding='5'>";
            
            // Headers
            echo "<tr>";
            foreach (array_keys($sample[0]) as $header) {
                echo "<th>" . htmlspecialchars($header) . "</th>";
            }
            echo "</tr>";
            
            // Data rows
            foreach ($sample as $row) {
                echo "<tr>";
                foreach ($row as $value) {
                    echo "<td>" . htmlspecialchars($value ?? 'NULL') . "</td>";
                }
                echo "</tr>";
            }
            
            echo "</table>";
            
        } else {
            echo "<p style='color:red'>✗ The 'emergency_codes' table exists but contains no records!</p>";
        }
    }
} catch (PDOException $e) {
    echo "<p style='color:red'>✗ Error querying data: " . htmlspecialchars($e->getMessage()) . "</p>";
}

// Test the actual query used in edit-user-page.php
echo "<h2>Specific Query Test</h2>";
try {
    $testQuery = "SELECT code_value, label, description FROM emergency_codes ORDER BY label";
    $stmt = $pdo->prepare($testQuery);
    $stmt->execute();
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    if (count($results) > 0) {
        echo "<p style='color:green'>✓ The query returns " . count($results) . " results</p>";
    } else {
        echo "<p style='color:red'>✗ The query returns no results!</p>";
        
        // Try alternative queries
        echo "<p>Trying alternative queries:</p>";
        
        $altQuery = "SELECT * FROM emergency_codes LIMIT 5";
        $stmt = $pdo->prepare($altQuery);
        $stmt->execute();
        $altResults = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        if (count($altResults) > 0) {
            echo "<p style='color:green'>✓ Alternative query returns results. The column names might be different.</p>";
            echo "<p>Column names in results: " . implode(', ', array_keys($altResults[0])) . "</p>";
        } else {
            echo "<p style='color:red'>✗ Alternative query also returns no results. The table is likely empty.</p>";
        }
    }
} catch (PDOException $e) {
    echo "<p style='color:red'>✗ Error with specific query: " . htmlspecialchars($e->getMessage()) . "</p>";
}

// Provide a fix based on findings
echo "<h2>Recommended Fix</h2>";
echo "<p>Based on the diagnostics above, here's what you should do:</p>";
echo "<ol>";

if (!isset($tableExists) || !$tableExists) {
    echo "<li>Your 'emergency_codes' table does not exist or has a different name. Check the table name case-sensitivity.</li>";
    if (!empty($similar)) {
        echo "<li>Try using one of these similar tables instead: " . implode(', ', $similar) . "</li>";
    }
} elseif (!empty($missingColumns)) {
    echo "<li>Your table is missing these columns: " . implode(', ', $missingColumns) . ". Update your query to use existing columns.</li>";
} elseif (isset($count) && $count == 0) {
    echo "<li>Your 'emergency_codes' table exists but is empty. You need to insert data into the table.</li>";
    echo "<li>You can use the SQL insert statements from your emergency_codes.sql file.</li>";
} elseif (isset($results) && count($results) == 0 && isset($altResults) && count($altResults) > 0) {
    echo "<li>The column names in your database don't match what's expected. Update your query to use: " . implode(', ', array_keys($altResults[0])) . "</li>";
} elseif (isset($results) && count($results) > 0) {
    echo "<li>The query works correctly in this test script but fails in your page. Check for code differences or variable scope issues.</li>";
} else {
    echo "<li>Check your db-connection.php file to ensure it connects to the correct database.</li>";
    echo "<li>Make sure your database user has SELECT permissions on the emergency_codes table.</li>";
}

echo "</ol>";

// Code replacement suggestion
echo "<h2>Code Replacement</h2>";
echo "<p>Replace your emergency codes query in edit-user-page.php with this:</p>";
echo "<pre>";
echo htmlspecialchars('
// Fetch emergency codes for team dropdown
try {
    // Try to get emergency codes
    $codesQuery = "SELECT * FROM emergency_codes ORDER BY id";
    $codesStmt = $pdo->query($codesQuery);
    $emergency_codes = $codesStmt->fetchAll(PDO::FETCH_ASSOC);
    
    if (empty($emergency_codes)) {
        error_log("Emergency codes query returned no results");
    }
} catch (PDOException $e) {
    error_log("Error fetching emergency codes: " . $e->getMessage());
    $emergency_codes = [];
}
');
echo "</pre>";

// Environment information
echo "<h2>Environment Information</h2>";
echo "<p>PHP Version: " . phpversion() . "</p>";
echo "<p>Server: " . $_SERVER['SERVER_SOFTWARE'] . "</p>";
echo "<p>Error Log Path: " . ini_get('error_log') . "</p>";
?>