<?php
// get-my-reports-api.php - Clean API endpoint with no HTML output
// Disable any output buffering
if (ob_get_level()) ob_end_clean();

// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'error' => 'Unauthorized']);
    exit;
}

// Set response headers - VERY IMPORTANT
header('Content-Type: application/json');
// Disable caching to prevent issues
header('Cache-Control: no-store, no-cache, must-revalidate, max-age=0');
header('Cache-Control: post-check=0, pre-check=0', false);
header('Pragma: no-cache');

// Get user information
$userId = $_SESSION["user_id"] ?? 0;

// Include database connection
require_once 'db-connection.php';

try {
    $limit = isset($_GET['limit']) ? (int)$_GET['limit'] : 20;
    $offset = isset($_GET['offset']) ? (int)$_GET['offset'] : 0;
    $status = isset($_GET['status']) ? $_GET['status'] : null;
    
    // Validate parameters
    if ($limit > 100) $limit = 100;
    if ($limit < 1) $limit = 1;
    if ($offset < 0) $offset = 0;
    
    // Use a two-step query approach to eliminate duplicates
    
    // Step 1: Get DISTINCT report IDs first with proper pagination
    // IMPORTANT: Filter by user_id to show only the current user's reports
    $idQuery = "
        SELECT DISTINCT id 
        FROM code_reports 
        WHERE user_id = ? 
    ";
    
    // Add status filter if needed
    $idParams = [$userId]; // Always filter by user ID
    if ($status) {
        $idQuery .= " AND status = ? ";
        $idParams[] = $status;
    }
    
    // Add sorting and pagination
    $idQuery .= "
        ORDER BY id DESC
        LIMIT ? OFFSET ?
    ";
    
    $idParams[] = $limit;
    $idParams[] = $offset;
    
    // Execute the first query to get distinct IDs
    $idStmt = $pdo->prepare($idQuery);
    $idStmt->execute($idParams);
    $ids = $idStmt->fetchAll(PDO::FETCH_COLUMN);
    
    // If no reports found, return empty array
    if (empty($ids)) {
        echo json_encode([
            'success' => true,
            'reports' => [],
            'pagination' => [
                'total' => 0,
                'limit' => $limit,
                'offset' => $offset,
                'hasMore' => false
            ]
        ]);
        exit;
    }
    
    // Step 2: Get full details for these specific IDs only
    // Create placeholders for the IN clause
    $placeholders = implode(',', array_fill(0, count($ids), '?'));
    
    // Build the second query that gets details for these IDs only
    $detailQuery = "
        SELECT 
            r.id,
            CONCAT('ECR-', LPAD(r.id, 6, '0')) AS formatted_reference_id,
            r.code_id,
            (SELECT label FROM emergency_codes WHERE code_value = r.code_id LIMIT 1) AS code_label,
            (SELECT description FROM emergency_codes WHERE code_value = r.code_id LIMIT 1) AS code_description,
            r.location_id AS location,
            r.reported_by,
            r.details,
            r.audio_file,
            DATE_FORMAT(r.report_timestamp, '%Y-%m-%d %H:%i:%s') AS report_time,
            r.status
        FROM 
            code_reports r
        WHERE 
            r.id IN ($placeholders)
        ORDER BY 
            r.id DESC
    ";
    
    // Execute the second query to get full report details
    $detailStmt = $pdo->prepare($detailQuery);
    $detailStmt->execute($ids); // Pass the IDs as parameters for the IN clause
    $reports = $detailStmt->fetchAll(PDO::FETCH_ASSOC);
    
    // Count total distinct reports for pagination (only for this user)
    $countQuery = "SELECT COUNT(DISTINCT id) FROM code_reports WHERE user_id = ?";
    $countParams = [$userId];
    
    if ($status) {
        $countQuery .= " AND status = ?";
        $countParams[] = $status;
    }
    
    $countStmt = $pdo->prepare($countQuery);
    $countStmt->execute($countParams);
    $totalCount = $countStmt->fetchColumn();
    
    // Return JSON response
    echo json_encode([
        'success' => true,
        'reports' => $reports,
        'pagination' => [
            'total' => (int)$totalCount,
            'limit' => $limit,
            'offset' => $offset,
            'hasMore' => ($offset + $limit < $totalCount)
        ]
    ]);
    
} catch (Exception $e) {
    // Log the error
    error_log('Database Error: ' . $e->getMessage());
    
    // Return error response
    http_response_code(500);
    echo json_encode([
        'success' => false,
        'error' => 'Database error: ' . $e->getMessage()
    ]);
}
exit; // Make sure no other output follows
?>