<?php
// Enable error reporting for troubleshooting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
} else if ($_SESSION["role"] !== "admin") {
    // Redirect non-admin users
    echo "<script>window.location.href = 'index.php';</script>";
    exit;
}

// For API requests
if (isset($_GET['api']) && $_GET['api'] === 'true') {
    // Include database connection
    require_once 'db-connection.php';
    
    // Set response headers
    header('Content-Type: application/json');
    
    try {
        // Prepare query parameters
        $limit = isset($_GET['limit']) ? (int)$_GET['limit'] : 20;
        $offset = isset($_GET['offset']) ? (int)$_GET['offset'] : 0;
        $status = isset($_GET['status']) ? $_GET['status'] : null;
        
        // Validate parameters
        if ($limit > 100) $limit = 100; // Maximum 100 records per request
        if ($limit < 1) $limit = 1;     // Minimum 1 record
        if ($offset < 0) $offset = 0;   // No negative offset
        
        // Build query with GROUP BY to ensure we get distinct reports
        $query = "
            SELECT DISTINCT
                r.id,
                CONCAT('ECR-', LPAD(r.id, 6, '0')) AS formatted_reference_id,
                e.label AS code_label,
                e.description AS code_description,
                r.location_id AS location,
                r.reported_by,
                r.details,
                r.audio_file,
                DATE_FORMAT(r.report_timestamp, '%Y-%m-%d %H:%i:%s') AS report_time,
                r.status
            FROM 
                code_reports r
            JOIN 
                emergency_codes e ON r.code_id = e.code_value
        ";
        
        // Add filters
        $params = [];
        if ($status) {
            $query .= " WHERE r.status = ?";
            $params[] = $status;
        }
        
        // Add sorting and ensure we get unique records
        $query .= " GROUP BY r.id ORDER BY r.id DESC";
        
        // Add pagination
        $query .= " LIMIT ? OFFSET ?";
        $params[] = $limit;
        $params[] = $offset;
        
        // Execute the query
        $stmt = $pdo->prepare($query);
        $stmt->execute($params);
        
        // Fetch all records
        $reports = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // Count total DISTINCT records for pagination
        $countQuery = "SELECT COUNT(DISTINCT id) FROM code_reports";
        if ($status) {
            $countQuery .= " WHERE status = ?";
            $countStmt = $pdo->prepare($countQuery);
            $countStmt->execute([$status]);
        } else {
            $countStmt = $pdo->query($countQuery);
        }
        $totalCount = $countStmt->fetchColumn();
        
        // Return the data
        echo json_encode([
            'success' => true,
            'reports' => $reports,
            'pagination' => [
                'total' => (int)$totalCount,
                'limit' => $limit,
                'offset' => $offset,
                'hasMore' => ($offset + $limit < $totalCount)
            ]
        ]);
        
    } catch (Exception $e) {
        // Log the error (in a production environment)
        error_log('Database Error: ' . $e->getMessage());
        
        // Return error response
        http_response_code(500); // Internal Server Error
        echo json_encode([
            'error' => 'Failed to retrieve reports',
            'message' => $e->getMessage(),
            'success' => false
        ]);
    }
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Emergency Code Reports - Admin Panel</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
</head>



<body class="bg-gray-100 min-h-screen flex flex-col">
    
    
    
    
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">KSUMC Hospital Emergency Code Reports</h1>
            <div class="flex items-center space-x-4">
                
                
                
                <a href="user-manager.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Manage Users</a>
                
                
                
                
                
                        <a href="manage-emergency-codes.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Manage Codes</a>
                
                
                  <a href="manage-emergency-codes.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Locations</a>
                
                
                
                
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"] ?? 'Admin'); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
                
                
                
                
                
                
            </div>

            
            
            
            
            
            
        </div>
    </header>
    
    
    
    
    
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <div class="bg-white rounded-lg shadow p-6">
                <div class="flex justify-between items-center mb-6">
                    <h2 class="text-xl font-bold text-gray-800">Emergency Reports</h2>
                    <div class="flex space-x-2">
                        <a href="index.php" class="bg-red-500 hover:bg-red-600 text-white px-4 py-2 rounded">
                            New Report
                        </a>
                        <select id="status-filter" class="border border-gray-300 rounded px-3 py-1 focus:outline-none focus:ring-2 focus:ring-red-500">
                            <option value="">All Reports</option>
                            <option value="active">Active</option>
                            <option value="resolved">Resolved</option>
                            <option value="false_alarm">False Alarm</option>
                        </select>
                        <button id="refresh-btn" class="bg-blue-500 hover:bg-blue-600 text-white px-3 py-1 rounded">
                            Refresh
                        </button>
                    </div>
                </div>
                
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-200">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Report ID</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Code</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Location</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Reported By</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Time</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                            </tr>
                        </thead>
                        <tbody id="reports-table-body" class="bg-white divide-y divide-gray-200">
                            <tr>
                                <td colspan="7" class="px-6 py-4 text-center text-gray-500">Loading reports...</td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                
                <div class="mt-4 flex justify-between items-center">
                    <div class="text-sm text-gray-500" id="reports-count">
                        Loading...
                    </div>
                    <div class="flex space-x-2">
                        <button id="prev-page" class="px-3 py-1 border border-gray-300 rounded disabled:opacity-50">
                            Previous
                        </button>
                        <button id="next-page" class="px-3 py-1 border border-gray-300 rounded disabled:opacity-50">
                            Next
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
    
    <!-- Report details modal -->
    <div id="report-modal" class="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center hidden">
        <div class="bg-white rounded-lg max-w-2xl w-full p-6 max-h-screen overflow-auto">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-bold" id="modal-title">Report Details</h3>
                <button id="close-modal" class="text-gray-500 hover:text-gray-700">
                    <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12"></path>
                    </svg>
                </button>
            </div>
            <div id="modal-content">
                <!-- Report details will be loaded here -->
            </div>
            <div class="mt-4 pt-4 border-t border-gray-200">
                <h4 class="font-bold mb-2">Update Status</h4>
                <div class="flex space-x-2">
                    <select id="status-update" class="border border-gray-300 rounded px-3 py-2 focus:outline-none focus:ring-2 focus:ring-red-500 flex-grow">
                        <option value="active">Active</option>
                        <option value="resolved">Resolved</option>
                        <option value="false_alarm">False Alarm</option>
                    </select>
                    <button id="update-status-btn" class="bg-green-500 hover:bg-green-600 text-white px-4 py-2 rounded" data-report-id="">
                        Update
                    </button>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Include the JavaScript files -->
    <script src="js/pagination.js"></script>
    <script src="js/announcement-player.js"></script>
</body>
</html>