/**
 * Hospital Emergency Code Announcement Player
 * 
 * This file handles the playback of emergency code announcements
 * using the Web Speech API.
 */

// Function to play attention sound to precede announcements
function playAttentionSound() {
    return new Promise((resolve) => {
        try {
            const audioContext = new (window.AudioContext || window.webkitAudioContext)();
            const oscillator = audioContext.createOscillator();
            const gainNode = audioContext.createGain();
            
            oscillator.type = 'sine';
            oscillator.frequency.setValueAtTime(880, audioContext.currentTime); // A5 note
            
            // Fade in/out to avoid clicks
            gainNode.gain.setValueAtTime(0, audioContext.currentTime);
            gainNode.gain.linearRampToValueAtTime(0.5, audioContext.currentTime + 0.1);
            gainNode.gain.linearRampToValueAtTime(0, audioContext.currentTime + 0.8);
            
            oscillator.connect(gainNode);
            gainNode.connect(audioContext.destination);
            
            oscillator.start();
            oscillator.stop(audioContext.currentTime + 0.9);
            
            // Resolve after sound finishes
            setTimeout(resolve, 1000);
        } catch (error) {
            console.error("Error playing attention sound:", error);
            resolve(); // Continue even if sound fails
        }
    });
}

// Function to get best available voice for announcements
function getBestAvailableVoice() {
    const voices = window.speechSynthesis.getVoices();
    
    // Try to find a premium/enhanced voice
    const premiumVoice = voices.find(voice => 
        (voice.name.includes('Premium') || voice.name.includes('Enhanced')) && 
        voice.lang.startsWith('en')
    );
    
    if (premiumVoice) return premiumVoice;
    
    // Try specific high-quality voices by name
    const knownGoodVoices = [
        'Google US English Male',
        'Microsoft David',
        'Microsoft Mark',
        'Daniel',
        'Google UK English Male'
    ];
    
    for (const voiceName of knownGoodVoices) {
        const voice = voices.find(v => v.name.includes(voiceName));
        if (voice) return voice;
    }
    
    // Try any male English voice
    const maleEnglishVoice = voices.find(voice => 
        voice.lang.startsWith('en') && 
        (voice.name.includes('Male') || !voice.name.includes('Female'))
    );
    
    if (maleEnglishVoice) return maleEnglishVoice;
    
    // Fall back to any English voice
    const anyEnglishVoice = voices.find(voice => voice.lang.startsWith('en'));
    
    if (anyEnglishVoice) return anyEnglishVoice;
    
    // Last resort: any available voice
    return voices[0];
}

// Function to speak text with proper parameters
function speak(text) {
    return new Promise((resolve) => {
        const utterance = new SpeechSynthesisUtterance(text);
        const voice = getBestAvailableVoice();
        
        // Optimize speech parameters
        utterance.rate = 0.9;     // Slightly slower for clarity
        utterance.pitch = 1.0;    // Natural pitch
        utterance.volume = 1.0;   // Maximum volume
        
        if (voice) {
            utterance.voice = voice;
        }
        
        // Set up event handlers
        utterance.onend = () => {
            resolve();
        };
        
        utterance.onerror = (e) => {
            console.error("Speech synthesis error:", e);
            resolve();
        };
        
        // Start speaking
        window.speechSynthesis.speak(utterance);
    });
}

// Main function to play the emergency code announcement
async function playAnnouncement(codeLabel, codeDescription, location, details) {
    // Get the button for UI updates
    const playBtn = document.getElementById('play-announcement-btn');
    if (playBtn) {
        playBtn.disabled = true;
        playBtn.innerHTML = '<svg class="animate-spin -ml-1 mr-2 h-4 w-4 text-white inline-block" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"><circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle><path class="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path></svg> Playing...';
    }
    
    try {
        // Cancel any ongoing speech
        window.speechSynthesis.cancel();
        
        // Format the announcement text
        const announcementText = `Attention all staff. ${codeLabel}. ${codeDescription}. Has been reported in ${location}.`;
        const detailsText = details ? `Additional details: ${details}.` : '';
        const repetitionText = `Repeating: ${codeLabel} in ${location}.`;
        
        // Play attention sound before first announcement
        await playAttentionSound();
        
        // First full announcement
        await speak(announcementText + ' ' + detailsText);
        
        // Short pause
        await new Promise(resolve => setTimeout(resolve, 1000));
        
        // Second announcement (with attention sound)
        await playAttentionSound();
        await speak("Repeating announcement.");
        await speak(repetitionText);
        
    } catch (error) {
        console.error("Error during announcement:", error);
    } finally {
        // Reset play button state
        if (playBtn) {
            playBtn.disabled = false;
            playBtn.innerHTML = `
                <svg class="w-4 h-4 mr-1 inline-block" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.752 11.168l-3.197-2.132A1 1 0 0010 9.87v4.263a1 1 0 001.555.832l3.197-2.132a1 1 0 000-1.664z"></path>
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
                </svg>
                Play Announcement
            `;
        }
    }
}

// Simple fallback function for browsers without Web Speech API
function playSimpleAnnouncement(codeLabel, codeDescription, location, details) {
    alert(`Emergency Announcement: ${codeLabel} - ${codeDescription} in ${location}`);
    
    // Reset button state
    const playBtn = document.getElementById('play-announcement-btn');
    if (playBtn) {
        playBtn.disabled = false;
        playBtn.innerHTML = `
            <svg class="w-4 h-4 mr-1 inline-block" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.752 11.168l-3.197-2.132A1 1 0 0010 9.87v4.263a1 1 0 001.555.832l3.197-2.132a1 1 0 000-1.664z"></path>
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
            </svg>
            Play Announcement
        `;
    }
}

// Initialize speech synthesis when the page loads
document.addEventListener('DOMContentLoaded', function() {
    // Check if browser supports speech synthesis
    if (!('speechSynthesis' in window)) {
        console.warn("This browser does not support speech synthesis");
        
        // Replace playAnnouncement with the simple version
        window.playAnnouncement = playSimpleAnnouncement;
        return;
    }
    
    // Load voices (needed for Chrome)
    window.speechSynthesis.getVoices();
    
    // Set up voice changed event (for Chrome)
    if (window.speechSynthesis.onvoiceschanged !== undefined) {
        window.speechSynthesis.onvoiceschanged = function() {
            console.log("Speech synthesis voices loaded: " + window.speechSynthesis.getVoices().length);
        };
    }
    
    // Make playAnnouncement globally available
    window.playAnnouncement = playAnnouncement;
});