// Main Emergency Code Reporter Component

// Define component - Get user info from the global variables properly
const EmergencyCodeReporter = () => {
  // Access user info from the global variables defined in index.php
  // Avoid using optional chaining (?.) for older browsers
  const userId = window.userInfo && window.userInfo.userId ? window.userInfo.userId : '';
  const fullname = window.userInfo && window.userInfo.fullname ? window.userInfo.fullname : '';
  const userRole = window.userInfo && window.userInfo.role ? window.userInfo.role : ''; // Get user role
  const requestId = window.currentRequestId || '';

  const [formData, setFormData] = React.useState({
    codeType: '',
    location: '',
    selectedBuilding: '',
    reportedBy: fullname, // Pre-fill with user's full name
    details: ''
  });
  const [isSubmitting, setIsSubmitting] = React.useState(false);
  const [submitSuccess, setSubmitSuccess] = React.useState(false);
  const [error, setError] = React.useState('');
  const [voicesLoaded, setVoicesLoaded] = React.useState(false);
  const [audioContext, setAudioContext] = React.useState(null);

  // Log the userInfo to help with debugging
  React.useEffect(() => {
    console.log('Component mounted with user info:', {
      userId,
      fullname,
      userRole,
      requestId
    });
  }, []);

  const emergencyCodes = [
    { 
      value: 'code-red', 
      label: 'CODE RED', 
      description: 'Fire',
      arabicText: 'حريق',
      bgColor: '#FF3333', 
      textColor: 'white' 
    },
    { 
      value: 'code-yellow', 
      label: 'CODE YELLOW', 
      description: 'External Disaster',
      arabicText: 'الكوارث الخارجية',
      bgColor: '#FFDC46', 
      textColor: 'black' 
    },
    { 
      value: 'code-black', 
      label: 'CODE BLACK', 
      description: 'BOMB THREAT',
      arabicText: 'التهديد بزرع قنبلة',
      bgColor: '#000000', 
      textColor: 'white' 
    },
    { 
      value: 'code-orange', 
      label: 'CODE ORANGE', 
      description: 'Chemical, Radioactive, Biological Spill',
      arabicText: 'تسرب بيولوجي،كيميائي،إشعاعي',
      bgColor: '#FF9966', 
      textColor: 'white' 
    }
  ];

  const locations = [
    'Emergency Room',
    'ICU',
    'Surgery Center',
    'Pediatrics',
    'Radiology',
    'Laboratory',
    'Cafeteria',
    'Administration',
    'Main Entrance',
    'Parking Garage'
  ];

  const buildings = [
    'Main Hospital Building',
    'Emergency Department',
    'Outpatient Clinic',
    'Surgical Center',
    'Administrative Building',
    'Research Wing'
  ];

  // Fetch buildings from the database if needed
  React.useEffect(() => {
    // This could be extended to fetch buildings from the server
    // For now, we use the static list above
  }, []);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData(function(prev) {
      return Object.assign({}, prev, { [name]: value });
    });
  };

  // Initialize audio context on user interaction
  const initializeAudioContext = () => {
    if (!audioContext) {
      try {
        const newContext = new (window.AudioContext || window.webkitAudioContext)();
        setAudioContext(newContext);
        console.log("Audio context initialized:", newContext);
        return newContext;
      } catch (e) {
        console.error("Failed to initialize AudioContext:", e);
        return null;
      }
    }
    return audioContext;
  };

  // Ensure audio context is running (needed for mobile)
  const ensureAudioContextRunning = async (context) => {
    if (context && context.state !== 'running') {
      try {
        await context.resume();
        console.log('AudioContext resumed successfully');
      } catch (e) {
        console.error('Failed to resume AudioContext:', e);
      }
    }
  };

  // Generate text for audio announcement
  const generateAnnouncementText = () => {
    const selectedCode = emergencyCodes.find(function(code) { 
      return code.value === formData.codeType;
    });
    const codeLabel = selectedCode ? selectedCode.label : 'Emergency Code';
    const codeDescription = selectedCode ? selectedCode.description : '';
    
    let textToAudio = codeLabel + " ";
    
    if (formData.selectedBuilding) {
      textToAudio += formData.selectedBuilding + " ";
    }
    
    textToAudio += formData.location + " ";
    
    if (formData.details) {
      textToAudio += formData.details;
    }
    
    return textToAudio;
  };

  // Play the announcement
  const playAnnouncementAudio = async () => {
    try {
      const ctx = initializeAudioContext();
      if (!ctx) {
        console.warn("No audio context available");
        return;
      }
      
      await ensureAudioContextRunning(ctx);
      
      // Get the announcement text
      const text = generateAnnouncementText();
      console.log("Announcement text:", text);
      
      // Use browser's speech synthesis if available
      if ('speechSynthesis' in window) {
        // Cancel any ongoing speech
        window.speechSynthesis.cancel();
        
        // Create a speech synthesis utterance
        const speech = new SpeechSynthesisUtterance(text);
        speech.rate = 0.9; // slightly slower for clarity
        speech.volume = 1.0;
        
        // Try to get a good voice
        const voices = window.speechSynthesis.getVoices();
        const englishVoice = voices.find(function(voice) { 
          return voice.lang.startsWith('en') && voice.name.includes('Male');
        }) || voices.find(function(voice) { 
          return voice.lang.startsWith('en');
        }) || voices[0];
        
        if (englishVoice) {
          speech.voice = englishVoice;
        }
        
        // Speak the text
        window.speechSynthesis.speak(speech);
      } else {
        console.warn("Speech synthesis not available in this browser");
      }
      
      // Also play an attention tone
      try {
        const oscillator = ctx.createOscillator();
        const gainNode = ctx.createGain();
        
        oscillator.type = 'sine';
        oscillator.frequency.setValueAtTime(880, ctx.currentTime); // A5 note
        
        gainNode.gain.setValueAtTime(0, ctx.currentTime);
        gainNode.gain.linearRampToValueAtTime(0.3, ctx.currentTime + 0.1);
        gainNode.gain.linearRampToValueAtTime(0, ctx.currentTime + 0.8);
        
        oscillator.connect(gainNode);
        gainNode.connect(ctx.destination);
        
        oscillator.start();
        oscillator.stop(ctx.currentTime + 0.9);
      } catch (e) {
        console.error("Error playing attention sound:", e);
      }
    } catch (e) {
      console.error("Error in playAnnouncementAudio:", e);
    }
  };

  // Submit data to the server
  const submitToDatabase = async () => {
    try {
      console.log("Submitting form data:", formData);
      
      // Generate text for audio announcement
      const textToAudio = generateAnnouncementText();
      
      // Prepare data for submission
      const data = {
        codeType: formData.codeType,
        location: formData.location,
        selectedBuilding: formData.selectedBuilding,
        reportedBy: formData.reportedBy,
        details: formData.details,
        textToAudio: textToAudio,
        requestId: requestId
      };
      
      console.log("Sending data to server:", data);
      
      // Send the data to our PHP backend
      const response = await fetch('save-report.php', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify(data)
      });
      
      console.log("Server response status:", response.status);
      
      // Get the raw response text first for debugging
      const responseText = await response.text();
      console.log("Raw server response:", responseText);
      
      // Parse the JSON response (might fail if invalid JSON)
      let result;
      try {
        result = JSON.parse(responseText);
      } catch (e) {
        console.error("Error parsing JSON response:", e);
        throw new Error("Invalid response from server: " + responseText.substring(0, 100));
      }
      
      // Check if the request was successful
      if (!response.ok) {
        throw new Error(result.message || 'Failed to save report to database');
      }
      
      console.log('Report saved with ID:', result.reportId);
      return result;
    } catch (error) {
      console.error('Error submitting report:', error);
      throw error;
    }
  };

  // Handle redirects based on user role
  const handleRedirect = (reportId) => {
    console.log("Handling redirect for role:", userRole, "Report ID:", reportId);
    
    // Store report details in sessionStorage for thank you page
    const reportDetails = {
      id: reportId,
      codeType: formData.codeType,
      location: formData.location,
      building: formData.selectedBuilding,
      details: formData.details,
      timestamp: new Date().toISOString()
    };
    sessionStorage.setItem('lastReport', JSON.stringify(reportDetails));
    
    // Admin users go to the reports list page
    if (userRole === 'admin') {
      // Brief delay to allow announcement to play
      setTimeout(function() {
        window.location.href = 'get-reports.php';
      }, 3000);
    } else {
      // Other users go to the thank you page
      setTimeout(function() {
        window.location.href = 'thank-you.php';
      }, 3000);
    }
  };

  // Handle form submission
  const handleSubmit = async (e) => {
    e.preventDefault();
    setIsSubmitting(true);
    setError('');
    
    // Basic validation
    if (!formData.codeType) {
      setError('Please select an emergency code type');
      setIsSubmitting(false);
      return;
    }
    
    if (!formData.location) {
      setError('Please select a location');
      setIsSubmitting(false);
      return;
    }
    
    if (!formData.reportedBy) {
      setError('Please enter your name');
      setIsSubmitting(false);
      return;
    }
    
    try {
      // Initialize audio for mobile
      if (!audioContext) {
        initializeAudioContext();
      }
      
      // Submit data to database
      const result = await submitToDatabase();
      
      if (result.success) {
        // Show success state
        setSubmitSuccess(true);
        
        // Play the announcement
        try {
          await playAnnouncementAudio();
        } catch (audioErr) {
          console.error("Error playing announcement:", audioErr);
        }
        
        // Handle redirect based on user role
        handleRedirect(result.reportId);
      } else {
        setError(result.message || 'Unknown error occurred');
      }
    } catch (err) {
      console.error("Submission error:", err);
      setError(err.message || 'Failed to submit the emergency code. Please try again.');
    } finally {
      setIsSubmitting(false);
    }
  };

  return (
    React.createElement("div", { className: "flex flex-col min-h-screen bg-gray-100" },
      React.createElement("main", { className: "flex-grow p-4" },
        submitSuccess ? 
          React.createElement("div", { className: "bg-green-100 border border-green-400 text-green-700 px-4 py-3 rounded relative mb-4" },
            React.createElement("strong", { className: "font-bold" }, "Success!"),
            React.createElement("span", { className: "block sm:inline" }, " Emergency code has been reported and announced."),
            React.createElement("div", { className: "mt-2" },
              React.createElement("p", null, "Redirecting you ", userRole === 'admin' ? 'to reports page' : 'to confirmation page', "..."),
              React.createElement("div", { className: "mt-2 w-full h-2 bg-gray-200 rounded-full overflow-hidden" },
                React.createElement("div", { className: "bg-green-500 h-full animate-pulse", style: {width: '100%'} })
              )
            )
          ) : 
          React.createElement("div", { className: "bg-white rounded-lg shadow-md p-6" },
            React.createElement("div", { className: "mb-6" },
              React.createElement("div", { className: "mb-4" },
                React.createElement("h2", { className: "text-xl font-bold flex items-center" },
                  React.createElement("span", { className: "bg-blue-500 text-white rounded-full w-6 h-6 inline-flex items-center justify-center mr-2" }, "1"),
                  React.createElement("span", null, "Code")
                )
              ),
              
              React.createElement("div", { className: "grid grid-cols-1 md:grid-cols-2 gap-4" },
                emergencyCodes.map(function(code, index) {
                  const letter = String.fromCharCode(65 + index);
                  
                  return React.createElement("div", {
                    key: code.value,
                    className: "border rounded-md overflow-hidden cursor-pointer " + (formData.codeType === code.value ? 'ring-2 ring-blue-500' : ''),
                    onClick: function() { 
                      setFormData(function(prev) { 
                        return Object.assign({}, prev, { codeType: code.value });
                      });
                    }
                  },
                    React.createElement("div", {
                      className: "p-4 text-center flex flex-col items-center justify-center",
                      style: { 
                        backgroundColor: code.bgColor, 
                        color: code.textColor,
                        height: "260px"
                      }
                    },
                      React.createElement("div", { className: "text-xl font-semibold mb-2 arabic-text", style: { fontSize: '20px' } }, code.arabicText),
                      React.createElement("div", { className: "text-6xl font-bold my-3" }, code.label.split(' ')[1]),
                      React.createElement("div", { className: "text-xl" }, code.description)
                    ),
                    React.createElement("div", { className: "bg-gray-100 px-4 py-2" },
                      React.createElement("div", { className: "flex items-center" },
                        React.createElement("span", { className: "inline-flex items-center justify-center border border-gray-400 rounded-full w-6 h-6 mr-2" }, letter),
                        React.createElement("span", { className: "font-bold" }, code.label)
                      )
                    )
                  );
                })
              )
            ),
            
            React.createElement("form", { onSubmit: handleSubmit },
              React.createElement("input", {
                type: "hidden",
                name: "codeType",
                value: formData.codeType,
                required: true
              }),
              
              React.createElement("div", { className: "mb-4" },
                React.createElement("label", { className: "block text-gray-700 font-bold mb-2", htmlFor: "location" }, "Location *"),
                React.createElement("select", {
                  id: "location",
                  name: "location",
                  value: formData.location,
                  onChange: handleChange,
                  required: true,
                  className: "w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500"
                },
                  React.createElement("option", { value: "" }, "Select Location"),
                  locations.map(function(location) {
                    return React.createElement("option", { key: location, value: location }, location);
                  })
                )
              ),
              
              React.createElement("div", { className: "mb-4" },
                React.createElement("label", { className: "block text-gray-700 font-bold mb-2", htmlFor: "selectedBuilding" }, "Building"),
                React.createElement("select", {
                  id: "selectedBuilding",
                  name: "selectedBuilding",
                  value: formData.selectedBuilding,
                  onChange: handleChange,
                  className: "w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500"
                },
                  React.createElement("option", { value: "" }, "Select Building (Optional)"),
                  buildings.map(function(building) {
                    return React.createElement("option", { key: building, value: building }, building);
                  })
                )
              ),
              
              React.createElement("div", { className: "mb-4" },
                React.createElement("label", { className: "block text-gray-700 font-bold mb-2", htmlFor: "reportedBy" }, "Reported By *"),
                React.createElement("input", {
                  id: "reportedBy",
                  name: "reportedBy",
                  type: "text",
                  value: formData.reportedBy,
                  onChange: handleChange,
                  required: true,
                  className: "w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500",
                  placeholder: "Your name"
                })
              ),
              
              React.createElement("div", { className: "mb-6" },
                React.createElement("label", { className: "block text-gray-700 font-bold mb-2", htmlFor: "details" }, "Additional Details"),
                React.createElement("textarea", {
                  id: "details",
                  name: "details",
                  value: formData.details,
                  onChange: handleChange,
                  className: "w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500",
                  rows: "3",
                  placeholder: "Enter any additional details about the emergency"
                })
              ),
              
              error && React.createElement("div", { className: "bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative mb-4" },
                React.createElement("span", { className: "block sm:inline" }, error)
              ),
              
              React.createElement("div", { className: "flex items-center justify-center" },
                React.createElement("button", {
                  type: "submit",
                  disabled: isSubmitting,
                  className: "bg-red-600 hover:bg-red-700 text-white font-bold py-3 px-6 rounded-full focus:outline-none focus:shadow-outline w-full max-w-xs " + (isSubmitting ? 'opacity-50 cursor-not-allowed' : '')
                }, isSubmitting ? 'Submitting...' : 'REPORT EMERGENCY CODE')
              )
            )
          )
      )
    )
  );
};

// Wait for the DOM to be fully loaded
document.addEventListener('DOMContentLoaded', function() {
  // Make sure the root element exists
  const rootElement = document.getElementById('root');
  if (rootElement) {
    console.log('Root element found, rendering EmergencyCodeReporter component');
    
    // Check if userInfo is available
    if (window.userInfo) {
      console.log('userInfo found:', window.userInfo);
    } else {
      console.warn('userInfo not found in window object');
    }
    
    // Render the component with a try-catch to handle errors
    try {
      ReactDOM.render(
        React.createElement(EmergencyCodeReporter, null),
        rootElement
      );
    } catch (error) {
      console.error('Error rendering React component:', error);
      rootElement.innerHTML = `
        <div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative">
          <strong class="font-bold">Error!</strong>
          <span class="block sm:inline"> Failed to load the form. Please try refreshing the page.</span>
          <p class="mt-2">Error details: ${error.message}</p>
        </div>
      `;
    }
  } else {
    console.error('Root element not found in the DOM');
  }
});