/**
 * Modal Handler for Emergency Code Reports
 * Manages the report details modal functionality and delete confirmation
 */

class ModalHandler {
    constructor() {
        // Report details modal elements
        this.modal = document.getElementById('report-modal');
        this.closeModalBtn = document.getElementById('close-modal');
        this.modalContent = document.getElementById('modal-content');
        this.modalTitle = document.getElementById('modal-title');
        this.statusUpdate = document.getElementById('status-update');
        this.updateStatusBtn = document.getElementById('update-status-btn');
        
        // Delete confirmation modal elements
        this.deleteModal = document.getElementById('delete-modal');
        this.deleteModalTitle = document.getElementById('delete-modal-title');
        this.deleteModalMessage = document.getElementById('delete-modal-message');
        this.cancelDeleteBtn = document.getElementById('cancel-delete');
        this.confirmDeleteBtn = document.getElementById('confirm-delete');
        
        // Delete API endpoint
        this.deleteEndpoint = 'delete-report.php';
        
        // Setup event listeners
        this.setupEventListeners();
    }
    
    setupEventListeners() {
        // Close details modal when clicking the close button
        if (this.closeModalBtn) {
            this.closeModalBtn.addEventListener('click', () => this.hideModal());
        }
        
        // Close details modal when clicking outside
        if (this.modal) {
            this.modal.addEventListener('click', (event) => {
                if (event.target === this.modal) {
                    this.hideModal();
                }
            });
        }
        
        // Handle status update
        if (this.updateStatusBtn) {
            this.updateStatusBtn.addEventListener('click', async () => {
                await this.updateReportStatus();
            });
        }
        
        // Delete confirmation modal handlers
        if (this.cancelDeleteBtn) {
            this.cancelDeleteBtn.addEventListener('click', () => this.hideDeleteModal());
        }
        
        if (this.confirmDeleteBtn) {
            this.confirmDeleteBtn.addEventListener('click', async () => {
                await this.deleteReport();
            });
        }
        
        if (this.deleteModal) {
            this.deleteModal.addEventListener('click', (event) => {
                if (event.target === this.deleteModal) {
                    this.hideDeleteModal();
                }
            });
        }
        
        // Close modals with Escape key
        document.addEventListener('keydown', (event) => {
            if (event.key === 'Escape') {
                if (this.modal && !this.modal.classList.contains('hidden')) {
                    this.hideModal();
                }
                if (this.deleteModal && !this.deleteModal.classList.contains('hidden')) {
                    this.hideDeleteModal();
                }
            }
        });
    }
    
    // Show the details modal with report details
    showReportDetails(report) {
        if (!this.modal || !this.modalTitle || !this.modalContent) {
            console.error('Modal elements not found');
            return;
        }
        
        this.modalTitle.textContent = `${report.code_label} Report`;
        
        // Format reference ID if not already formatted
        const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
        
        // Create modal content with all report details
        this.modalContent.innerHTML = `
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <p class="text-gray-500 text-sm">Report ID</p>
                    <p class="font-medium text-blue-600">${formattedRefId}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Code</p>
                    <p class="font-medium">${report.code_label}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Location</p>
                    <p class="font-medium">${report.location}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Reported By</p>
                    <p class="font-medium">${report.reported_by}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Time</p>
                    <p class="font-medium">${this.formatDate(report.report_time)}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Status</p>
                    <p class="font-medium">${this.getStatusBadge(report.status)}</p>
                </div>
                <div class="col-span-2">
                    <p class="text-gray-500 text-sm">Details</p>
                    <p class="font-medium">${report.details || 'No additional details provided'}</p>
                </div>
            </div>
            
            <div class="mt-4 pt-4 border-t border-gray-200">
                <h4 class="font-bold mb-2">Status Notes</h4>
                <textarea id="status-notes" class="w-full px-3 py-2 border border-gray-300 rounded-md" 
                          rows="2" placeholder="Add notes about this status change (optional)"></textarea>
            </div>
        `;
        
        // Set current status in the dropdown
        if (this.statusUpdate) {
            this.statusUpdate.value = report.status;
        }
        
        // Set report ID for the update button
        if (this.updateStatusBtn) {
            this.updateStatusBtn.setAttribute('data-report-id', report.id);
        }
        
        // Show modal
        this.modal.classList.remove('hidden');
    }
    
    // Show delete confirmation modal
    showDeleteConfirmation(reportId, reportRef) {
        if (!this.deleteModal || !this.deleteModalTitle || !this.deleteModalMessage || !this.confirmDeleteBtn) {
            console.error('Delete modal elements not found');
            return;
        }
        
        this.deleteModalTitle.textContent = 'Confirm Deletion';
        this.deleteModalMessage.textContent = `Are you sure you want to delete report ${reportRef}? This action cannot be undone.`;
        
        // Set report ID for the delete button
        this.confirmDeleteBtn.setAttribute('data-report-id', reportId);
        
        // Show the delete modal
        this.deleteModal.classList.remove('hidden');
    }
    
    // Hide modals
    hideModal() {
        if (this.modal) {
            this.modal.classList.add('hidden');
        }
    }
    
    hideDeleteModal() {
        if (this.deleteModal) {
            this.deleteModal.classList.add('hidden');
        }
    }
    
    // Format date helper
    formatDate(dateString) {
        try {
            const options = { 
                year: 'numeric', 
                month: 'short', 
                day: 'numeric',
                hour: '2-digit',
                minute: '2-digit'
            };
            return new Date(dateString).toLocaleDateString(undefined, options);
        } catch (e) {
            console.error("Date formatting error:", e);
            return dateString; // Return original string if formatting fails
        }
    }
    
    // Get status badge HTML
    getStatusBadge(status) {
        let color = '';
        switch(status) {
            case 'active':
                color = 'bg-yellow-100 text-yellow-800';
                break;
            case 'resolved':
                color = 'bg-green-100 text-green-800';
                break;
            case 'false_alarm':
                color = 'bg-gray-100 text-gray-800';
                break;
            default:
                color = 'bg-blue-100 text-blue-800';
        }
        
        return `<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full ${color}">
            ${status.replace('_', ' ').toUpperCase()}
        </span>`;
    }
    
    // Update report status
    async updateReportStatus() {
        const reportId = this.updateStatusBtn.getAttribute('data-report-id');
        const newStatus = this.statusUpdate.value;
        const statusNotes = document.getElementById('status-notes').value;
        
        if (!reportId) {
            alert('No report selected');
            return;
        }
        
        // Show loading state
        this.updateStatusBtn.disabled = true;
        this.updateStatusBtn.textContent = 'Updating...';
        
        try {
            // Send status update request to the server
            const response = await fetch('update-status.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    report_id: reportId,
                    status: newStatus,
                    notes: statusNotes
                })
            });
            
            const result = await response.json();
            
            if (!result.success) {
                throw new Error(result.error || 'Failed to update status');
            }
            
            // Show success message
            alert(`Status successfully updated from ${result.oldStatus?.toUpperCase() || 'PREVIOUS STATUS'} to ${result.newStatus.toUpperCase()}`);
            
            // Close the modal
            this.hideModal();
            
            // Trigger a refresh of the reports table
            if (typeof window.reportsManager !== 'undefined' && window.reportsManager.loadReports) {
                window.reportsManager.loadReports();
            } else {
                // Fallback if reportsManager isn't available
                window.location.reload();
            }
            
        } catch (error) {
            console.error('Error updating status:', error);
            alert('Failed to update status: ' + error.message);
        } finally {
            // Reset button state
            this.updateStatusBtn.disabled = false;
            this.updateStatusBtn.textContent = 'Update';
        }
    }
    
    // Delete report
    async deleteReport() {
        const reportId = this.confirmDeleteBtn.getAttribute('data-report-id');
        
        if (!reportId) {
            alert('Invalid report ID');
            return;
        }
        
        // Show loading state
        this.confirmDeleteBtn.disabled = true;
        this.confirmDeleteBtn.textContent = 'Deleting...';
        
        try {
            // Send delete request to the server
            const response = await fetch(this.deleteEndpoint, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    report_id: reportId
                })
            });
            
            const result = await response.json();
            
            if (!result.success) {
                throw new Error(result.error || 'Failed to delete report');
            }
            
            // Show success message
            alert('Report successfully deleted');
            
            // Close the modal
            this.hideDeleteModal();
            
            // Trigger a refresh of the reports table
            if (typeof window.reportsManager !== 'undefined' && window.reportsManager.loadReports) {
                window.reportsManager.loadReports();
            } else {
                // Fallback if reportsManager isn't available
                window.location.reload();
            }
            
        } catch (error) {
            console.error('Error deleting report:', error);
            alert('Failed to delete report: ' + error.message);
        } finally {
            // Reset button state
            this.confirmDeleteBtn.disabled = false;
            this.confirmDeleteBtn.textContent = 'Delete';
        }
    }
}

// Initialize the modal handler when the DOM is fully loaded
document.addEventListener('DOMContentLoaded', function() {
    window.modalHandler = new ModalHandler();
});