
// Set current year in footer
document.getElementById('current-year').textContent = new Date().getFullYear();

// Get user info from PHP session
document.addEventListener('DOMContentLoaded', async function() {
    // Try to get session info
    try {
        const response = await fetch('check-session.php');
        const data = await response.json();
        
        if (data.loggedin) {
            // Set user fullname
            document.getElementById('user-fullname').textContent = data.fullname || 'User';
            
            // Show admin link if user is admin
            if (data.role === 'admin') {
                document.getElementById('admin-reports-link').style.display = 'inline-block';
            }
        } else {
            // Redirect to login if not logged in
            window.location.href = 'login.php';
        }
    } catch (error) {
        console.error('Error fetching session info:', error);
    }
});

document.addEventListener('DOMContentLoaded', function() {
    // DOM elements
    const reportsTableBody = document.getElementById('reports-table-body');
    const reportsCount = document.getElementById('reports-count');
    const prevPageBtn = document.getElementById('prev-page');
    const nextPageBtn = document.getElementById('next-page');
    const statusFilter = document.getElementById('status-filter');
    const refreshBtn = document.getElementById('refresh-btn');
    const reportModal = document.getElementById('report-modal');
    const closeModalBtn = document.getElementById('close-modal');
    const modalContent = document.getElementById('modal-content');
    const modalTitle = document.getElementById('modal-title');
    
    // Variables for pagination
    let currentOffset = 0;
    const limit = 10;
    let totalReports = 0;
    let currentStatus = '';
    
    /**
     * Format date string to readable format
     * @param {string} dateString - Date string to format
     * @returns {string} Formatted date string
     */
    const formatDate = (dateString) => {
        try {
            const options = { 
                year: 'numeric', 
                month: 'short', 
                day: 'numeric',
                hour: '2-digit',
                minute: '2-digit'
            };
            return new Date(dateString).toLocaleDateString(undefined, options);
        } catch (e) {
            console.error("Date formatting error:", e);
            return dateString; // Return original string if formatting fails
        }
    };
    
    /**
     * Get HTML for status badge
     * @param {string} status - Report status
     * @returns {string} HTML for status badge
     */
    const getStatusBadge = (status) => {
        let color = '';
        switch(status) {
            case 'active':
                color = 'bg-yellow-100 text-yellow-800';
                break;
            case 'resolved':
                color = 'bg-green-100 text-green-800';
                break;
            case 'false_alarm':
                color = 'bg-gray-100 text-gray-800';
                break;
            default:
                color = 'bg-blue-100 text-blue-800';
        }
        
        return `<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full ${color}">
            ${status.replace('_', ' ').toUpperCase()}
        </span>`;
    };
    
    /**
     * Load reports from API and populate table
     */
    const loadReports = async () => {
        try {
            // Show loading state
            reportsTableBody.innerHTML = `
                <tr>
                    <td colspan="6" class="px-6 py-4 text-center text-gray-500">
                        <div class="loading-spinner"></div> Loading your reports...
                    </td>
                </tr>
            `;
            
            // Use the dedicated API script
            const url = `get-my-reports-api.php?limit=${limit}&offset=${currentOffset}${currentStatus ? '&status=' + currentStatus : ''}`;
            console.log('Fetching from URL:', url);
            
            const response = await fetch(url);
            
            if (!response.ok) {
                throw new Error(`HTTP error! Status: ${response.status}`);
            }
            
            const data = await response.json();
            
            if (!data.success) {
                throw new Error(data.error || 'Failed to load reports');
            }
            
            totalReports = data.pagination.total;
            
            // Update reports count
            reportsCount.textContent = `Showing ${Math.min(data.reports.length, limit)} of ${totalReports} reports`;
            
            // Update pagination buttons
            prevPageBtn.disabled = currentOffset === 0;
            nextPageBtn.disabled = !data.pagination.hasMore;
            
            // Render reports
            if (data.reports.length === 0) {
                reportsTableBody.innerHTML = '<tr><td colspan="6" class="px-6 py-4 text-center text-gray-500">No reports found</td></tr>';
                return;
            }
            
            // Build the HTML for the table rows
            let html = '';
            data.reports.forEach(report => {
                const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
                html += `
                <tr>
                    <td class="px-6 py-4 whitespace-nowrap font-bold text-blue-600">${formattedRefId}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${report.code_label}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${report.location}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${formatDate(report.report_time)}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${getStatusBadge(report.status)}</td>
                    <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                        <button class="text-indigo-600 hover:text-indigo-900 view-details" 
                                data-report-id="${report.id}" 
                                data-report='${JSON.stringify(report)}'>
                            View Details
                        </button>
                    </td>
                </tr>`;
            });
            reportsTableBody.innerHTML = html;
            
            // Add event listeners to view details buttons
            document.querySelectorAll('.view-details').forEach(button => {
                button.addEventListener('click', function() {
                    try {
                        const reportData = JSON.parse(this.getAttribute('data-report'));
                        showReportDetails(reportData);
                    } catch (e) {
                        console.error("Error parsing report data:", e);
                        alert("Error displaying report details");
                    }
                });
            });
            
        } catch (error) {
            console.error('Error loading reports:', error);
            reportsTableBody.innerHTML = `
                <tr>
                    <td colspan="6" class="px-6 py-4 text-center text-red-500">
                        Error loading reports: ${error.message}
                    </td>
                </tr>
            `;
        }
    };
    
    /**
     * Display report details in modal
     * @param {object} report - Report data object
     */
    const showReportDetails = (report) => {
        modalTitle.textContent = `${report.code_label} Report`;
        
        const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
        
        modalContent.innerHTML = `
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <p class="text-gray-500 text-sm">Report ID</p>
                    <p class="font-medium text-blue-600">${formattedRefId}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Code</p>
                    <p class="font-medium">${report.code_label}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Location</p>
                    <p class="font-medium">${report.location}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Reported By</p>
                    <p class="font-medium">${report.reported_by}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Time</p>
                    <p class="font-medium">${formatDate(report.report_time)}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Status</p>
                    <p class="font-medium">${getStatusBadge(report.status)}</p>
                </div>
                <div class="col-span-2">
                    <p class="text-gray-500 text-sm">Details</p>
                    <p class="font-medium">${report.details || 'No additional details provided'}</p>
                </div>
            </div>
        `;
        
        // Show modal
        reportModal.classList.remove('hidden');
    };
    
    // Event Listeners
    statusFilter.addEventListener('change', function() {
        currentStatus = this.value;
        currentOffset = 0;
        loadReports();
    });
    
    refreshBtn.addEventListener('click', loadReports);
    
    prevPageBtn.addEventListener('click', function() {
        if (currentOffset >= limit) {
            currentOffset -= limit;
            loadReports();
        }
    });
    
    nextPageBtn.addEventListener('click', function() {
        currentOffset += limit;
        loadReports();
    });
    
    closeModalBtn.addEventListener('click', function() {
        reportModal.classList.add('hidden');
    });
    
    // Close modal when clicking outside
    reportModal.addEventListener('click', function(event) {
        if (event.target === reportModal) {
            reportModal.classList.add('hidden');
        }
    });
    
    // Error handling for network issues
    window.addEventListener('error', function(e) {
        console.error('Script error:', e.message);
    });
    
    // Initial load
    loadReports();
});