document.addEventListener('DOMContentLoaded', function() {
    // DOM elements
    const reportsTableBody = document.getElementById('reports-table-body');
    const reportsCount = document.getElementById('reports-count');
    const prevPageBtn = document.getElementById('prev-page');
    const nextPageBtn = document.getElementById('next-page');
    const statusFilter = document.getElementById('status-filter');
    const refreshBtn = document.getElementById('refresh-btn');
    const reportModal = document.getElementById('report-modal');
    const closeModalBtn = document.getElementById('close-modal');
    const modalContent = document.getElementById('modal-content');
    const modalTitle = document.getElementById('modal-title');
    const statusUpdate = document.getElementById('status-update');
    const updateStatusBtn = document.getElementById('update-status-btn');
    
    // Variables for pagination
    let currentOffset = 0;
    const limit = 10;
    let totalReports = 0;
    let currentStatus = '';
    
    // Format date function
    const formatDate = (dateString) => {
        try {
            const options = { 
                year: 'numeric', 
                month: 'short', 
                day: 'numeric',
                hour: '2-digit',
                minute: '2-digit'
            };
            return new Date(dateString).toLocaleDateString(undefined, options);
        } catch (e) {
            console.error("Date formatting error:", e);
            return dateString; // Return original string if formatting fails
        }
    };
    
    // Function to get status badge HTML
    const getStatusBadge = (status) => {
        let color = '';
        switch(status) {
            case 'active':
                color = 'bg-yellow-100 text-yellow-800';
                break;
            case 'resolved':
                color = 'bg-green-100 text-green-800';
                break;
            case 'false_alarm':
                color = 'bg-gray-100 text-gray-800';
                break;
            default:
                color = 'bg-blue-100 text-blue-800';
        }
        
        return `<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full ${color}">
            ${status.replace('_', ' ').toUpperCase()}
        </span>`;
    };
    
    // Load reports from API
    const loadReports = async () => {
        try {
            // Show loading state
            reportsTableBody.innerHTML = `
                <tr>
                    <td colspan="7" class="px-6 py-4 text-center text-gray-500">Loading reports...</td>
                </tr>
            `;
            
            // Fetch data from API
            const url = `get-reports.php?api=true&limit=${limit}&offset=${currentOffset}${currentStatus ? '&status=' + currentStatus : ''}`;
            const response = await fetch(url);
            const data = await response.json();
            
            if (!data.success) {
                throw new Error(data.message || 'Failed to load reports');
            }
            
            totalReports = data.pagination.total;
            
            // Update reports count
            reportsCount.textContent = `Showing ${Math.min(data.reports.length, limit)} of ${totalReports} reports`;
            
            // Update pagination buttons
            prevPageBtn.disabled = currentOffset === 0;
            nextPageBtn.disabled = !data.pagination.hasMore;
            
            // Render reports
            if (data.reports.length === 0) {
                reportsTableBody.innerHTML = `
                    <tr>
                        <td colspan="7" class="px-6 py-4 text-center text-gray-500">No reports found</td>
                    </tr>
                `;
                return;
            }
            
            reportsTableBody.innerHTML = data.reports.map(report => {
                const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
                
                return `
                <tr>
                    <td class="px-6 py-4 whitespace-nowrap font-bold text-blue-600">${formattedRefId}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${report.code_label}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${report.location}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${report.reported_by}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${formatDate(report.report_time)}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${getStatusBadge(report.status)}</td>
                    <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                        <button 
                            class="text-indigo-600 hover:text-indigo-900 view-details"
                            data-report-id="${report.id}"
                            data-report='${JSON.stringify(report)}'
                        >
                            View Details
                        </button>
                    </td>
                </tr>
                `;
            }).join('');
            
            // Add event listeners to view details buttons
            document.querySelectorAll('.view-details').forEach(button => {
                button.addEventListener('click', function() {
                    try {
                        const reportData = JSON.parse(this.getAttribute('data-report'));
                        showReportDetails(reportData);
                    } catch (e) {
                        console.error("Error parsing report data:", e);
                        alert("Error displaying report details");
                    }
                });
            });
            
        } catch (error) {
            console.error('Error loading reports:', error);
            reportsTableBody.innerHTML = `
                <tr>
                    <td colspan="7" class="px-6 py-4 text-center text-red-500">
                        Error loading reports: ${error.message}
                    </td>
                </tr>
            `;
        }
    };
    
    // Show report details in modal
    const showReportDetails = (report) => {
        modalTitle.textContent = `${report.code_label} Report`;
        
        const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
        
        modalContent.innerHTML = `
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <p class="text-gray-500 text-sm">Report ID</p>
                    <p class="font-medium text-blue-600">${formattedRefId}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Code</p>
                    <p class="font-medium">${report.code_label}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Location</p>
                    <p class="font-medium">${report.location}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Reported By</p>
                    <p class="font-medium">${report.reported_by}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Time</p>
                    <p class="font-medium">${formatDate(report.report_time)}</p>
                </div>
                <div>
                    <p class="text-gray-500 text-sm">Status</p>
                    <p class="font-medium">${getStatusBadge(report.status)}</p>
                </div>
                <div class="col-span-2">
                    <p class="text-gray-500 text-sm">Details</p>
                    <p class="font-medium">${report.details || 'No additional details provided'}</p>
                </div>
            </div>
            
            <!-- Play button section -->
            <div class="mt-4 pt-4 border-t border-gray-200">
                <button id="play-announcement-btn" class="bg-blue-500 hover:bg-blue-600 text-white px-3 py-2 rounded flex items-center" onclick="playAnnouncement('${report.code_label}', '${report.code_description}', '${report.location}', '${report.details ? report.details.replace(/'/g, "\\'") : ''}')">
                    <svg class="w-4 h-4 mr-1 inline-block" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.752 11.168l-3.197-2.132A1 1 0 0010 9.87v4.263a1 1 0 001.555.832l3.197-2.132a1 1 0 000-1.664z"></path>
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
                    </svg>
                    Play Announcement
                </button>
            </div>
            
            <div class="mt-4 pt-4 border-t border-gray-200">
                <h4 class="font-bold mb-2">Status Notes</h4>
                <textarea id="status-notes" class="w-full px-3 py-2 border border-gray-300 rounded-md" 
                          rows="2" placeholder="Add notes about this status change (optional)"></textarea>
            </div>
        `;
        
        // Set current status in the dropdown
        statusUpdate.value = report.status;
        
        // Set report ID for the update button
        updateStatusBtn.setAttribute('data-report-id', report.id);
        
        // Show modal
        reportModal.classList.remove('hidden');
    };
    
    // Event Listeners
    statusFilter.addEventListener('change', function() {
        currentStatus = this.value;
        currentOffset = 0;
        loadReports();
    });
    
    refreshBtn.addEventListener('click', loadReports);
    
    prevPageBtn.addEventListener('click', function() {
        if (currentOffset >= limit) {
            currentOffset -= limit;
            loadReports();
        }
    });
    
    nextPageBtn.addEventListener('click', function() {
        currentOffset += limit;
        loadReports();
    });
    
    closeModalBtn.addEventListener('click', function() {
        reportModal.classList.add('hidden');
    });
    
    updateStatusBtn.addEventListener('click', async function() {
        const reportId = this.getAttribute('data-report-id');
        const newStatus = statusUpdate.value;
        const statusNotes = document.getElementById('status-notes').value;
        
        // Show loading state
        updateStatusBtn.disabled = true;
        updateStatusBtn.textContent = 'Updating...';
        
        try {
            // Send status update request to the server
            const response = await fetch('update-status.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    report_id: reportId,
                    status: newStatus,
                    notes: statusNotes
                })
            });
            
            const result = await response.json();
            
            if (!result.success) {
                throw new Error(result.error || 'Failed to update status');
            }
            
            // Show success message
            alert(`Status successfully updated to ${newStatus.toUpperCase()}`);
            
            // Close the modal
            reportModal.classList.add('hidden');
            
            // Refresh reports
            loadReports();
        } catch (error) {
            console.error('Error updating status:', error);
            alert('Failed to update status: ' + error.message);
        } finally {
            // Reset button state
            updateStatusBtn.disabled = false;
            updateStatusBtn.textContent = 'Update';
        }
    });
    
    // Close modal when clicking outside
    reportModal.addEventListener('click', function(event) {
        if (event.target === reportModal) {
            reportModal.classList.add('hidden');
        }
    });
    
    // Initialize speech synthesis
    if ('speechSynthesis' in window) {
        // Force voices to load
        window.speechSynthesis.getVoices();
        
        if (window.speechSynthesis.onvoiceschanged !== undefined) {
            window.speechSynthesis.onvoiceschanged = function() {
                console.log("Voices loaded: " + window.speechSynthesis.getVoices().length);
            };
        }
    } else {
        console.warn("This browser does not support the Speech Synthesis API");
    }
    
    // Make the showReportDetails function globally available
    window.showReportDetails = showReportDetails;
    
    // Initial load
    loadReports();
});