/**
 * Reports Manager
 * Handles loading, displaying, and managing emergency code reports
 */

class ReportsManager {
    constructor() {
        // DOM elements
        this.reportsTableBody = document.getElementById('reports-table-body');
        this.reportsCount = document.getElementById('reports-count');
        this.prevPageBtn = document.getElementById('prev-page');
        this.nextPageBtn = document.getElementById('next-page');
        this.statusFilter = document.getElementById('status-filter');
        this.refreshBtn = document.getElementById('refresh-btn');
        
        // Variables for pagination
        this.currentOffset = 0;
        this.limit = 10;
        this.totalReports = 0;
        this.currentStatus = '';
        
        // API endpoint
        this.apiEndpoint = 'reports-api.php';
        
        // Initialize
        this.init();
    }
    
    init() {
        // Set up event listeners
        this.setupEventListeners();
        
        // Load initial data
        this.loadReports();
    }
    
    setupEventListeners() {
        // Status filter change
        if (this.statusFilter) {
            this.statusFilter.addEventListener('change', () => {
                this.currentStatus = this.statusFilter.value;
                this.currentOffset = 0;
                this.loadReports();
            });
        }
        
        // Refresh button
        if (this.refreshBtn) {
            this.refreshBtn.addEventListener('click', () => this.loadReports());
        }
        
        // Pagination
        if (this.prevPageBtn) {
            this.prevPageBtn.addEventListener('click', () => {
                if (this.currentOffset >= this.limit) {
                    this.currentOffset -= this.limit;
                    this.loadReports();
                }
            });
        }
        
        if (this.nextPageBtn) {
            this.nextPageBtn.addEventListener('click', () => {
                this.currentOffset += this.limit;
                this.loadReports();
            });
        }
    }
    
    // Load reports from API
    async loadReports() {
        console.log('Starting to load reports...');
        
        try {
            // Show loading state
            if (this.reportsTableBody) {
                this.reportsTableBody.innerHTML = `
                    <tr>
                        <td colspan="7" class="px-6 py-4 text-center text-gray-500">
                            <span class="loading">Loading reports</span>
                        </td>
                    </tr>
                `;
            }
            
            // Build API URL with parameters
            const url = `${this.apiEndpoint}?limit=${this.limit}&offset=${this.currentOffset}${this.currentStatus ? '&status=' + this.currentStatus : ''}`;
            console.log('Fetching from URL:', url);
            
            // Fetch data from API
            const response = await fetch(url);
            console.log('Received response:', response);
            
            if (!response.ok) {
                throw new Error(`HTTP error! Status: ${response.status}`);
            }
            
            const data = await response.json();
            console.log('Parsed data:', data);
            
            if (!data.success) {
                throw new Error(data.message || 'Failed to load reports');
            }
            
            this.totalReports = data.pagination.total;
            
            // Update reports count
            if (this.reportsCount) {
                this.reportsCount.textContent = `Showing ${Math.min(data.reports.length, this.limit)} of ${this.totalReports} reports`;
            }
            
            // Update pagination buttons
            if (this.prevPageBtn) {
                this.prevPageBtn.disabled = this.currentOffset === 0;
            }
            
            if (this.nextPageBtn) {
                this.nextPageBtn.disabled = !data.pagination.hasMore;
            }
            
            // Render reports
            this.renderReports(data.reports);
            
        } catch (error) {
            console.error('Error loading reports:', error);
            
            if (this.reportsTableBody) {
                this.reportsTableBody.innerHTML = `
                    <tr>
                        <td colspan="7" class="px-6 py-4 text-center text-red-500">
                            Error loading reports: ${error.message}
                        </td>
                    </tr>
                `;
            }
        }
    }
    
    // Render reports in the table
    renderReports(reports) {
        if (!this.reportsTableBody) return;
        
        if (reports.length === 0) {
            this.reportsTableBody.innerHTML = `
                <tr>
                    <td colspan="7" class="px-6 py-4 text-center text-gray-500">No reports found</td>
                </tr>
            `;
            return;
        }
        
        this.reportsTableBody.innerHTML = reports.map(report => {
            const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
            
            return `
            <tr>
                <td class="px-6 py-4 whitespace-nowrap font-bold text-blue-600">${formattedRefId}</td>
                <td class="px-6 py-4 whitespace-nowrap">${report.code_label}</td>
                <td class="px-6 py-4 whitespace-nowrap">${report.location}</td>
                <td class="px-6 py-4 whitespace-nowrap">${report.reported_by}</td>
                <td class="px-6 py-4 whitespace-nowrap">${this.formatDate(report.report_time)}</td>
                <td class="px-6 py-4 whitespace-nowrap">${this.getStatusBadge(report.status)}</td>
                <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                    <button 
                        class="text-indigo-600 hover:text-indigo-900 view-details"
                        data-report-id="${report.id}"
                        data-report='${JSON.stringify(report)}'
                    >
                        View Details
                    </button>
                </td>
            </tr>
            `;
        }).join('');
        
        // Add event listeners to view details buttons
        document.querySelectorAll('.view-details').forEach(button => {
            button.addEventListener('click', function() {
                try {
                    const reportData = JSON.parse(this.getAttribute('data-report'));
                    // Use the modalHandler if available
                    if (window.modalHandler && window.modalHandler.showReportDetails) {
                        window.modalHandler.showReportDetails(reportData);
                    } else {
                        console.error('Modal handler not available');
                        alert('Unable to show report details: Modal handler not available');
                    }
                } catch (e) {
                    console.error("Error parsing report data:", e);
                    alert("Error displaying report details");
                }
            });
        });
    }
    
    // Format date helper
    formatDate(dateString) {
        try {
            const options = { 
                year: 'numeric', 
                month: 'short', 
                day: 'numeric',
                hour: '2-digit',
                minute: '2-digit'
            };
            return new Date(dateString).toLocaleDateString(undefined, options);
        } catch (e) {
            console.error("Date formatting error:", e);
            return dateString; // Return original string if formatting fails
        }
    }
    
    // Get status badge HTML
    getStatusBadge(status) {
        let color = '';
        switch(status) {
            case 'active':
                color = 'bg-yellow-100 text-yellow-800';
                break;
            case 'resolved':
                color = 'bg-green-100 text-green-800';
                break;
            case 'false_alarm':
                color = 'bg-gray-100 text-gray-800';
                break;
            default:
                color = 'bg-blue-100 text-blue-800';
        }
        
        return `<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full ${color}">
            ${status.replace('_', ' ').toUpperCase()}
        </span>`;
    }
}

// Initialize the reports manager when the DOM is fully loaded
document.addEventListener('DOMContentLoaded', function() {
    window.reportsManager = new ReportsManager();
});
