// /js/reports.js
document.addEventListener('DOMContentLoaded', function() {
    // DOM elements cache
    const elements = {
        tableBody: document.getElementById('reports-table-body'),
        countDisplay: document.getElementById('reports-count'),
        prevBtn: document.getElementById('prev-page'),
        nextBtn: document.getElementById('next-page'),
        statusFilter: document.getElementById('status-filter'),
        refreshBtn: document.getElementById('refresh-btn'),
        modal: document.getElementById('report-modal'),
        closeModalBtn: document.getElementById('close-modal'),
        modalContent: document.getElementById('modal-content'),
        modalTitle: document.getElementById('modal-title')
    };

    // Pagination state
    const state = {
        currentOffset: 0,
        limit: 10,
        totalReports: 0,
        currentStatus: ''
    };

    // Utility functions
    const utils = {
        formatDate: (dateString) => {
            try {
                return new Date(dateString).toLocaleString();
            } catch (e) {
                console.error('Date formatting error:', e);
                return dateString;
            }
        },

        getStatusBadge: (status) => {
            const statusClasses = {
                active: 'bg-yellow-100 text-yellow-800',
                resolved: 'bg-green-100 text-green-800',
                false_alarm: 'bg-gray-100 text-gray-800',
                default: 'bg-blue-100 text-blue-800'
            };

            const color = statusClasses[status] || statusClasses.default;
            const displayText = status.replace('_', ' ').toUpperCase();

            return `<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full ${color}">
                ${displayText}
            </span>`;
        },

        showError: (message) => {
            elements.tableBody.innerHTML = `
                <tr>
                    <td colspan="6" class="px-6 py-4 text-center text-red-500">
                        ${message}
                    </td>
                </tr>
            `;
        }
    };

    // API functions
    const api = {
        updateStatus: async (reportId, newStatus) => {
            try {
                const response = await fetch('api/reports.php?action=update_status', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `report_id=${reportId}&new_status=${newStatus}`
                });

                if (!response.ok) throw new Error('Network response was not ok');
                return await response.json();
            } catch (error) {
                console.error('API update error:', error);
                throw error;
            }
        },

        getReports: async () => {
            try {
                const url = `api/reports.php?action=get_reports&limit=${state.limit}&offset=${state.currentOffset}${state.currentStatus ? '&status=' + state.currentStatus : ''}`;
                const response = await fetch(url);

                if (!response.ok) throw new Error('Network response was not ok');
                return await response.json();
            } catch (error) {
                console.error('API fetch error:', error);
                throw error;
            }
        }
    };

    // UI components
    const components = {
        createStatusDropdown: (currentStatus, reportId) => {
            const dropdown = document.createElement('select');
            dropdown.className = 'status-dropdown border rounded px-2 py-1 text-xs';
            dropdown.setAttribute('data-report-id', reportId);

            const statusOptions = [
                { value: 'active', label: 'ACTIVE' },
                { value: 'resolved', label: 'RESOLVED' },
                { value: 'false_alarm', label: 'FALSE ALARM' }
            ];

            statusOptions.forEach(option => {
                const element = document.createElement('option');
                element.value = option.value;
                element.textContent = option.label;
                element.selected = option.value === currentStatus;
                dropdown.appendChild(element);
            });

            dropdown.addEventListener('change', async function() {
                const newStatus = this.value;
                const reportId = this.getAttribute('data-report-id');

                try {
                    const result = await api.updateStatus(reportId, newStatus);
                    if (!result.success) throw new Error(result.error);

                    const statusCell = this.closest('td');
                    statusCell.innerHTML = utils.getStatusBadge(newStatus);
                    
                    components.showStatusUpdateSuccess(statusCell);
                    components.makeStatusEditable(statusCell, newStatus, reportId);
                } catch (error) {
                    console.error('Status update failed:', error);
                    this.value = currentStatus;
                    alert(`Status update failed: ${error.message}`);
                }
            });

            return dropdown;
        },

        showStatusUpdateSuccess: (statusCell) => {
            const successMsg = document.createElement('div');
            successMsg.className = 'text-green-500 text-xs mt-1';
            successMsg.textContent = 'Status updated!';
            statusCell.appendChild(successMsg);

            setTimeout(() => successMsg.remove(), 2000);
        },

        makeStatusEditable: (statusCell, currentStatus, reportId) => {
            statusCell.style.position = 'relative';

            const editBtn = document.createElement('button');
            editBtn.className = 'edit-status-btn absolute -right-6 top-1/2 transform -translate-y-1/2 text-gray-400 hover:text-gray-600';
            editBtn.innerHTML = '<svg class="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M11 5H6a2 2 0 00-2 2v11a2 2 0 002 2h11a2 2 0 002-2v-5m-1.414-9.414a2 2 0 112.828 2.828L11.828 15H9v-2.828l8.586-8.586z"></path></svg>';
            editBtn.title = 'Edit status';

            const originalContent = statusCell.innerHTML;

            editBtn.addEventListener('click', (e) => {
                e.stopPropagation();
                if (statusCell.querySelector('.status-dropdown')) return;

                statusCell.innerHTML = '';
                const dropdown = components.createStatusDropdown(currentStatus, reportId);
                statusCell.appendChild(dropdown);
                dropdown.focus();

                const cancelBtn = document.createElement('button');
                cancelBtn.className = 'cancel-edit-btn ml-2 text-gray-500 hover:text-gray-700';
                cancelBtn.innerHTML = '<svg class="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12"></path></svg>';
                cancelBtn.title = 'Cancel';

                cancelBtn.addEventListener('click', (e) => {
                    e.stopPropagation();
                    statusCell.innerHTML = originalContent;
                    components.makeStatusEditable(statusCell, currentStatus, reportId);
                });

                statusCell.appendChild(cancelBtn);
            });

            statusCell.appendChild(editBtn);
        },

        renderReportDetails: (report) => {
            elements.modalTitle.textContent = `${report.code_label} Report`;
            
            const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
            
            elements.modalContent.innerHTML = `
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div>
                        <p class="text-gray-500 text-sm">Report ID</p>
                        <p class="font-medium text-blue-600">${formattedRefId}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Code</p>
                        <p class="font-medium">${report.code_label}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Location</p>
                        <p class="font-medium">${report.location}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Reported By</p>
                        <p class="font-medium">${report.reported_by}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Time</p>
                        <p class="font-medium">${utils.formatDate(report.report_time)}</p>
                    </div>
                    <div>
                        <p class="text-gray-500 text-sm">Status</p>
                        <p class="font-medium">${utils.getStatusBadge(report.status)}</p>
                    </div>
                    <div class="col-span-2">
                        <p class="text-gray-500 text-sm">Details</p>
                        <p class="font-medium">${report.details || 'No additional details provided'}</p>
                    </div>
                </div>
                
                ${report.audio_file ? `
                <div class="mt-4 pt-4 border-t border-gray-200">
                    <h4 class="font-bold mb-2">Emergency Announcement</h4>
                    <button class="play-announcement-btn bg-blue-500 hover:bg-blue-600 text-white px-3 py-2 rounded flex items-center" 
                            data-report='${JSON.stringify(report)}'>
                        <svg class="w-4 h-4 mr-1 inline-block" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.752 11.168l-3.197-2.132A1 1 0 0010 9.87v4.263a1 1 0 001.555.832l3.197-2.132a1 1 0 000-1.664z"></path>
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 12a9 9 0 11-18 0 9 9 0 0118 0z"></path>
                        </svg>
                        Play Announcement
                    </button>
                </div>
                ` : ''}
            `;
            
            // Add event listener for the play button
            const playBtn = elements.modalContent.querySelector('.play-announcement-btn');
            if (playBtn) {
                playBtn.addEventListener('click', function() {
                    const reportData = JSON.parse(this.getAttribute('data-report'));
                    playEmergencyAnnouncement(reportData);
                });
            }
            
            elements.modal.classList.remove('hidden');
        },

        renderReportsTable: (reports) => {
            if (reports.length === 0) {
                elements.tableBody.innerHTML = '<tr><td colspan="6" class="px-6 py-4 text-center text-gray-500">No reports found</td></tr>';
                return;
            }

            let html = '';
            for (const report of reports) {
                const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
                html += `
                <tr>
                    <td class="px-6 py-4 whitespace-nowrap font-bold text-blue-600">${formattedRefId}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${report.code_label}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${report.location}</td>
                    <td class="px-6 py-4 whitespace-nowrap">${utils.formatDate(report.report_time)}</td>
                    <td class="px-6 py-4 whitespace-nowrap status-cell" data-status="${report.status}" data-report-id="${report.id}">
                        ${utils.getStatusBadge(report.status)}
                    </td>
                    <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                        <button class="text-indigo-600 hover:text-indigo-900 view-details" 
                                data-report-id="${report.id}" 
                                data-report='${JSON.stringify(report)}'>
                            View Details
                        </button>
                    </td>
                </tr>`;
            }
            elements.tableBody.innerHTML = html;

            // Make status cells editable
            document.querySelectorAll('.status-cell').forEach(cell => {
                const currentStatus = cell.getAttribute('data-status');
                const reportId = cell.getAttribute('data-report-id');
                components.makeStatusEditable(cell, currentStatus, reportId);
            });

            // Add event listeners to view details buttons
            document.querySelectorAll('.view-details').forEach(button => {
                button.addEventListener('click', function() {
                    try {
                        const reportData = JSON.parse(this.getAttribute('data-report'));
                        components.renderReportDetails(reportData);
                    } catch (e) {
                        console.error("Error parsing report data:", e);
                        alert("Error displaying report details");
                    }
                });
            });
        }
    };

    // Main functions
    const loadReports = async () => {
        try {
            elements.tableBody.innerHTML = '<tr><td colspan="6" class="px-6 py-4 text-center text-gray-500">Loading your reports...</td></tr>';
            
            const data = await api.getReports();
            if (!data.success) throw new Error(data.message || 'Failed to load reports');

            state.totalReports = data.pagination.total;
            elements.countDisplay.textContent = `Showing ${Math.min(data.reports.length, state.limit)} of ${state.totalReports} reports`;
            elements.prevBtn.disabled = state.currentOffset === 0;
            elements.nextBtn.disabled = !data.pagination.hasMore;

            components.renderReportsTable(data.reports);
        } catch (error) {
            console.error('Error loading reports:', error);
            utils.showError(`Error loading reports: ${error.message}`);
        }
    };

    // Event Listeners
    elements.statusFilter.addEventListener('change', function() {
        state.currentStatus = this.value;
        state.currentOffset = 0;
        loadReports();
    });

    elements.refreshBtn.addEventListener('click', loadReports);
    
    elements.prevBtn.addEventListener('click', () => {
        if (state.currentOffset >= state.limit) {
            state.currentOffset -= state.limit;
            loadReports();
        }
    });

    elements.nextBtn.addEventListener('click', () => {
        state.currentOffset += state.limit;
        loadReports();
    });

    elements.closeModalBtn.addEventListener('click', () => elements.modal.classList.add('hidden'));
    
    elements.modal.addEventListener('click', (event) => {
        if (event.target === elements.modal) {
            elements.modal.classList.add('hidden');
        }
    });

    // Initial load
    loadReports();
});

// Global function for announcement player
function playEmergencyAnnouncement(report) {
    if (typeof playAnnouncement === 'function') {
        playAnnouncement(report);
    } else if ('speechSynthesis' in window) {
        const text = `Attention all staff. ${report.code_label}. ${report.code_description}. Has been reported in ${report.location}.`;
        const utterance = new SpeechSynthesisUtterance(text);
        window.speechSynthesis.speak(utterance);
    } else {
        alert(`Emergency: ${report.code_label} in ${report.location}`);
    }
}