<?php
// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'error' => 'Unauthorized']);
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Set response headers
header('Content-Type: application/json');

// Only allow POST method
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Method not allowed', 'success' => false]);
    exit;
}

// Get JSON input
$input = json_decode(file_get_contents('php://input'), true);

// If input is not valid JSON
if (json_last_error() !== JSON_ERROR_NONE) {
    http_response_code(400); // Bad Request
    echo json_encode(['error' => 'Invalid JSON', 'success' => false]);
    exit;
}

// Validate required fields
$required_fields = ['codeType', 'location', 'reportedBy'];
foreach ($required_fields as $field) {
    if (empty($input[$field])) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => "Missing required field: $field", 'success' => false]);
        exit;
    }
}

// Add request ID to detect and prevent duplicate submissions
$requestId = isset($input['requestId']) ? $input['requestId'] : uniqid();

// Sanitize inputs
$codeType = trim($input['codeType']);
$location = trim($input['location']);
$reportedBy = trim($input['reportedBy']);
$details = isset($input['details']) ? trim($input['details']) : '';
$building = isset($input['building']) ? trim($input['building']) : null;

// Get user ID from session
$userId = $_SESSION["user_id"];

// Get client IP address
$ipAddress = $_SERVER['REMOTE_ADDR'];
if (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
    $ipAddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
}

// Get user agent
$userAgent = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';

try {
    // Begin transaction
    $pdo->beginTransaction();
    
    // Check for duplicate submission by checking recent reports with same data
    // This helps prevent multiple form submissions
    $checkDuplicate = $pdo->prepare("
        SELECT id FROM code_reports 
        WHERE user_id = ? 
        AND code_id = ? 
        AND location_id = ? 
        AND reported_by = ? 
        AND report_timestamp >= NOW() - INTERVAL 5 MINUTE
    ");
    
    $checkDuplicate->execute([
        $userId,
        $codeType,
        $location,
        $reportedBy
    ]);
    
    if ($checkDuplicate->rowCount() > 0) {
        // A similar report was already submitted in the last 5 minutes
        $existingId = $checkDuplicate->fetchColumn();
        $formattedId = 'ECR-' . str_pad($existingId, 6, '0', STR_PAD_LEFT);
        
        // Commit transaction and return existing ID
        $pdo->commit();
        
        echo json_encode([
            'success' => true,
            'message' => 'Report already exists',
            'reportId' => $existingId,
            'formattedReportId' => $formattedId,
            'isDuplicate' => true,
            'timestamp' => date('Y-m-d H:i:s')
        ]);
        exit;
    }
    
    // First verify that the code exists
    $stmt = $pdo->prepare("SELECT code_value FROM emergency_codes WHERE code_value = ?");
    $stmt->execute([$codeType]);
    $codeExists = $stmt->fetch();
    
    if (!$codeExists) {
        // Improved error logging for debugging
        error_log("Invalid code type submitted: " . $codeType);
        
        // Get all valid codes for debugging
        $allCodes = $pdo->query("SELECT code_value FROM emergency_codes")->fetchAll(PDO::FETCH_COLUMN);
        error_log("Valid code types: " . implode(", ", $allCodes));
        
        throw new Exception("Invalid code type: $codeType - Code does not exist in database");
    }
    
    // Also verify location exists
    $locationCheck = $pdo->prepare("SELECT id FROM locations WHERE name = ?");
    $locationCheck->execute([$location]);
    if (!$locationCheck->fetch()) {
        error_log("Invalid location submitted: " . $location);
        
        // List the valid locations for debugging
        $allLocations = $pdo->query("SELECT name FROM locations")->fetchAll(PDO::FETCH_COLUMN);
        error_log("Valid locations: " . implode(", ", $allLocations));
        
        throw new Exception("Invalid location: $location - Location does not exist in database");
    }
    
    // If a building was provided, verify it exists
    if (!empty($building)) {
        $buildingCheck = $pdo->prepare("SELECT id FROM buildings WHERE name = ? AND active = 1");
        $buildingCheck->execute([$building]);
        if (!$buildingCheck->fetch()) {
            error_log("Invalid building submitted: " . $building);
            throw new Exception("Invalid building: $building - Building does not exist or is not active");
        }
    }

    // Build insert query with optional building column
    $insertQuery = "
        INSERT INTO code_reports 
        (user_id, code_id, location_id, reported_by, details, ip_address, user_agent, status";
    
    // Add selected_building column if building is provided
    if (!empty($building)) {
        $insertQuery .= ", selected_building";
    }
    
    $insertQuery .= ") VALUES (?, ?, ?, ?, ?, ?, ?, 'active'";
    
    // Add placeholder for building if provided
    if (!empty($building)) {
        $insertQuery .= ", ?";
    }
    
    $insertQuery .= ")";
    
    // Prepare parameters for the insert
    $params = [
        $userId,
        $codeType,
        $location,
        $reportedBy,
        $details,
        $ipAddress,
        $userAgent
    ];
    
    // Add building to parameters if provided
    if (!empty($building)) {
        $params[] = $building;
    }
    
    // Log the query and parameters for debugging
    error_log("Executing insert: " . $insertQuery);
    error_log("With parameters: " . json_encode($params));
    
    // Insert the report
    $stmt = $pdo->prepare($insertQuery);
    $result = $stmt->execute($params);
    
    if (!$result) {
        error_log("Execute failed: " . json_encode($stmt->errorInfo()));
        throw new Exception("Database insert failed: " . $stmt->errorInfo()[2]);
    }
    
    // Get the inserted ID
    $reportId = $pdo->lastInsertId();
    
    // Format the report ID for display
    $formattedReportId = 'ECR-' . str_pad($reportId, 6, '0', STR_PAD_LEFT);
    
    // Commit transaction
    $pdo->commit();
    
    // Successful response
    http_response_code(201); // Created
    echo json_encode([
        'success' => true,
        'message' => 'Emergency code reported successfully',
        'reportId' => $reportId,
        'formattedReportId' => $formattedReportId,
        'requestId' => $requestId,
        'timestamp' => date('Y-m-d H:i:s')
    ]);
    
} catch (Exception $e) {
    // Rollback transaction on error
    if ($pdo->inTransaction()) {
        $pdo->rollBack();
    }
    
    // Log the error (in a production environment)
    error_log('Database Error: ' . $e->getMessage());
    
    // Return error response with more details for debugging
    http_response_code(500); // Internal Server Error
    echo json_encode([
        'error' => 'Failed to save report',
        'message' => $e->getMessage(),
        'details' => isset($stmt) ? $stmt->errorInfo() : null,
        'input' => [
            'codeType' => $codeType,
            'location' => $location,
            'building' => $building
        ],
        'success' => false
    ]);
}