<?php
// Start session - for access control (only admins and reporters should access this)
session_start();

// Check if user is logged in and has either admin or reporter role
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true || 
    !in_array($_SESSION["role"], ["admin", "reporter"])) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Define variables
$error_message = "";
$success_message = "";
$user_id = "";
$user_fullname = "";
$current_duty_status_id = null;
$current_duty_shift = null;

// Get duty status options
try {
    $status_sql = "SELECT id, status_name FROM duty_status ORDER BY id";
    $duty_statuses = $pdo->query($status_sql)->fetchAll();
} catch (PDOException $e) {
    $error_message = "Could not fetch duty statuses: " . $e->getMessage();
    $duty_statuses = [];
}

// Check if user_id is provided
if (isset($_GET['user_id']) && !empty($_GET['user_id'])) {
    $user_id = $_GET['user_id'];
    
    // Get user details
    try {
        $user_sql = "SELECT u.id, u.fullname, u.duty_status_id, u.duty_shift 
                    FROM users u 
                    WHERE u.id = ?";
        $stmt = $pdo->prepare($user_sql);
        $stmt->execute([$user_id]);
        
        if ($stmt->rowCount() > 0) {
            $user = $stmt->fetch();
            $user_fullname = $user['fullname'];
            $current_duty_status_id = $user['duty_status_id'];
            $current_duty_shift = $user['duty_shift'];
        } else {
            $error_message = "User not found";
        }
    } catch (PDOException $e) {
        $error_message = "Database error: " . $e->getMessage();
    }
}
// Process the form submission
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["update_duty"])) {
    $user_id = $_POST["user_id"];
    $duty_status_id = !empty($_POST["duty_status_id"]) ? $_POST["duty_status_id"] : null;
    $duty_shift = !empty($_POST["duty_shift"]) ? $_POST["duty_shift"] : null;
    
    try {
        $update_sql = "UPDATE users SET duty_status_id = ?, duty_shift = ? WHERE id = ?";
        $update_stmt = $pdo->prepare($update_sql);
        $update_stmt->execute([$duty_status_id, $duty_shift, $user_id]);
        
        $success_message = "Duty status and shift updated successfully. Redirecting to My Reports...";
        
        // Update the current values
        $current_duty_status_id = $duty_status_id;
        $current_duty_shift = $duty_shift;
        
        // Add JavaScript to redirect after 3 seconds
        echo '<script>
                setTimeout(function() {
                    window.location.href = "my-reports.php";
                }, 3000);
              </script>';
        
    } catch (PDOException $e) {
        $error_message = "Failed to update duty status: " . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Update Duty Status - Emergency Code System</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Update Duty Status</h1>
            <div class="flex items-center space-x-4">
                <a href="my-reports.php" class="text-white hover:underline">My Reports</a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"]); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto max-w-2xl">
            <?php if(!empty($error_message)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
                    <p><?php echo $error_message; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if(!empty($success_message)): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4" role="alert">
                    <p><?php echo $success_message; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($user_id) && empty($error_message)): ?>
            <div class="bg-white rounded-lg shadow-md p-6">
                <h2 class="text-xl font-bold mb-4">Update Duty Status for <?php echo htmlspecialchars($user_fullname); ?></h2>
                
                <form method="post" action="">
                    <input type="hidden" name="user_id" value="<?php echo $user_id; ?>">
                    
                    <div class="mb-4">
                        <label for="duty_status_id" class="block text-sm font-medium text-gray-700 mb-1">Duty Status</label>
                        <select name="duty_status_id" id="duty_status_id" class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                            <option value="">-- Not Assigned --</option>
                            <?php foreach ($duty_statuses as $status): ?>
                                <option value="<?php echo $status['id']; ?>" <?php echo ($current_duty_status_id == $status['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($status['status_name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="mb-4">
                        <label for="duty_shift" class="block text-sm font-medium text-gray-700 mb-1">Duty Shift</label>
                        <select name="duty_shift" id="duty_shift" class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                            <option value="">-- Not Assigned --</option>
                            <optgroup label="Day Shifts">
                                <option value="D6Hours" <?php echo ($current_duty_shift == 'D6Hours') ? 'selected' : ''; ?>>Day 6 Hours</option>
                                <option value="D12Hours" <?php echo ($current_duty_shift == 'D12Hours') ? 'selected' : ''; ?>>Day 12 Hours</option>
                                <option value="D24Hours" <?php echo ($current_duty_shift == 'D24Hours') ? 'selected' : ''; ?>>Day 24 Hours</option>
                            </optgroup>
                            <optgroup label="Night Shifts">
                                <option value="N6Hours" <?php echo ($current_duty_shift == 'N6Hours') ? 'selected' : ''; ?>>Night 6 Hours</option>
                                <option value="N12Hours" <?php echo ($current_duty_shift == 'N12Hours') ? 'selected' : ''; ?>>Night 12 Hours</option>
                                <option value="N24Hours" <?php echo ($current_duty_shift == 'N24Hours') ? 'selected' : ''; ?>>Night 24 Hours</option>
                            </optgroup>
                        </select>
                    </div>
                    
                    <div class="flex justify-between">
                        <a href="user-manager.php" class="bg-gray-300 hover:bg-gray-400 text-gray-800 font-bold py-2 px-4 rounded">
                            Cancel
                        </a>
                        <button type="submit" name="update_duty" class="bg-green-500 hover:bg-green-600 text-white font-bold py-2 px-4 rounded">
                            Update Duty Status
                        </button>
                    </div>
                </form>
            </div>
            <?php else: ?>
                <div class="bg-white rounded-lg shadow-md p-6 text-center">
                    <p class="text-red-600 text-lg mb-4">No user selected or user not found.</p>
                    <a href="user-manager.php" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded inline-block">
                        Return to User Management
                    </a>
                </div>
            <?php endif; ?>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
    </footer>
</body>
</html>