<?php
// Start session
session_start();

// Check if user is logged in and has admin privileges
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true || $_SESSION["role"] !== "admin") {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'error' => 'Unauthorized access']);
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Set response headers
header('Content-Type: application/json');

// Only allow POST method
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['success' => false, 'error' => 'Method not allowed']);
    exit;
}

// Get JSON input
$input = json_decode(file_get_contents('php://input'), true);

// Validate required fields
if (empty($input['report_id']) || empty($input['status'])) {
    http_response_code(400); // Bad Request
    echo json_encode(['success' => false, 'error' => 'Report ID and status are required']);
    exit;
}

// Sanitize inputs
$reportId = (int)$input['report_id'];
$status = trim($input['status']);
$notes = isset($input['notes']) ? trim($input['notes']) : '';

// Validate status
$validStatuses = ['active', 'resolved', 'false_alarm'];
if (!in_array($status, $validStatuses)) {
    http_response_code(400); // Bad Request
    echo json_encode(['success' => false, 'error' => 'Invalid status value']);
    exit;
}

try {
    // Begin transaction
    $pdo->beginTransaction();
    
    // First check if the report exists
    $checkSql = "SELECT id, status, reference_id FROM code_reports WHERE id = ?";
    $checkStmt = $pdo->prepare($checkSql);
    $checkStmt->execute([$reportId]);
    $report = $checkStmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$report) {
        throw new Exception("Report not found");
    }
    
    // Get the old status for logging
    $oldStatus = $report['status'];
    $referenceId = $report['reference_id'];
    
    // Only update if status has changed
    if ($oldStatus !== $status) {
        // Update the report status
        $updateSql = "UPDATE code_reports SET status = ? WHERE id = ?";
        $updateStmt = $pdo->prepare($updateSql);
        $updateStmt->execute([$status, $reportId]);
        
        // Add entry to report updates
        $logSql = "INSERT INTO report_updates (report_id, update_text, updated_by, user_id) VALUES (?, ?, ?, ?)";
        $logStmt = $pdo->prepare($logSql);
        
        $updateText = "Status changed from " . strtoupper($oldStatus) . " to " . strtoupper($status);
        if (!empty($notes)) {
            $updateText .= ". Notes: " . $notes;
        }
        
        $logStmt->execute([
            $reportId,
            $updateText,
            $_SESSION["fullname"],
            $_SESSION["user_id"]
        ]);
    }
    
    // Commit transaction
    $pdo->commit();
    
    // Return success response
    echo json_encode([
        'success' => true,
        'message' => 'Status updated successfully',
        'reportId' => $reportId,
        'referenceId' => $referenceId,
        'newStatus' => $status,
        'oldStatus' => $oldStatus
    ]);
    
} catch (Exception $e) {
    // Rollback transaction on error
    if ($pdo->inTransaction()) {
        $pdo->rollBack();
    }
    
    // Log the error
    error_log('Database Error: ' . $e->getMessage());
    
    // Return error response
    http_response_code(500); // Internal Server Error
    echo json_encode([
        'success' => false,
        'error' => 'Failed to update status: ' . $e->getMessage()
    ]);
}
