<?php
// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true || $_SESSION["role"] !== "admin") {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Initialize messages
$successMessage = '';
$errorMessage = '';

// Get the user ID from request parameter
$userId = isset($_GET['user_id']) ? (int)$_GET['user_id'] : 0;

// Check if the user exists
try {
    $userQuery = "SELECT username, fullname FROM users WHERE id = ?";
    $userStmt = $pdo->prepare($userQuery);
    $userStmt->execute([$userId]);
    $user = $userStmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$user) {
        echo "<script>alert('User not found'); window.location.href = 'user-manager.php';</script>";
        exit;
    }
} catch (PDOException $e) {
    $errorMessage = "Error fetching user: " . $e->getMessage();
}

// Handle form submission to update duty status
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_status'])) {
    $newStatusId = isset($_POST['duty_status']) ? (int)$_POST['duty_status'] : null;
    $shift = isset($_POST['shift']) ? $_POST['shift'] : null;
    
    try {
        // Update the user's duty status
        $stmt = $pdo->prepare("UPDATE users SET duty_status_id = ?, duty_shift = ? WHERE id = ?");
        $stmt->execute([$newStatusId, $shift, $userId]);
        
        if ($stmt->rowCount() > 0) {
            $successMessage = "Duty status has been updated successfully.";
            
            // Log the status change
            $getStatusName = $pdo->prepare("SELECT status_name FROM duty_status WHERE id = ?");
            $getStatusName->execute([$newStatusId]);
            $statusName = $getStatusName->fetchColumn();
            
            $logStmt = $pdo->prepare("INSERT INTO status_logs (user_id, status_change, notes, change_timestamp) 
                                       VALUES (?, ?, ?, NOW())");
            $logStmt->execute([
                $userId, 
                "Changed to $statusName ($shift)", 
                "Status updated by admin: " . $_SESSION["fullname"]
            ]);
        } else {
            $errorMessage = "No changes were made.";
        }
    } catch (PDOException $e) {
        $errorMessage = "Error updating status: " . $e->getMessage();
    }
}

// Get current user status
try {
    $stmt = $pdo->prepare("
        SELECT u.duty_status_id, u.duty_shift, d.status_name, d.description
        FROM users u
        LEFT JOIN duty_status d ON u.duty_status_id = d.id
        WHERE u.id = ?
    ");
    $stmt->execute([$userId]);
    $currentStatus = $stmt->fetch(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $errorMessage = "Error fetching user status: " . $e->getMessage();
    $currentStatus = null;
}

// Get all available duty statuses
try {
    $stmt = $pdo->query("SELECT id, status_name, description FROM duty_status ORDER BY id");
    $dutyStatuses = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $errorMessage = "Error fetching duty statuses: " . $e->getMessage();
    $dutyStatuses = [];
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Update User Duty Status - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="css/duty-status.css" rel="stylesheet">
    <!-- Add favicon link -->
    <link rel="icon" href="favicon.ico" type="image/x-icon">
    <style>
        /* Status indicators */
        .status-badge {
            display: inline-block;
            padding: 0.25rem 0.75rem;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 600;
            text-align: center;
            margin-bottom: 0.5rem;
        }
        .status-on-duty {
            background-color: #10B981;
            color: white;
        }
        .status-on-call {
            background-color: #3B82F6;
            color: white;
        }
        .status-on-leave {
            background-color: #F59E0B;
            color: white;
        }
        .status-sick-leave {
            background-color: #EF4444;
            color: white;
        }
        .status-unknown {
            background-color: #6B7280;
            color: white;
        }
        
        /* Shift badge styles */
        .shift-badge {
            display: inline-block;
            padding: 0.15rem 0.5rem;
            border-radius: 0.25rem;
            font-size: 0.7rem;
        }
        .shift-day {
            background-color: #FEF3C7;
            color: #92400E;
            border: 1px solid #F59E0B;
        }
        .shift-night {
            background-color: #E0E7FF;
            color: #3730A3;
            border: 1px solid #6366F1;
        }
    </style>
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Update Duty Status for <?php echo htmlspecialchars($user['fullname']); ?></h1>
            <div class="flex items-center space-x-4">
                <a href="user-manager.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Back to User Manager</a>
                <span class="text-sm">Admin: <?php echo htmlspecialchars($_SESSION["fullname"]); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto max-w-2xl">
            <?php if (!empty($successMessage)): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4" role="alert">
                    <p><?php echo $successMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($errorMessage)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
                    <p><?php echo $errorMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="bg-white rounded-lg shadow p-6">
                <div class="mb-6 flex items-center">
                    <div class="mr-4 bg-blue-100 rounded-full p-3">
                        <svg class="w-8 h-8 text-blue-500" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M16 7a4 4 0 11-8 0 4 4 0 018 0zM12 14a7 7 0 00-7 7h14a7 7 0 00-7-7z"></path>
                        </svg>
                    </div>
                    <div>
                        <h2 class="text-xl font-bold"><?php echo htmlspecialchars($user['fullname']); ?></h2>
                        <p class="text-gray-600">Username: <?php echo htmlspecialchars($user['username']); ?></p>
                    </div>
                </div>
                
                <h3 class="text-lg font-bold mb-4">Current Duty Status</h3>
                
                <div class="mb-8 p-4 bg-gray-50 rounded-lg">
                    <?php if ($currentStatus && isset($currentStatus['duty_status_id'])): ?>
                        <div class="flex items-center justify-between">
                            <div>
                                <p class="text-lg font-semibold">
                                    <?php echo htmlspecialchars($currentStatus['status_name'] ?? 'Not Set'); ?>
                                </p>
                                <p class="text-gray-600">
                                    <?php echo htmlspecialchars($currentStatus['description'] ?? ''); ?>
                                </p>
                                <?php if (!empty($currentStatus['duty_shift'])): ?>
                                    <?php 
                                    $shiftClass = 'shift-day';
                                    $shiftDisplay = $currentStatus['duty_shift'];
                                    
                                    if (strpos($currentStatus['duty_shift'], 'N') === 0) {
                                        $shiftClass = 'shift-night';
                                    }
                                    
                                    // Format shift display
                                    $shiftDisplay = str_replace(['D', 'N'], ['Day ', 'Night '], $shiftDisplay);
                                    $shiftDisplay = str_replace('Hours', ' hrs', $shiftDisplay);
                                    ?>
                                    <p class="mt-2">
                                        <span class="shift-badge <?php echo $shiftClass; ?>">
                                            <?php echo htmlspecialchars($shiftDisplay); ?>
                                        </span>
                                    </p>
                                <?php endif; ?>
                            </div>
                            <div>
                                <?php 
                                // Show status indicator
                                $statusClass = 'status-unknown';
                                $statusName = $currentStatus['status_name'] ?? '';
                                
                                if ($statusName === 'OnDuty') {
                                    $statusClass = 'status-on-duty';
                                } elseif ($statusName === 'OnCall') {
                                    $statusClass = 'status-on-call';
                                } elseif ($statusName === 'OnLeave') {
                                    $statusClass = 'status-on-leave';
                                } elseif ($statusName === 'SickLeave') {
                                    $statusClass = 'status-sick-leave';
                                }
                                ?>
                                <span class="status-badge <?php echo $statusClass; ?>">
                                    <?php echo htmlspecialchars($statusName ?: 'Not Set'); ?>
                                </span>
                            </div>
                        </div>
                    <?php else: ?>
                        <p class="text-gray-500">No status set for this user.</p>
                    <?php endif; ?>
                </div>
                
                <h3 class="text-lg font-bold mb-4">Update Duty Status</h3>
                
                <form method="post" action="" id="duty-status-form">
                    <div class="mb-4">
                        <label for="duty_status" class="block text-gray-700 font-medium mb-2">Select Status:</label>
                        <select id="duty_status" name="duty_status" class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500" required>
                            <option value="">-- Select Duty Status --</option>
                            <?php foreach ($dutyStatuses as $status): ?>
                                <option value="<?php echo $status['id']; ?>" <?php echo ($currentStatus && $currentStatus['duty_status_id'] == $status['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($status['status_name']); ?> - <?php echo htmlspecialchars($status['description']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="mb-6">
                        <label for="shift" class="block text-gray-700 font-medium mb-2">Select Shift:</label>
                        <select id="shift" name="shift" class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                            <option value="">-- Select Shift --</option>
                            <option value="D6Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'D6Hours') ? 'selected' : ''; ?>>Day - 6 Hours</option>
                            <option value="D12Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'D12Hours') ? 'selected' : ''; ?>>Day - 12 Hours</option>
                            <option value="D24Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'D24Hours') ? 'selected' : ''; ?>>Day - 24 Hours</option>
                            <option value="N6Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'N6Hours') ? 'selected' : ''; ?>>Night - 6 Hours</option>
                            <option value="N12Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'N12Hours') ? 'selected' : ''; ?>>Night - 12 Hours</option>
                            <option value="N24Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'N24Hours') ? 'selected' : ''; ?>>Night - 24 Hours</option>
                        </select>
                    </div>
                    
                    <div class="flex justify-between">
                        <a href="user-manager.php" class="bg-gray-500 hover:bg-gray-600 text-white font-bold py-2 px-4 rounded focus:outline-none focus:ring-2 focus:ring-gray-500">
                            Cancel
                        </a>
                        <button type="submit" name="update_status" id="update-status-btn" class="bg-red-600 hover:bg-red-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:ring-2 focus:ring-red-500">
                            Update Status
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
    
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        const dutyStatusForm = document.getElementById('duty-status-form');
        const dutyStatusSelect = document.getElementById('duty_status');
        
        if (dutyStatusForm) {
            dutyStatusForm.addEventListener('submit', function(e) {
                if (dutyStatusSelect.value === '') {
                    e.preventDefault();
                    alert('Please select a duty status');
                    return false;
                }
            });
        }
    });
    </script>
</body>
</html>